"""
Themes/Icon Definitions
=======================

.. seealso::

   `Material Design Icons <https://materialdesignicons.com/>`_

.. image:: https://github.com/HeaTTheatR/KivyMD-data/raw/master/gallery/kivymddoc/material-icons.png
    :align: center

List of icons from materialdesignicons.com. These expanded material design
icons are maintained by Austin Andrews (Templarian on Github).

LAST UPDATED: Version 4.9.95

To preview the icons and their names, you can use the following application:
----------------------------------------------------------------------------

.. code-block:: python

    from kivy.lang import Builder
    from kivy.properties import StringProperty
    from kivy.uix.screenmanager import Screen

    from kivymd.icon_definitions import md_icons
    from kivymd.app import MDApp
    from kivymd.uix.list import OneLineIconListItem


    Builder.load_string(
        '''
    #:import images_path kivymd.images_path


    <CustomOneLineIconListItem>:

        IconLeftWidget:
            icon: root.icon


    <PreviousMDIcons>:

        BoxLayout:
            orientation: 'vertical'
            spacing: dp(10)
            padding: dp(20)

            BoxLayout:
                size_hint_y: None
                height: self.minimum_height

                MDIconButton:
                    icon: 'magnify'

                MDTextField:
                    id: search_field
                    hint_text: 'Search icon'
                    on_text: root.set_list_md_icons(self.text, True)

            RecycleView:
                id: rv
                key_viewclass: 'viewclass'
                key_size: 'height'

                RecycleBoxLayout:
                    padding: dp(10)
                    default_size: None, dp(48)
                    default_size_hint: 1, None
                    size_hint_y: None
                    height: self.minimum_height
                    orientation: 'vertical'
    '''
    )


    class CustomOneLineIconListItem(OneLineIconListItem):
        icon = StringProperty()


    class PreviousMDIcons(Screen):

        def set_list_md_icons(self, text="", search=False):
            '''Builds a list of icons for the screen MDIcons.'''

            def add_icon_item(name_icon):
                self.ids.rv.data.append(
                    {
                        "viewclass": "CustomOneLineIconListItem",
                        "icon": name_icon,
                        "text": name_icon,
                        "callback": lambda x: x,
                    }
                )

            self.ids.rv.data = []
            for name_icon in md_icons.keys():
                if search:
                    if text in name_icon:
                        add_icon_item(name_icon)
                else:
                    add_icon_item(name_icon)


    class MainApp(MDApp):
        def __init__(self, **kwargs):
            super().__init__(**kwargs)
            self.screen = PreviousMDIcons()

        def build(self):
            return self.screen

        def on_start(self):
            self.screen.set_list_md_icons()


    MainApp().run()

.. image:: https://github.com/HeaTTheatR/KivyMD-data/raw/master/gallery/kivymddoc/md-icons-previous.gif
    :align: center

"""

# THIS DICTIONARY WAS GENERATED BY ``kivymd/tools/update_icons.py``
md_icons = {
    "ab-testing": "\U000F001C",
    "abjad-arabic": "\U000F0353",
    "abjad-hebrew": "\U000F0354",
    "abugida-devanagari": "\U000F0355",
    "abugida-thai": "\U000F0356",
    "access-point": "\uF002",
    "access-point-network": "\uF003",
    "access-point-network-off": "\uFBBD",
    "account": "\uF004",
    "account-alert": "\uF005",
    "account-alert-outline": "\uFB2C",
    "account-arrow-left": "\uFB2D",
    "account-arrow-left-outline": "\uFB2E",
    "account-arrow-right": "\uFB2F",
    "account-arrow-right-outline": "\uFB30",
    "account-badge": "\uFD83",
    "account-badge-alert": "\uFD84",
    "account-badge-alert-outline": "\uFD85",
    "account-badge-horizontal": "\uFDF0",
    "account-badge-horizontal-outline": "\uFDF1",
    "account-badge-outline": "\uFD86",
    "account-box": "\uF006",
    "account-box-multiple": "\uF933",
    "account-box-multiple-outline": "\U000F002C",
    "account-box-outline": "\uF007",
    "account-cancel": "\U000F030A",
    "account-cancel-outline": "\U000F030B",
    "account-card-details": "\uF5D2",
    "account-card-details-outline": "\uFD87",
    "account-cash": "\U000F00C2",
    "account-cash-outline": "\U000F00C3",
    "account-check": "\uF008",
    "account-check-outline": "\uFBBE",
    "account-child": "\uFA88",
    "account-child-circle": "\uFA89",
    "account-child-outline": "\U000F00F3",
    "account-circle": "\uF009",
    "account-circle-outline": "\uFB31",
    "account-clock": "\uFB32",
    "account-clock-outline": "\uFB33",
    "account-cog": "\U000F039B",
    "account-cog-outline": "\U000F039C",
    "account-convert": "\uF00A",
    "account-convert-outline": "\U000F032C",
    "account-details": "\uF631",
    "account-details-outline": "\U000F039D",
    "account-edit": "\uF6BB",
    "account-edit-outline": "\U000F001D",
    "account-group": "\uF848",
    "account-group-outline": "\uFB34",
    "account-heart": "\uF898",
    "account-heart-outline": "\uFBBF",
    "account-key": "\uF00B",
    "account-key-outline": "\uFBC0",
    "account-lock": "\U000F0189",
    "account-lock-outline": "\U000F018A",
    "account-minus": "\uF00D",
    "account-minus-outline": "\uFAEB",
    "account-multiple": "\uF00E",
    "account-multiple-check": "\uF8C4",
    "account-multiple-check-outline": "\U000F0229",
    "account-multiple-minus": "\uF5D3",
    "account-multiple-minus-outline": "\uFBC1",
    "account-multiple-outline": "\uF00F",
    "account-multiple-plus": "\uF010",
    "account-multiple-plus-outline": "\uF7FF",
    "account-multiple-remove": "\U000F0235",
    "account-multiple-remove-outline": "\U000F0236",
    "account-network": "\uF011",
    "account-network-outline": "\uFBC2",
    "account-off": "\uF012",
    "account-off-outline": "\uFBC3",
    "account-outline": "\uF013",
    "account-plus": "\uF014",
    "account-plus-outline": "\uF800",
    "account-question": "\uFB35",
    "account-question-outline": "\uFB36",
    "account-remove": "\uF015",
    "account-remove-outline": "\uFAEC",
    "account-search": "\uF016",
    "account-search-outline": "\uF934",
    "account-settings": "\uF630",
    "account-settings-outline": "\U000F00F4",
    "account-star": "\uF017",
    "account-star-outline": "\uFBC4",
    "account-supervisor": "\uFA8A",
    "account-supervisor-circle": "\uFA8B",
    "account-supervisor-outline": "\U000F0158",
    "account-switch": "\uF019",
    "account-tie": "\uFCBF",
    "account-tie-outline": "\U000F00F5",
    "account-tie-voice": "\U000F0333",
    "account-tie-voice-off": "\U000F0335",
    "account-tie-voice-off-outline": "\U000F0336",
    "account-tie-voice-outline": "\U000F0334",
    "accusoft": "\uF849",
    "adjust": "\uF01A",
    "adobe": "\uF935",
    "adobe-acrobat": "\uFFBD",
    "air-conditioner": "\uF01B",
    "air-filter": "\uFD1F",
    "air-horn": "\uFD88",
    "air-humidifier": "\U000F00C4",
    "air-purifier": "\uFD20",
    "airbag": "\uFBC5",
    "airballoon": "\uF01C",
    "airballoon-outline": "\U000F002D",
    "airplane": "\uF01D",
    "airplane-landing": "\uF5D4",
    "airplane-off": "\uF01E",
    "airplane-takeoff": "\uF5D5",
    "airplay": "\uF01F",
    "airport": "\uF84A",
    "alarm": "\uF020",
    "alarm-bell": "\uF78D",
    "alarm-check": "\uF021",
    "alarm-light": "\uF78E",
    "alarm-light-outline": "\uFBC6",
    "alarm-multiple": "\uF022",
    "alarm-note": "\uFE8E",
    "alarm-note-off": "\uFE8F",
    "alarm-off": "\uF023",
    "alarm-plus": "\uF024",
    "alarm-snooze": "\uF68D",
    "album": "\uF025",
    "alert": "\uF026",
    "alert-box": "\uF027",
    "alert-box-outline": "\uFCC0",
    "alert-circle": "\uF028",
    "alert-circle-check": "\U000F0218",
    "alert-circle-check-outline": "\U000F0219",
    "alert-circle-outline": "\uF5D6",
    "alert-decagram": "\uF6BC",
    "alert-decagram-outline": "\uFCC1",
    "alert-octagon": "\uF029",
    "alert-octagon-outline": "\uFCC2",
    "alert-octagram": "\uF766",
    "alert-octagram-outline": "\uFCC3",
    "alert-outline": "\uF02A",
    "alert-rhombus": "\U000F01F9",
    "alert-rhombus-outline": "\U000F01FA",
    "alien": "\uF899",
    "alien-outline": "\U000F00F6",
    "align-horizontal-center": "\U000F01EE",
    "align-horizontal-left": "\U000F01ED",
    "align-horizontal-right": "\U000F01EF",
    "align-vertical-bottom": "\U000F01F0",
    "align-vertical-center": "\U000F01F1",
    "align-vertical-top": "\U000F01F2",
    "all-inclusive": "\uF6BD",
    "allergy": "\U000F0283",
    "alpha": "\uF02B",
    "alpha-a": "\u0041",
    "alpha-a-box": "\uFAED",
    "alpha-a-box-outline": "\uFBC7",
    "alpha-a-circle": "\uFBC8",
    "alpha-a-circle-outline": "\uFBC9",
    "alpha-b": "\u0042",
    "alpha-b-box": "\uFAEE",
    "alpha-b-box-outline": "\uFBCA",
    "alpha-b-circle": "\uFBCB",
    "alpha-b-circle-outline": "\uFBCC",
    "alpha-c": "\u0043",
    "alpha-c-box": "\uFAEF",
    "alpha-c-box-outline": "\uFBCD",
    "alpha-c-circle": "\uFBCE",
    "alpha-c-circle-outline": "\uFBCF",
    "alpha-d": "\u0044",
    "alpha-d-box": "\uFAF0",
    "alpha-d-box-outline": "\uFBD0",
    "alpha-d-circle": "\uFBD1",
    "alpha-d-circle-outline": "\uFBD2",
    "alpha-e": "\u0045",
    "alpha-e-box": "\uFAF1",
    "alpha-e-box-outline": "\uFBD3",
    "alpha-e-circle": "\uFBD4",
    "alpha-e-circle-outline": "\uFBD5",
    "alpha-f": "\u0046",
    "alpha-f-box": "\uFAF2",
    "alpha-f-box-outline": "\uFBD6",
    "alpha-f-circle": "\uFBD7",
    "alpha-f-circle-outline": "\uFBD8",
    "alpha-g": "\u0047",
    "alpha-g-box": "\uFAF3",
    "alpha-g-box-outline": "\uFBD9",
    "alpha-g-circle": "\uFBDA",
    "alpha-g-circle-outline": "\uFBDB",
    "alpha-h": "\u0048",
    "alpha-h-box": "\uFAF4",
    "alpha-h-box-outline": "\uFBDC",
    "alpha-h-circle": "\uFBDD",
    "alpha-h-circle-outline": "\uFBDE",
    "alpha-i": "\u0049",
    "alpha-i-box": "\uFAF5",
    "alpha-i-box-outline": "\uFBDF",
    "alpha-i-circle": "\uFBE0",
    "alpha-i-circle-outline": "\uFBE1",
    "alpha-j": "\u004A",
    "alpha-j-box": "\uFAF6",
    "alpha-j-box-outline": "\uFBE2",
    "alpha-j-circle": "\uFBE3",
    "alpha-j-circle-outline": "\uFBE4",
    "alpha-k": "\u004B",
    "alpha-k-box": "\uFAF7",
    "alpha-k-box-outline": "\uFBE5",
    "alpha-k-circle": "\uFBE6",
    "alpha-k-circle-outline": "\uFBE7",
    "alpha-l": "\u004C",
    "alpha-l-box": "\uFAF8",
    "alpha-l-box-outline": "\uFBE8",
    "alpha-l-circle": "\uFBE9",
    "alpha-l-circle-outline": "\uFBEA",
    "alpha-m": "\u004D",
    "alpha-m-box": "\uFAF9",
    "alpha-m-box-outline": "\uFBEB",
    "alpha-m-circle": "\uFBEC",
    "alpha-m-circle-outline": "\uFBED",
    "alpha-n": "\u004E",
    "alpha-n-box": "\uFAFA",
    "alpha-n-box-outline": "\uFBEE",
    "alpha-n-circle": "\uFBEF",
    "alpha-n-circle-outline": "\uFBF0",
    "alpha-o": "\u004F",
    "alpha-o-box": "\uFAFB",
    "alpha-o-box-outline": "\uFBF1",
    "alpha-o-circle": "\uFBF2",
    "alpha-o-circle-outline": "\uFBF3",
    "alpha-p": "\u0050",
    "alpha-p-box": "\uFAFC",
    "alpha-p-box-outline": "\uFBF4",
    "alpha-p-circle": "\uFBF5",
    "alpha-p-circle-outline": "\uFBF6",
    "alpha-q": "\u0051",
    "alpha-q-box": "\uFAFD",
    "alpha-q-box-outline": "\uFBF7",
    "alpha-q-circle": "\uFBF8",
    "alpha-q-circle-outline": "\uFBF9",
    "alpha-r": "\u0052",
    "alpha-r-box": "\uFAFE",
    "alpha-r-box-outline": "\uFBFA",
    "alpha-r-circle": "\uFBFB",
    "alpha-r-circle-outline": "\uFBFC",
    "alpha-s": "\u0053",
    "alpha-s-box": "\uFAFF",
    "alpha-s-box-outline": "\uFBFD",
    "alpha-s-circle": "\uFBFE",
    "alpha-s-circle-outline": "\uFBFF",
    "alpha-t": "\u0054",
    "alpha-t-box": "\uFB00",
    "alpha-t-box-outline": "\uFC00",
    "alpha-t-circle": "\uFC01",
    "alpha-t-circle-outline": "\uFC02",
    "alpha-u": "\u0055",
    "alpha-u-box": "\uFB01",
    "alpha-u-box-outline": "\uFC03",
    "alpha-u-circle": "\uFC04",
    "alpha-u-circle-outline": "\uFC05",
    "alpha-v": "\u0056",
    "alpha-v-box": "\uFB02",
    "alpha-v-box-outline": "\uFC06",
    "alpha-v-circle": "\uFC07",
    "alpha-v-circle-outline": "\uFC08",
    "alpha-w": "\u0057",
    "alpha-w-box": "\uFB03",
    "alpha-w-box-outline": "\uFC09",
    "alpha-w-circle": "\uFC0A",
    "alpha-w-circle-outline": "\uFC0B",
    "alpha-x": "\u0058",
    "alpha-x-box": "\uFB04",
    "alpha-x-box-outline": "\uFC0C",
    "alpha-x-circle": "\uFC0D",
    "alpha-x-circle-outline": "\uFC0E",
    "alpha-y": "\u0059",
    "alpha-y-box": "\uFB05",
    "alpha-y-box-outline": "\uFC0F",
    "alpha-y-circle": "\uFC10",
    "alpha-y-circle-outline": "\uFC11",
    "alpha-z": "\u005A",
    "alpha-z-box": "\uFB06",
    "alpha-z-box-outline": "\uFC12",
    "alpha-z-circle": "\uFC13",
    "alpha-z-circle-outline": "\uFC14",
    "alphabet-aurebesh": "\U000F0357",
    "alphabet-cyrillic": "\U000F0358",
    "alphabet-greek": "\U000F0359",
    "alphabet-latin": "\U000F035A",
    "alphabet-piqad": "\U000F035B",
    "alphabet-tengwar": "\U000F0362",
    "alphabetical": "\uF02C",
    "alphabetical-off": "\U000F002E",
    "alphabetical-variant": "\U000F002F",
    "alphabetical-variant-off": "\U000F0030",
    "altimeter": "\uF5D7",
    "amazon": "\uF02D",
    "amazon-alexa": "\uF8C5",
    "amazon-drive": "\uF02E",
    "ambulance": "\uF02F",
    "ammunition": "\uFCC4",
    "ampersand": "\uFA8C",
    "amplifier": "\uF030",
    "amplifier-off": "\U000F01E0",
    "anchor": "\uF031",
    "android": "\uF032",
    "android-auto": "\uFA8D",
    "android-debug-bridge": "\uF033",
    "android-head": "\uF78F",
    "android-messages": "\uFD21",
    "android-studio": "\uF034",
    "angle-acute": "\uF936",
    "angle-obtuse": "\uF937",
    "angle-right": "\uF938",
    "angular": "\uF6B1",
    "angularjs": "\uF6BE",
    "animation": "\uF5D8",
    "animation-outline": "\uFA8E",
    "animation-play": "\uF939",
    "animation-play-outline": "\uFA8F",
    "ansible": "\U000F00C5",
    "antenna": "\U000F0144",
    "anvil": "\uF89A",
    "apache-kafka": "\U000F0031",
    "api": "\U000F00C6",
    "api-off": "\U000F0282",
    "apple": "\uF035",
    "apple-finder": "\uF036",
    "apple-icloud": "\uF038",
    "apple-ios": "\uF037",
    "apple-keyboard-caps": "\uF632",
    "apple-keyboard-command": "\uF633",
    "apple-keyboard-control": "\uF634",
    "apple-keyboard-option": "\uF635",
    "apple-keyboard-shift": "\uF636",
    "apple-safari": "\uF039",
    "application": "\uF614",
    "application-export": "\uFD89",
    "application-import": "\uFD8A",
    "approximately-equal": "\uFFBE",
    "approximately-equal-box": "\uFFBF",
    "apps": "\uF03B",
    "apps-box": "\uFD22",
    "arch": "\uF8C6",
    "archive": "\uF03C",
    "archive-arrow-down": "\U000F0284",
    "archive-arrow-down-outline": "\U000F0285",
    "archive-arrow-up": "\U000F0286",
    "archive-arrow-up-outline": "\U000F0287",
    "archive-outline": "\U000F0239",
    "arm-flex": "\U000F008F",
    "arm-flex-outline": "\U000F0090",
    "arrange-bring-forward": "\uF03D",
    "arrange-bring-to-front": "\uF03E",
    "arrange-send-backward": "\uF03F",
    "arrange-send-to-back": "\uF040",
    "arrow-all": "\uF041",
    "arrow-bottom-left": "\uF042",
    "arrow-bottom-left-bold-outline": "\uF9B6",
    "arrow-bottom-left-thick": "\uF9B7",
    "arrow-bottom-right": "\uF043",
    "arrow-bottom-right-bold-outline": "\uF9B8",
    "arrow-bottom-right-thick": "\uF9B9",
    "arrow-collapse": "\uF615",
    "arrow-collapse-all": "\uF044",
    "arrow-collapse-down": "\uF791",
    "arrow-collapse-horizontal": "\uF84B",
    "arrow-collapse-left": "\uF792",
    "arrow-collapse-right": "\uF793",
    "arrow-collapse-up": "\uF794",
    "arrow-collapse-vertical": "\uF84C",
    "arrow-decision": "\uF9BA",
    "arrow-decision-auto": "\uF9BB",
    "arrow-decision-auto-outline": "\uF9BC",
    "arrow-decision-outline": "\uF9BD",
    "arrow-down": "\uF045",
    "arrow-down-bold": "\uF72D",
    "arrow-down-bold-box": "\uF72E",
    "arrow-down-bold-box-outline": "\uF72F",
    "arrow-down-bold-circle": "\uF047",
    "arrow-down-bold-circle-outline": "\uF048",
    "arrow-down-bold-hexagon-outline": "\uF049",
    "arrow-down-bold-outline": "\uF9BE",
    "arrow-down-box": "\uF6BF",
    "arrow-down-circle": "\uFCB7",
    "arrow-down-circle-outline": "\uFCB8",
    "arrow-down-drop-circle": "\uF04A",
    "arrow-down-drop-circle-outline": "\uF04B",
    "arrow-down-thick": "\uF046",
    "arrow-expand": "\uF616",
    "arrow-expand-all": "\uF04C",
    "arrow-expand-down": "\uF795",
    "arrow-expand-horizontal": "\uF84D",
    "arrow-expand-left": "\uF796",
    "arrow-expand-right": "\uF797",
    "arrow-expand-up": "\uF798",
    "arrow-expand-vertical": "\uF84E",
    "arrow-horizontal-lock": "\U000F0186",
    "arrow-left": "\uF04D",
    "arrow-left-bold": "\uF730",
    "arrow-left-bold-box": "\uF731",
    "arrow-left-bold-box-outline": "\uF732",
    "arrow-left-bold-circle": "\uF04F",
    "arrow-left-bold-circle-outline": "\uF050",
    "arrow-left-bold-hexagon-outline": "\uF051",
    "arrow-left-bold-outline": "\uF9BF",
    "arrow-left-box": "\uF6C0",
    "arrow-left-circle": "\uFCB9",
    "arrow-left-circle-outline": "\uFCBA",
    "arrow-left-drop-circle": "\uF052",
    "arrow-left-drop-circle-outline": "\uF053",
    "arrow-left-right": "\uFE90",
    "arrow-left-right-bold": "\uFE91",
    "arrow-left-right-bold-outline": "\uF9C0",
    "arrow-left-thick": "\uF04E",
    "arrow-right": "\uF054",
    "arrow-right-bold": "\uF733",
    "arrow-right-bold-box": "\uF734",
    "arrow-right-bold-box-outline": "\uF735",
    "arrow-right-bold-circle": "\uF056",
    "arrow-right-bold-circle-outline": "\uF057",
    "arrow-right-bold-hexagon-outline": "\uF058",
    "arrow-right-bold-outline": "\uF9C1",
    "arrow-right-box": "\uF6C1",
    "arrow-right-circle": "\uFCBB",
    "arrow-right-circle-outline": "\uFCBC",
    "arrow-right-drop-circle": "\uF059",
    "arrow-right-drop-circle-outline": "\uF05A",
    "arrow-right-thick": "\uF055",
    "arrow-split-horizontal": "\uF93A",
    "arrow-split-vertical": "\uF93B",
    "arrow-top-left": "\uF05B",
    "arrow-top-left-bold-outline": "\uF9C2",
    "arrow-top-left-bottom-right": "\uFE92",
    "arrow-top-left-bottom-right-bold": "\uFE93",
    "arrow-top-left-thick": "\uF9C3",
    "arrow-top-right": "\uF05C",
    "arrow-top-right-bold-outline": "\uF9C4",
    "arrow-top-right-bottom-left": "\uFE94",
    "arrow-top-right-bottom-left-bold": "\uFE95",
    "arrow-top-right-thick": "\uF9C5",
    "arrow-up": "\uF05D",
    "arrow-up-bold": "\uF736",
    "arrow-up-bold-box": "\uF737",
    "arrow-up-bold-box-outline": "\uF738",
    "arrow-up-bold-circle": "\uF05F",
    "arrow-up-bold-circle-outline": "\uF060",
    "arrow-up-bold-hexagon-outline": "\uF061",
    "arrow-up-bold-outline": "\uF9C6",
    "arrow-up-box": "\uF6C2",
    "arrow-up-circle": "\uFCBD",
    "arrow-up-circle-outline": "\uFCBE",
    "arrow-up-down": "\uFE96",
    "arrow-up-down-bold": "\uFE97",
    "arrow-up-down-bold-outline": "\uF9C7",
    "arrow-up-drop-circle": "\uF062",
    "arrow-up-drop-circle-outline": "\uF063",
    "arrow-up-thick": "\uF05E",
    "arrow-vertical-lock": "\U000F0187",
    "artist": "\uF802",
    "artist-outline": "\uFCC5",
    "artstation": "\uFB37",
    "aspect-ratio": "\uFA23",
    "assistant": "\uF064",
    "asterisk": "\uF6C3",
    "at": "\uF065",
    "atlassian": "\uF803",
    "atm": "\uFD23",
    "atom": "\uF767",
    "atom-variant": "\uFE98",
    "attachment": "\uF066",
    "audio-video": "\uF93C",
    "audio-video-off": "\U000F01E1",
    "audiobook": "\uF067",
    "augmented-reality": "\uF84F",
    "auto-download": "\U000F03A9",
    "auto-fix": "\uF068",
    "auto-upload": "\uF069",
    "autorenew": "\uF06A",
    "av-timer": "\uF06B",
    "aws": "\uFDF2",
    "axe": "\uF8C7",
    "axis": "\uFD24",
    "axis-arrow": "\uFD25",
    "axis-arrow-lock": "\uFD26",
    "axis-lock": "\uFD27",
    "axis-x-arrow": "\uFD28",
    "axis-x-arrow-lock": "\uFD29",
    "axis-x-rotate-clockwise": "\uFD2A",
    "axis-x-rotate-counterclockwise": "\uFD2B",
    "axis-x-y-arrow-lock": "\uFD2C",
    "axis-y-arrow": "\uFD2D",
    "axis-y-arrow-lock": "\uFD2E",
    "axis-y-rotate-clockwise": "\uFD2F",
    "axis-y-rotate-counterclockwise": "\uFD30",
    "axis-z-arrow": "\uFD31",
    "axis-z-arrow-lock": "\uFD32",
    "axis-z-rotate-clockwise": "\uFD33",
    "axis-z-rotate-counterclockwise": "\uFD34",
    "azure": "\uF804",
    "azure-devops": "\U000F0091",
    "babel": "\uFA24",
    "baby": "\uF06C",
    "baby-bottle": "\uFF56",
    "baby-bottle-outline": "\uFF57",
    "baby-carriage": "\uF68E",
    "baby-carriage-off": "\uFFC0",
    "baby-face": "\uFE99",
    "baby-face-outline": "\uFE9A",
    "backburger": "\uF06D",
    "backspace": "\uF06E",
    "backspace-outline": "\uFB38",
    "backspace-reverse": "\uFE9B",
    "backspace-reverse-outline": "\uFE9C",
    "backup-restore": "\uF06F",
    "bacteria": "\uFEF2",
    "bacteria-outline": "\uFEF3",
    "badminton": "\uF850",
    "bag-carry-on": "\uFF58",
    "bag-carry-on-check": "\uFD41",
    "bag-carry-on-off": "\uFF59",
    "bag-checked": "\uFF5A",
    "bag-personal": "\uFDF3",
    "bag-personal-off": "\uFDF4",
    "bag-personal-off-outline": "\uFDF5",
    "bag-personal-outline": "\uFDF6",
    "baguette": "\uFF5B",
    "balloon": "\uFA25",
    "ballot": "\uF9C8",
    "ballot-outline": "\uF9C9",
    "ballot-recount": "\uFC15",
    "ballot-recount-outline": "\uFC16",
    "bandage": "\uFD8B",
    "bandcamp": "\uF674",
    "bank": "\uF070",
    "bank-minus": "\uFD8C",
    "bank-outline": "\uFE9D",
    "bank-plus": "\uFD8D",
    "bank-remove": "\uFD8E",
    "bank-transfer": "\uFA26",
    "bank-transfer-in": "\uFA27",
    "bank-transfer-out": "\uFA28",
    "barcode": "\uF071",
    "barcode-off": "\U000F0261",
    "barcode-scan": "\uF072",
    "barley": "\uF073",
    "barley-off": "\uFB39",
    "barn": "\uFB3A",
    "barrel": "\uF074",
    "baseball": "\uF851",
    "baseball-bat": "\uF852",
    "basecamp": "\uF075",
    "bash": "\U000F01AE",
    "basket": "\uF076",
    "basket-fill": "\uF077",
    "basket-outline": "\U000F01AC",
    "basket-unfill": "\uF078",
    "basketball": "\uF805",
    "basketball-hoop": "\uFC17",
    "basketball-hoop-outline": "\uFC18",
    "bat": "\uFB3B",
    "battery": "\uF079",
    "battery-10": "\uF07A",
    "battery-10-bluetooth": "\uF93D",
    "battery-20": "\uF07B",
    "battery-20-bluetooth": "\uF93E",
    "battery-30": "\uF07C",
    "battery-30-bluetooth": "\uF93F",
    "battery-40": "\uF07D",
    "battery-40-bluetooth": "\uF940",
    "battery-50": "\uF07E",
    "battery-50-bluetooth": "\uF941",
    "battery-60": "\uF07F",
    "battery-60-bluetooth": "\uF942",
    "battery-70": "\uF080",
    "battery-70-bluetooth": "\uF943",
    "battery-80": "\uF081",
    "battery-80-bluetooth": "\uF944",
    "battery-90": "\uF082",
    "battery-90-bluetooth": "\uF945",
    "battery-alert": "\uF083",
    "battery-alert-bluetooth": "\uF946",
    "battery-alert-variant": "\U000F00F7",
    "battery-alert-variant-outline": "\U000F00F8",
    "battery-bluetooth": "\uF947",
    "battery-bluetooth-variant": "\uF948",
    "battery-charging": "\uF084",
    "battery-charging-10": "\uF89B",
    "battery-charging-100": "\uF085",
    "battery-charging-20": "\uF086",
    "battery-charging-30": "\uF087",
    "battery-charging-40": "\uF088",
    "battery-charging-50": "\uF89C",
    "battery-charging-60": "\uF089",
    "battery-charging-70": "\uF89D",
    "battery-charging-80": "\uF08A",
    "battery-charging-90": "\uF08B",
    "battery-charging-high": "\U000F02D1",
    "battery-charging-low": "\U000F02CF",
    "battery-charging-medium": "\U000F02D0",
    "battery-charging-outline": "\uF89E",
    "battery-charging-wireless": "\uF806",
    "battery-charging-wireless-10": "\uF807",
    "battery-charging-wireless-20": "\uF808",
    "battery-charging-wireless-30": "\uF809",
    "battery-charging-wireless-40": "\uF80A",
    "battery-charging-wireless-50": "\uF80B",
    "battery-charging-wireless-60": "\uF80C",
    "battery-charging-wireless-70": "\uF80D",
    "battery-charging-wireless-80": "\uF80E",
    "battery-charging-wireless-90": "\uF80F",
    "battery-charging-wireless-alert": "\uF810",
    "battery-charging-wireless-outline": "\uF811",
    "battery-heart": "\U000F023A",
    "battery-heart-outline": "\U000F023B",
    "battery-heart-variant": "\U000F023C",
    "battery-high": "\U000F02CE",
    "battery-low": "\U000F02CC",
    "battery-medium": "\U000F02CD",
    "battery-minus": "\uF08C",
    "battery-negative": "\uF08D",
    "battery-off": "\U000F0288",
    "battery-off-outline": "\U000F0289",
    "battery-outline": "\uF08E",
    "battery-plus": "\uF08F",
    "battery-positive": "\uF090",
    "battery-unknown": "\uF091",
    "battery-unknown-bluetooth": "\uF949",
    "battlenet": "\uFB3C",
    "beach": "\uF092",
    "beaker": "\uFCC6",
    "beaker-alert": "\U000F0254",
    "beaker-alert-outline": "\U000F0255",
    "beaker-check": "\U000F0256",
    "beaker-check-outline": "\U000F0257",
    "beaker-minus": "\U000F0258",
    "beaker-minus-outline": "\U000F0259",
    "beaker-outline": "\uF68F",
    "beaker-plus": "\U000F025A",
    "beaker-plus-outline": "\U000F025B",
    "beaker-question": "\U000F025C",
    "beaker-question-outline": "\U000F025D",
    "beaker-remove": "\U000F025E",
    "beaker-remove-outline": "\U000F025F",
    "beats": "\uF097",
    "bed-double": "\U000F0092",
    "bed-double-outline": "\U000F0093",
    "bed-empty": "\uF89F",
    "bed-king": "\U000F0094",
    "bed-king-outline": "\U000F0095",
    "bed-queen": "\U000F0096",
    "bed-queen-outline": "\U000F0097",
    "bed-single": "\U000F0098",
    "bed-single-outline": "\U000F0099",
    "bee": "\uFFC1",
    "bee-flower": "\uFFC2",
    "beehive-outline": "\U000F00F9",
    "beer": "\uF098",
    "beer-outline": "\U000F0337",
    "behance": "\uF099",
    "bell": "\uF09A",
    "bell-alert": "\uFD35",
    "bell-alert-outline": "\uFE9E",
    "bell-check": "\U000F0210",
    "bell-check-outline": "\U000F0211",
    "bell-circle": "\uFD36",
    "bell-circle-outline": "\uFD37",
    "bell-off": "\uF09B",
    "bell-off-outline": "\uFA90",
    "bell-outline": "\uF09C",
    "bell-plus": "\uF09D",
    "bell-plus-outline": "\uFA91",
    "bell-ring": "\uF09E",
    "bell-ring-outline": "\uF09F",
    "bell-sleep": "\uF0A0",
    "bell-sleep-outline": "\uFA92",
    "beta": "\uF0A1",
    "betamax": "\uF9CA",
    "biathlon": "\uFDF7",
    "bible": "\uF0A2",
    "bicycle": "\U000F00C7",
    "bicycle-basket": "\U000F0260",
    "bike": "\uF0A3",
    "bike-fast": "\U000F014A",
    "billboard": "\U000F0032",
    "billiards": "\uFB3D",
    "billiards-rack": "\uFB3E",
    "bing": "\uF0A4",
    "binoculars": "\uF0A5",
    "bio": "\uF0A6",
    "biohazard": "\uF0A7",
    "bitbucket": "\uF0A8",
    "bitcoin": "\uF812",
    "black-mesa": "\uF0A9",
    "blackberry": "\uF0AA",
    "blender": "\uFCC7",
    "blender-software": "\uF0AB",
    "blinds": "\uF0AC",
    "blinds-open": "\U000F0033",
    "block-helper": "\uF0AD",
    "blogger": "\uF0AE",
    "blood-bag": "\uFCC8",
    "bluetooth": "\uF0AF",
    "bluetooth-audio": "\uF0B0",
    "bluetooth-connect": "\uF0B1",
    "bluetooth-off": "\uF0B2",
    "bluetooth-settings": "\uF0B3",
    "bluetooth-transfer": "\uF0B4",
    "blur": "\uF0B5",
    "blur-linear": "\uF0B6",
    "blur-off": "\uF0B7",
    "blur-radial": "\uF0B8",
    "bolnisi-cross": "\uFCC9",
    "bolt": "\uFD8F",
    "bomb": "\uF690",
    "bomb-off": "\uF6C4",
    "bone": "\uF0B9",
    "book": "\uF0BA",
    "book-information-variant": "\U000F009A",
    "book-lock": "\uF799",
    "book-lock-open": "\uF79A",
    "book-minus": "\uF5D9",
    "book-minus-multiple": "\uFA93",
    "book-multiple": "\uF0BB",
    "book-open": "\uF0BD",
    "book-open-outline": "\uFB3F",
    "book-open-page-variant": "\uF5DA",
    "book-open-variant": "\uF0BE",
    "book-outline": "\uFB40",
    "book-play": "\uFE9F",
    "book-play-outline": "\uFEA0",
    "book-plus": "\uF5DB",
    "book-plus-multiple": "\uFA94",
    "book-remove": "\uFA96",
    "book-remove-multiple": "\uFA95",
    "book-search": "\uFEA1",
    "book-search-outline": "\uFEA2",
    "book-variant": "\uF0BF",
    "book-variant-multiple": "\uF0BC",
    "bookmark": "\uF0C0",
    "bookmark-check": "\uF0C1",
    "bookmark-check-outline": "\U000F03A6",
    "bookmark-minus": "\uF9CB",
    "bookmark-minus-outline": "\uF9CC",
    "bookmark-multiple": "\uFDF8",
    "bookmark-multiple-outline": "\uFDF9",
    "bookmark-music": "\uF0C2",
    "bookmark-music-outline": "\U000F03A4",
    "bookmark-off": "\uF9CD",
    "bookmark-off-outline": "\uF9CE",
    "bookmark-outline": "\uF0C3",
    "bookmark-plus": "\uF0C5",
    "bookmark-plus-outline": "\uF0C4",
    "bookmark-remove": "\uF0C6",
    "bookmark-remove-outline": "\U000F03A5",
    "bookshelf": "\U000F028A",
    "boom-gate": "\uFEA3",
    "boom-gate-alert": "\uFEA4",
    "boom-gate-alert-outline": "\uFEA5",
    "boom-gate-down": "\uFEA6",
    "boom-gate-down-outline": "\uFEA7",
    "boom-gate-outline": "\uFEA8",
    "boom-gate-up": "\uFEA9",
    "boom-gate-up-outline": "\uFEAA",
    "boombox": "\uF5DC",
    "boomerang": "\U000F00FA",
    "bootstrap": "\uF6C5",
    "border-all": "\uF0C7",
    "border-all-variant": "\uF8A0",
    "border-bottom": "\uF0C8",
    "border-bottom-variant": "\uF8A1",
    "border-color": "\uF0C9",
    "border-horizontal": "\uF0CA",
    "border-inside": "\uF0CB",
    "border-left": "\uF0CC",
    "border-left-variant": "\uF8A2",
    "border-none": "\uF0CD",
    "border-none-variant": "\uF8A3",
    "border-outside": "\uF0CE",
    "border-right": "\uF0CF",
    "border-right-variant": "\uF8A4",
    "border-style": "\uF0D0",
    "border-top": "\uF0D1",
    "border-top-variant": "\uF8A5",
    "border-vertical": "\uF0D2",
    "bottle-soda": "\U000F009B",
    "bottle-soda-classic": "\U000F009C",
    "bottle-soda-classic-outline": "\U000F038E",
    "bottle-soda-outline": "\U000F009D",
    "bottle-tonic": "\U000F0159",
    "bottle-tonic-outline": "\U000F015A",
    "bottle-tonic-plus": "\U000F015B",
    "bottle-tonic-plus-outline": "\U000F015C",
    "bottle-tonic-skull": "\U000F015D",
    "bottle-tonic-skull-outline": "\U000F015E",
    "bottle-wine": "\uF853",
    "bottle-wine-outline": "\U000F033B",
    "bow-tie": "\uF677",
    "bowl": "\uF617",
    "bowling": "\uF0D3",
    "box": "\uF0D4",
    "box-cutter": "\uF0D5",
    "box-shadow": "\uF637",
    "boxing-glove": "\uFB41",
    "braille": "\uF9CF",
    "brain": "\uF9D0",
    "bread-slice": "\uFCCA",
    "bread-slice-outline": "\uFCCB",
    "bridge": "\uF618",
    "briefcase": "\uF0D6",
    "briefcase-account": "\uFCCC",
    "briefcase-account-outline": "\uFCCD",
    "briefcase-check": "\uF0D7",
    "briefcase-check-outline": "\U000F0349",
    "briefcase-clock": "\U000F00FB",
    "briefcase-clock-outline": "\U000F00FC",
    "briefcase-download": "\uF0D8",
    "briefcase-download-outline": "\uFC19",
    "briefcase-edit": "\uFA97",
    "briefcase-edit-outline": "\uFC1A",
    "briefcase-minus": "\uFA29",
    "briefcase-minus-outline": "\uFC1B",
    "briefcase-outline": "\uF813",
    "briefcase-plus": "\uFA2A",
    "briefcase-plus-outline": "\uFC1C",
    "briefcase-remove": "\uFA2B",
    "briefcase-remove-outline": "\uFC1D",
    "briefcase-search": "\uFA2C",
    "briefcase-search-outline": "\uFC1E",
    "briefcase-upload": "\uF0D9",
    "briefcase-upload-outline": "\uFC1F",
    "brightness-1": "\uF0DA",
    "brightness-2": "\uF0DB",
    "brightness-3": "\uF0DC",
    "brightness-4": "\uF0DD",
    "brightness-5": "\uF0DE",
    "brightness-6": "\uF0DF",
    "brightness-7": "\uF0E0",
    "brightness-auto": "\uF0E1",
    "brightness-percent": "\uFCCE",
    "broom": "\uF0E2",
    "brush": "\uF0E3",
    "buddhism": "\uF94A",
    "buffer": "\uF619",
    "bug": "\uF0E4",
    "bug-check": "\uFA2D",
    "bug-check-outline": "\uFA2E",
    "bug-outline": "\uFA2F",
    "bugle": "\uFD90",
    "bulldozer": "\uFB07",
    "bullet": "\uFCCF",
    "bulletin-board": "\uF0E5",
    "bullhorn": "\uF0E6",
    "bullhorn-outline": "\uFB08",
    "bullseye": "\uF5DD",
    "bullseye-arrow": "\uF8C8",
    "bulma": "\U000F0312",
    "bunk-bed": "\U000F032D",
    "bus": "\uF0E7",
    "bus-alert": "\uFA98",
    "bus-articulated-end": "\uF79B",
    "bus-articulated-front": "\uF79C",
    "bus-clock": "\uF8C9",
    "bus-double-decker": "\uF79D",
    "bus-marker": "\U000F023D",
    "bus-multiple": "\uFF5C",
    "bus-school": "\uF79E",
    "bus-side": "\uF79F",
    "bus-stop": "\U000F0034",
    "bus-stop-covered": "\U000F0035",
    "bus-stop-uncovered": "\U000F0036",
    "cached": "\uF0E8",
    "cactus": "\uFD91",
    "cake": "\uF0E9",
    "cake-layered": "\uF0EA",
    "cake-variant": "\uF0EB",
    "calculator": "\uF0EC",
    "calculator-variant": "\uFA99",
    "calendar": "\uF0ED",
    "calendar-account": "\uFEF4",
    "calendar-account-outline": "\uFEF5",
    "calendar-alert": "\uFA30",
    "calendar-arrow-left": "\U000F015F",
    "calendar-arrow-right": "\U000F0160",
    "calendar-blank": "\uF0EE",
    "calendar-blank-multiple": "\U000F009E",
    "calendar-blank-outline": "\uFB42",
    "calendar-check": "\uF0EF",
    "calendar-check-outline": "\uFC20",
    "calendar-clock": "\uF0F0",
    "calendar-edit": "\uF8A6",
    "calendar-export": "\uFB09",
    "calendar-heart": "\uF9D1",
    "calendar-import": "\uFB0A",
    "calendar-minus": "\uFD38",
    "calendar-month": "\uFDFA",
    "calendar-month-outline": "\uFDFB",
    "calendar-multiple": "\uF0F1",
    "calendar-multiple-check": "\uF0F2",
    "calendar-multiselect": "\uFA31",
    "calendar-outline": "\uFB43",
    "calendar-plus": "\uF0F3",
    "calendar-question": "\uF691",
    "calendar-range": "\uF678",
    "calendar-range-outline": "\uFB44",
    "calendar-remove": "\uF0F4",
    "calendar-remove-outline": "\uFC21",
    "calendar-repeat": "\uFEAB",
    "calendar-repeat-outline": "\uFEAC",
    "calendar-search": "\uF94B",
    "calendar-star": "\uF9D2",
    "calendar-text": "\uF0F5",
    "calendar-text-outline": "\uFC22",
    "calendar-today": "\uF0F6",
    "calendar-week": "\uFA32",
    "calendar-week-begin": "\uFA33",
    "calendar-weekend": "\uFEF6",
    "calendar-weekend-outline": "\uFEF7",
    "call-made": "\uF0F7",
    "call-merge": "\uF0F8",
    "call-missed": "\uF0F9",
    "call-received": "\uF0FA",
    "call-split": "\uF0FB",
    "camcorder": "\uF0FC",
    "camcorder-box": "\uF0FD",
    "camcorder-box-off": "\uF0FE",
    "camcorder-off": "\uF0FF",
    "camera": "\uF100",
    "camera-account": "\uF8CA",
    "camera-burst": "\uF692",
    "camera-control": "\uFB45",
    "camera-enhance": "\uF101",
    "camera-enhance-outline": "\uFB46",
    "camera-front": "\uF102",
    "camera-front-variant": "\uF103",
    "camera-gopro": "\uF7A0",
    "camera-image": "\uF8CB",
    "camera-iris": "\uF104",
    "camera-metering-center": "\uF7A1",
    "camera-metering-matrix": "\uF7A2",
    "camera-metering-partial": "\uF7A3",
    "camera-metering-spot": "\uF7A4",
    "camera-off": "\uF5DF",
    "camera-outline": "\uFD39",
    "camera-party-mode": "\uF105",
    "camera-plus": "\uFEF8",
    "camera-plus-outline": "\uFEF9",
    "camera-rear": "\uF106",
    "camera-rear-variant": "\uF107",
    "camera-retake": "\uFDFC",
    "camera-retake-outline": "\uFDFD",
    "camera-switch": "\uF108",
    "camera-timer": "\uF109",
    "camera-wireless": "\uFD92",
    "camera-wireless-outline": "\uFD93",
    "campfire": "\uFEFA",
    "cancel": "\uF739",
    "candle": "\uF5E2",
    "candycane": "\uF10A",
    "cannabis": "\uF7A5",
    "caps-lock": "\uFA9A",
    "car": "\uF10B",
    "car-2-plus": "\U000F0037",
    "car-3-plus": "\U000F0038",
    "car-back": "\uFDFE",
    "car-battery": "\uF10C",
    "car-brake-abs": "\uFC23",
    "car-brake-alert": "\uFC24",
    "car-brake-hold": "\uFD3A",
    "car-brake-parking": "\uFD3B",
    "car-brake-retarder": "\U000F0039",
    "car-child-seat": "\uFFC3",
    "car-clutch": "\U000F003A",
    "car-connected": "\uF10D",
    "car-convertible": "\uF7A6",
    "car-coolant-level": "\U000F003B",
    "car-cruise-control": "\uFD3C",
    "car-defrost-front": "\uFD3D",
    "car-defrost-rear": "\uFD3E",
    "car-door": "\uFB47",
    "car-door-lock": "\U000F00C8",
    "car-electric": "\uFB48",
    "car-esp": "\uFC25",
    "car-estate": "\uF7A7",
    "car-hatchback": "\uF7A8",
    "car-info": "\U000F01E9",
    "car-key": "\uFB49",
    "car-light-dimmed": "\uFC26",
    "car-light-fog": "\uFC27",
    "car-light-high": "\uFC28",
    "car-limousine": "\uF8CC",
    "car-multiple": "\uFB4A",
    "car-off": "\uFDFF",
    "car-parking-lights": "\uFD3F",
    "car-pickup": "\uF7A9",
    "car-seat": "\uFFC4",
    "car-seat-cooler": "\uFFC5",
    "car-seat-heater": "\uFFC6",
    "car-shift-pattern": "\uFF5D",
    "car-side": "\uF7AA",
    "car-sports": "\uF7AB",
    "car-tire-alert": "\uFC29",
    "car-traction-control": "\uFD40",
    "car-turbocharger": "\U000F003C",
    "car-wash": "\uF10E",
    "car-windshield": "\U000F003D",
    "car-windshield-outline": "\U000F003E",
    "caravan": "\uF7AC",
    "card": "\uFB4B",
    "card-bulleted": "\uFB4C",
    "card-bulleted-off": "\uFB4D",
    "card-bulleted-off-outline": "\uFB4E",
    "card-bulleted-outline": "\uFB4F",
    "card-bulleted-settings": "\uFB50",
    "card-bulleted-settings-outline": "\uFB51",
    "card-outline": "\uFB52",
    "card-plus": "\U000F022A",
    "card-plus-outline": "\U000F022B",
    "card-search": "\U000F009F",
    "card-search-outline": "\U000F00A0",
    "card-text": "\uFB53",
    "card-text-outline": "\uFB54",
    "cards": "\uF638",
    "cards-club": "\uF8CD",
    "cards-diamond": "\uF8CE",
    "cards-diamond-outline": "\U000F003F",
    "cards-heart": "\uF8CF",
    "cards-outline": "\uF639",
    "cards-playing-outline": "\uF63A",
    "cards-spade": "\uF8D0",
    "cards-variant": "\uF6C6",
    "carrot": "\uF10F",
    "cart": "\uF110",
    "cart-arrow-down": "\uFD42",
    "cart-arrow-right": "\uFC2A",
    "cart-arrow-up": "\uFD43",
    "cart-minus": "\uFD44",
    "cart-off": "\uF66B",
    "cart-outline": "\uF111",
    "cart-plus": "\uF112",
    "cart-remove": "\uFD45",
    "case-sensitive-alt": "\uF113",
    "cash": "\uF114",
    "cash-100": "\uF115",
    "cash-marker": "\uFD94",
    "cash-minus": "\U000F028B",
    "cash-multiple": "\uF116",
    "cash-plus": "\U000F028C",
    "cash-refund": "\uFA9B",
    "cash-register": "\uFCD0",
    "cash-remove": "\U000F028D",
    "cash-usd": "\U000F01A1",
    "cash-usd-outline": "\uF117",
    "cassette": "\uF9D3",
    "cast": "\uF118",
    "cast-audio": "\U000F0040",
    "cast-connected": "\uF119",
    "cast-education": "\uFE6D",
    "cast-off": "\uF789",
    "castle": "\uF11A",
    "cat": "\uF11B",
    "cctv": "\uF7AD",
    "ceiling-light": "\uF768",
    "cellphone": "\uF11C",
    "cellphone-android": "\uF11D",
    "cellphone-arrow-down": "\uF9D4",
    "cellphone-basic": "\uF11E",
    "cellphone-dock": "\uF11F",
    "cellphone-erase": "\uF94C",
    "cellphone-information": "\uFF5E",
    "cellphone-iphone": "\uF120",
    "cellphone-key": "\uF94D",
    "cellphone-link": "\uF121",
    "cellphone-link-off": "\uF122",
    "cellphone-lock": "\uF94E",
    "cellphone-message": "\uF8D2",
    "cellphone-message-off": "\U000F00FD",
    "cellphone-nfc": "\uFEAD",
    "cellphone-nfc-off": "\U000F0303",
    "cellphone-off": "\uF94F",
    "cellphone-play": "\U000F0041",
    "cellphone-screenshot": "\uFA34",
    "cellphone-settings": "\uF123",
    "cellphone-settings-variant": "\uF950",
    "cellphone-sound": "\uF951",
    "cellphone-text": "\uF8D1",
    "cellphone-wireless": "\uF814",
    "celtic-cross": "\uFCD1",
    "centos": "\U000F0145",
    "certificate": "\uF124",
    "certificate-outline": "\U000F01B3",
    "chair-rolling": "\uFFBA",
    "chair-school": "\uF125",
    "charity": "\uFC2B",
    "chart-arc": "\uF126",
    "chart-areaspline": "\uF127",
    "chart-areaspline-variant": "\uFEAE",
    "chart-bar": "\uF128",
    "chart-bar-stacked": "\uF769",
    "chart-bell-curve": "\uFC2C",
    "chart-bell-curve-cumulative": "\uFFC7",
    "chart-bubble": "\uF5E3",
    "chart-donut": "\uF7AE",
    "chart-donut-variant": "\uF7AF",
    "chart-gantt": "\uF66C",
    "chart-histogram": "\uF129",
    "chart-line": "\uF12A",
    "chart-line-stacked": "\uF76A",
    "chart-line-variant": "\uF7B0",
    "chart-multiline": "\uF8D3",
    "chart-multiple": "\U000F023E",
    "chart-pie": "\uF12B",
    "chart-ppf": "\U000F03AB",
    "chart-scatter-plot": "\uFEAF",
    "chart-scatter-plot-hexbin": "\uF66D",
    "chart-snakey": "\U000F020A",
    "chart-snakey-variant": "\U000F020B",
    "chart-timeline": "\uF66E",
    "chart-timeline-variant": "\uFEB0",
    "chart-tree": "\uFEB1",
    "chat": "\uFB55",
    "chat-alert": "\uFB56",
    "chat-alert-outline": "\U000F02F4",
    "chat-outline": "\uFEFB",
    "chat-processing": "\uFB57",
    "chat-processing-outline": "\U000F02F5",
    "chat-sleep": "\U000F02FC",
    "chat-sleep-outline": "\U000F02FD",
    "check": "\uF12C",
    "check-all": "\uF12D",
    "check-bold": "\uFE6E",
    "check-box-multiple-outline": "\uFC2D",
    "check-box-outline": "\uFC2E",
    "check-circle": "\uF5E0",
    "check-circle-outline": "\uF5E1",
    "check-decagram": "\uF790",
    "check-network": "\uFC2F",
    "check-network-outline": "\uFC30",
    "check-outline": "\uF854",
    "check-underline": "\uFE70",
    "check-underline-circle": "\uFE71",
    "check-underline-circle-outline": "\uFE72",
    "checkbook": "\uFA9C",
    "checkbox-blank": "\uF12E",
    "checkbox-blank-circle": "\uF12F",
    "checkbox-blank-circle-outline": "\uF130",
    "checkbox-blank-off": "\U000F0317",
    "checkbox-blank-off-outline": "\U000F0318",
    "checkbox-blank-outline": "\uF131",
    "checkbox-intermediate": "\uF855",
    "checkbox-marked": "\uF132",
    "checkbox-marked-circle": "\uF133",
    "checkbox-marked-circle-outline": "\uF134",
    "checkbox-marked-outline": "\uF135",
    "checkbox-multiple-blank": "\uF136",
    "checkbox-multiple-blank-circle": "\uF63B",
    "checkbox-multiple-blank-circle-outline": "\uF63C",
    "checkbox-multiple-blank-outline": "\uF137",
    "checkbox-multiple-marked": "\uF138",
    "checkbox-multiple-marked-circle": "\uF63D",
    "checkbox-multiple-marked-circle-outline": "\uF63E",
    "checkbox-multiple-marked-outline": "\uF139",
    "checkerboard": "\uF13A",
    "checkerboard-minus": "\U000F022D",
    "checkerboard-plus": "\U000F022C",
    "checkerboard-remove": "\U000F022E",
    "cheese": "\U000F02E4",
    "chef-hat": "\uFB58",
    "chemical-weapon": "\uF13B",
    "chess-bishop": "\uF85B",
    "chess-king": "\uF856",
    "chess-knight": "\uF857",
    "chess-pawn": "\uF858",
    "chess-queen": "\uF859",
    "chess-rook": "\uF85A",
    "chevron-double-down": "\uF13C",
    "chevron-double-left": "\uF13D",
    "chevron-double-right": "\uF13E",
    "chevron-double-up": "\uF13F",
    "chevron-down": "\uF140",
    "chevron-down-box": "\uF9D5",
    "chevron-down-box-outline": "\uF9D6",
    "chevron-down-circle": "\uFB0B",
    "chevron-down-circle-outline": "\uFB0C",
    "chevron-left": "\uF141",
    "chevron-left-box": "\uF9D7",
    "chevron-left-box-outline": "\uF9D8",
    "chevron-left-circle": "\uFB0D",
    "chevron-left-circle-outline": "\uFB0E",
    "chevron-right": "\uF142",
    "chevron-right-box": "\uF9D9",
    "chevron-right-box-outline": "\uF9DA",
    "chevron-right-circle": "\uFB0F",
    "chevron-right-circle-outline": "\uFB10",
    "chevron-triple-down": "\uFD95",
    "chevron-triple-left": "\uFD96",
    "chevron-triple-right": "\uFD97",
    "chevron-triple-up": "\uFD98",
    "chevron-up": "\uF143",
    "chevron-up-box": "\uF9DB",
    "chevron-up-box-outline": "\uF9DC",
    "chevron-up-circle": "\uFB11",
    "chevron-up-circle-outline": "\uFB12",
    "chili-hot": "\uF7B1",
    "chili-medium": "\uF7B2",
    "chili-mild": "\uF7B3",
    "chip": "\uF61A",
    "christianity": "\uF952",
    "christianity-outline": "\uFCD2",
    "church": "\uF144",
    "cigar": "\U000F01B4",
    "circle": "\uF764",
    "circle-double": "\uFEB2",
    "circle-edit-outline": "\uF8D4",
    "circle-expand": "\uFEB3",
    "circle-medium": "\uF9DD",
    "circle-off-outline": "\U000F00FE",
    "circle-outline": "\uF765",
    "circle-slice-1": "\uFA9D",
    "circle-slice-2": "\uFA9E",
    "circle-slice-3": "\uFA9F",
    "circle-slice-4": "\uFAA0",
    "circle-slice-5": "\uFAA1",
    "circle-slice-6": "\uFAA2",
    "circle-slice-7": "\uFAA3",
    "circle-slice-8": "\uFAA4",
    "circle-small": "\uF9DE",
    "circular-saw": "\uFE73",
    "cisco-webex": "\uF145",
    "city": "\uF146",
    "city-variant": "\uFA35",
    "city-variant-outline": "\uFA36",
    "clipboard": "\uF147",
    "clipboard-account": "\uF148",
    "clipboard-account-outline": "\uFC31",
    "clipboard-alert": "\uF149",
    "clipboard-alert-outline": "\uFCD3",
    "clipboard-arrow-down": "\uF14A",
    "clipboard-arrow-down-outline": "\uFC32",
    "clipboard-arrow-left": "\uF14B",
    "clipboard-arrow-left-outline": "\uFCD4",
    "clipboard-arrow-right": "\uFCD5",
    "clipboard-arrow-right-outline": "\uFCD6",
    "clipboard-arrow-up": "\uFC33",
    "clipboard-arrow-up-outline": "\uFC34",
    "clipboard-check": "\uF14C",
    "clipboard-check-multiple": "\U000F028E",
    "clipboard-check-multiple-outline": "\U000F028F",
    "clipboard-check-outline": "\uF8A7",
    "clipboard-file": "\U000F0290",
    "clipboard-file-outline": "\U000F0291",
    "clipboard-flow": "\uF6C7",
    "clipboard-flow-outline": "\U000F0142",
    "clipboard-list": "\U000F00FF",
    "clipboard-list-outline": "\U000F0100",
    "clipboard-multiple": "\U000F0292",
    "clipboard-multiple-outline": "\U000F0293",
    "clipboard-outline": "\uF14D",
    "clipboard-play": "\uFC35",
    "clipboard-play-multiple": "\U000F0294",
    "clipboard-play-multiple-outline": "\U000F0295",
    "clipboard-play-outline": "\uFC36",
    "clipboard-plus": "\uF750",
    "clipboard-plus-outline": "\U000F034A",
    "clipboard-pulse": "\uF85C",
    "clipboard-pulse-outline": "\uF85D",
    "clipboard-text": "\uF14E",
    "clipboard-text-multiple": "\U000F0296",
    "clipboard-text-multiple-outline": "\U000F0297",
    "clipboard-text-outline": "\uFA37",
    "clipboard-text-play": "\uFC37",
    "clipboard-text-play-outline": "\uFC38",
    "clippy": "\uF14F",
    "clock": "\uF953",
    "clock-alert": "\uF954",
    "clock-alert-outline": "\uF5CE",
    "clock-check": "\uFFC8",
    "clock-check-outline": "\uFFC9",
    "clock-digital": "\uFEB4",
    "clock-end": "\uF151",
    "clock-fast": "\uF152",
    "clock-in": "\uF153",
    "clock-out": "\uF154",
    "clock-outline": "\uF150",
    "clock-start": "\uF155",
    "close": "\uF156",
    "close-box": "\uF157",
    "close-box-multiple": "\uFC39",
    "close-box-multiple-outline": "\uFC3A",
    "close-box-outline": "\uF158",
    "close-circle": "\uF159",
    "close-circle-outline": "\uF15A",
    "close-network": "\uF15B",
    "close-network-outline": "\uFC3B",
    "close-octagon": "\uF15C",
    "close-octagon-outline": "\uF15D",
    "close-outline": "\uF6C8",
    "closed-caption": "\uF15E",
    "closed-caption-outline": "\uFD99",
    "cloud": "\uF15F",
    "cloud-alert": "\uF9DF",
    "cloud-braces": "\uF7B4",
    "cloud-check": "\uF160",
    "cloud-check-outline": "\U000F02F7",
    "cloud-circle": "\uF161",
    "cloud-download": "\uF162",
    "cloud-download-outline": "\uFB59",
    "cloud-lock": "\U000F021C",
    "cloud-lock-outline": "\U000F021D",
    "cloud-off-outline": "\uF164",
    "cloud-outline": "\uF163",
    "cloud-print": "\uF165",
    "cloud-print-outline": "\uF166",
    "cloud-question": "\uFA38",
    "cloud-search": "\uF955",
    "cloud-search-outline": "\uF956",
    "cloud-sync": "\uF63F",
    "cloud-sync-outline": "\U000F0301",
    "cloud-tags": "\uF7B5",
    "cloud-upload": "\uF167",
    "cloud-upload-outline": "\uFB5A",
    "clover": "\uF815",
    "coach-lamp": "\U000F0042",
    "coat-rack": "\U000F00C9",
    "code-array": "\uF168",
    "code-braces": "\uF169",
    "code-braces-box": "\U000F0101",
    "code-brackets": "\uF16A",
    "code-equal": "\uF16B",
    "code-greater-than": "\uF16C",
    "code-greater-than-or-equal": "\uF16D",
    "code-less-than": "\uF16E",
    "code-less-than-or-equal": "\uF16F",
    "code-not-equal": "\uF170",
    "code-not-equal-variant": "\uF171",
    "code-parentheses": "\uF172",
    "code-parentheses-box": "\U000F0102",
    "code-string": "\uF173",
    "code-tags": "\uF174",
    "code-tags-check": "\uF693",
    "codepen": "\uF175",
    "coffee": "\uF176",
    "coffee-maker": "\U000F00CA",
    "coffee-off": "\uFFCA",
    "coffee-off-outline": "\uFFCB",
    "coffee-outline": "\uF6C9",
    "coffee-to-go": "\uF177",
    "coffee-to-go-outline": "\U000F0339",
    "coffin": "\uFB5B",
    "cog-clockwise": "\U000F0208",
    "cog-counterclockwise": "\U000F0209",
    "cogs": "\uF8D5",
    "coin": "\U000F0196",
    "coin-outline": "\uF178",
    "coins": "\uF694",
    "collage": "\uF640",
    "collapse-all": "\uFAA5",
    "collapse-all-outline": "\uFAA6",
    "color-helper": "\uF179",
    "comma": "\uFE74",
    "comma-box": "\uFE75",
    "comma-box-outline": "\uFE76",
    "comma-circle": "\uFE77",
    "comma-circle-outline": "\uFE78",
    "comment": "\uF17A",
    "comment-account": "\uF17B",
    "comment-account-outline": "\uF17C",
    "comment-alert": "\uF17D",
    "comment-alert-outline": "\uF17E",
    "comment-arrow-left": "\uF9E0",
    "comment-arrow-left-outline": "\uF9E1",
    "comment-arrow-right": "\uF9E2",
    "comment-arrow-right-outline": "\uF9E3",
    "comment-check": "\uF17F",
    "comment-check-outline": "\uF180",
    "comment-edit": "\U000F01EA",
    "comment-edit-outline": "\U000F02EF",
    "comment-eye": "\uFA39",
    "comment-eye-outline": "\uFA3A",
    "comment-multiple": "\uF85E",
    "comment-multiple-outline": "\uF181",
    "comment-outline": "\uF182",
    "comment-plus": "\uF9E4",
    "comment-plus-outline": "\uF183",
    "comment-processing": "\uF184",
    "comment-processing-outline": "\uF185",
    "comment-question": "\uF816",
    "comment-question-outline": "\uF186",
    "comment-quote": "\U000F0043",
    "comment-quote-outline": "\U000F0044",
    "comment-remove": "\uF5DE",
    "comment-remove-outline": "\uF187",
    "comment-search": "\uFA3B",
    "comment-search-outline": "\uFA3C",
    "comment-text": "\uF188",
    "comment-text-multiple": "\uF85F",
    "comment-text-multiple-outline": "\uF860",
    "comment-text-outline": "\uF189",
    "compare": "\uF18A",
    "compass": "\uF18B",
    "compass-off": "\uFB5C",
    "compass-off-outline": "\uFB5D",
    "compass-outline": "\uF18C",
    "compass-rose": "\U000F03AD",
    "concourse-ci": "\U000F00CB",
    "console": "\uF18D",
    "console-line": "\uF7B6",
    "console-network": "\uF8A8",
    "console-network-outline": "\uFC3C",
    "consolidate": "\U000F0103",
    "contact-mail": "\uF18E",
    "contact-mail-outline": "\uFEB5",
    "contact-phone": "\uFEB6",
    "contact-phone-outline": "\uFEB7",
    "contactless-payment": "\uFD46",
    "contacts": "\uF6CA",
    "contain": "\uFA3D",
    "contain-end": "\uFA3E",
    "contain-start": "\uFA3F",
    "content-copy": "\uF18F",
    "content-cut": "\uF190",
    "content-duplicate": "\uF191",
    "content-paste": "\uF192",
    "content-save": "\uF193",
    "content-save-alert": "\uFF5F",
    "content-save-alert-outline": "\uFF60",
    "content-save-all": "\uF194",
    "content-save-all-outline": "\uFF61",
    "content-save-edit": "\uFCD7",
    "content-save-edit-outline": "\uFCD8",
    "content-save-move": "\uFE79",
    "content-save-move-outline": "\uFE7A",
    "content-save-outline": "\uF817",
    "content-save-settings": "\uF61B",
    "content-save-settings-outline": "\uFB13",
    "contrast": "\uF195",
    "contrast-box": "\uF196",
    "contrast-circle": "\uF197",
    "controller-classic": "\uFB5E",
    "controller-classic-outline": "\uFB5F",
    "cookie": "\uF198",
    "coolant-temperature": "\uF3C8",
    "copyright": "\uF5E6",
    "cordova": "\uF957",
    "corn": "\uF7B7",
    "counter": "\uF199",
    "cow": "\uF19A",
    "cowboy": "\uFEB8",
    "cpu-32-bit": "\uFEFC",
    "cpu-64-bit": "\uFEFD",
    "crane": "\uF861",
    "creation": "\uF1C9",
    "creative-commons": "\uFD47",
    "credit-card": "\U000F0010",
    "credit-card-clock": "\uFEFE",
    "credit-card-clock-outline": "\uFFBC",
    "credit-card-marker": "\uF6A7",
    "credit-card-marker-outline": "\uFD9A",
    "credit-card-minus": "\uFFCC",
    "credit-card-minus-outline": "\uFFCD",
    "credit-card-multiple": "\U000F0011",
    "credit-card-multiple-outline": "\uF19C",
    "credit-card-off": "\U000F0012",
    "credit-card-off-outline": "\uF5E4",
    "credit-card-outline": "\uF19B",
    "credit-card-plus": "\U000F0013",
    "credit-card-plus-outline": "\uF675",
    "credit-card-refund": "\U000F0014",
    "credit-card-refund-outline": "\uFAA7",
    "credit-card-remove": "\uFFCE",
    "credit-card-remove-outline": "\uFFCF",
    "credit-card-scan": "\U000F0015",
    "credit-card-scan-outline": "\uF19D",
    "credit-card-settings": "\U000F0016",
    "credit-card-settings-outline": "\uF8D6",
    "credit-card-wireless": "\uF801",
    "credit-card-wireless-outline": "\uFD48",
    "cricket": "\uFD49",
    "crop": "\uF19E",
    "crop-free": "\uF19F",
    "crop-landscape": "\uF1A0",
    "crop-portrait": "\uF1A1",
    "crop-rotate": "\uF695",
    "crop-square": "\uF1A2",
    "crosshairs": "\uF1A3",
    "crosshairs-gps": "\uF1A4",
    "crosshairs-off": "\uFF62",
    "crosshairs-question": "\U000F0161",
    "crown": "\uF1A5",
    "crown-outline": "\U000F01FB",
    "cryengine": "\uF958",
    "crystal-ball": "\uFB14",
    "cube": "\uF1A6",
    "cube-outline": "\uF1A7",
    "cube-scan": "\uFB60",
    "cube-send": "\uF1A8",
    "cube-unfolded": "\uF1A9",
    "cup": "\uF1AA",
    "cup-off": "\uF5E5",
    "cup-off-outline": "\U000F03A8",
    "cup-outline": "\U000F033A",
    "cup-water": "\uF1AB",
    "cupboard": "\uFF63",
    "cupboard-outline": "\uFF64",
    "cupcake": "\uF959",
    "curling": "\uF862",
    "currency-bdt": "\uF863",
    "currency-brl": "\uFB61",
    "currency-btc": "\uF1AC",
    "currency-cny": "\uF7B9",
    "currency-eth": "\uF7BA",
    "currency-eur": "\uF1AD",
    "currency-eur-off": "\U000F0340",
    "currency-gbp": "\uF1AE",
    "currency-ils": "\uFC3D",
    "currency-inr": "\uF1AF",
    "currency-jpy": "\uF7BB",
    "currency-krw": "\uF7BC",
    "currency-kzt": "\uF864",
    "currency-ngn": "\uF1B0",
    "currency-php": "\uF9E5",
    "currency-rial": "\uFEB9",
    "currency-rub": "\uF1B1",
    "currency-sign": "\uF7BD",
    "currency-try": "\uF1B2",
    "currency-twd": "\uF7BE",
    "currency-usd": "\uF1B3",
    "currency-usd-off": "\uF679",
    "current-ac": "\uF95A",
    "current-dc": "\uF95B",
    "cursor-default": "\uF1B4",
    "cursor-default-click": "\uFCD9",
    "cursor-default-click-outline": "\uFCDA",
    "cursor-default-gesture": "\U000F0152",
    "cursor-default-gesture-outline": "\U000F0153",
    "cursor-default-outline": "\uF1B5",
    "cursor-move": "\uF1B6",
    "cursor-pointer": "\uF1B7",
    "cursor-text": "\uF5E7",
    "database": "\uF1B8",
    "database-check": "\uFAA8",
    "database-edit": "\uFB62",
    "database-export": "\uF95D",
    "database-import": "\uF95C",
    "database-lock": "\uFAA9",
    "database-marker": "\U000F0321",
    "database-minus": "\uF1B9",
    "database-plus": "\uF1BA",
    "database-refresh": "\uFCDB",
    "database-remove": "\uFCDC",
    "database-search": "\uF865",
    "database-settings": "\uFCDD",
    "death-star": "\uF8D7",
    "death-star-variant": "\uF8D8",
    "deathly-hallows": "\uFB63",
    "debian": "\uF8D9",
    "debug-step-into": "\uF1BB",
    "debug-step-out": "\uF1BC",
    "debug-step-over": "\uF1BD",
    "decagram": "\uF76B",
    "decagram-outline": "\uF76C",
    "decimal": "\U000F00CC",
    "decimal-comma": "\U000F00CD",
    "decimal-comma-decrease": "\U000F00CE",
    "decimal-comma-increase": "\U000F00CF",
    "decimal-decrease": "\uF1BE",
    "decimal-increase": "\uF1BF",
    "delete": "\uF1C0",
    "delete-alert": "\U000F00D0",
    "delete-alert-outline": "\U000F00D1",
    "delete-circle": "\uF682",
    "delete-circle-outline": "\uFB64",
    "delete-empty": "\uF6CB",
    "delete-empty-outline": "\uFEBA",
    "delete-forever": "\uF5E8",
    "delete-forever-outline": "\uFB65",
    "delete-off": "\U000F00D2",
    "delete-off-outline": "\U000F00D3",
    "delete-outline": "\uF9E6",
    "delete-restore": "\uF818",
    "delete-sweep": "\uF5E9",
    "delete-sweep-outline": "\uFC3E",
    "delete-variant": "\uF1C1",
    "delta": "\uF1C2",
    "desk": "\U000F0264",
    "desk-lamp": "\uF95E",
    "deskphone": "\uF1C3",
    "desktop-classic": "\uF7BF",
    "desktop-mac": "\uF1C4",
    "desktop-mac-dashboard": "\uF9E7",
    "desktop-tower": "\uF1C5",
    "desktop-tower-monitor": "\uFAAA",
    "details": "\uF1C6",
    "dev-to": "\uFD4A",
    "developer-board": "\uF696",
    "deviantart": "\uF1C7",
    "devices": "\uFFD0",
    "diabetes": "\U000F0151",
    "dialpad": "\uF61C",
    "diameter": "\uFC3F",
    "diameter-outline": "\uFC40",
    "diameter-variant": "\uFC41",
    "diamond": "\uFB66",
    "diamond-outline": "\uFB67",
    "diamond-stone": "\uF1C8",
    "dice-1": "\uF1CA",
    "dice-1-outline": "\U000F0175",
    "dice-2": "\uF1CB",
    "dice-2-outline": "\U000F0176",
    "dice-3": "\uF1CC",
    "dice-3-outline": "\U000F0177",
    "dice-4": "\uF1CD",
    "dice-4-outline": "\U000F0178",
    "dice-5": "\uF1CE",
    "dice-5-outline": "\U000F0179",
    "dice-6": "\uF1CF",
    "dice-6-outline": "\U000F017A",
    "dice-d10": "\U000F017E",
    "dice-d10-outline": "\uF76E",
    "dice-d12": "\U000F017F",
    "dice-d12-outline": "\uF866",
    "dice-d20": "\U000F0180",
    "dice-d20-outline": "\uF5EA",
    "dice-d4": "\U000F017B",
    "dice-d4-outline": "\uF5EB",
    "dice-d6": "\U000F017C",
    "dice-d6-outline": "\uF5EC",
    "dice-d8": "\U000F017D",
    "dice-d8-outline": "\uF5ED",
    "dice-multiple": "\uF76D",
    "dice-multiple-outline": "\U000F0181",
    "dictionary": "\uF61D",
    "digital-ocean": "\U000F0262",
    "dip-switch": "\uF7C0",
    "directions": "\uF1D0",
    "directions-fork": "\uF641",
    "disc": "\uF5EE",
    "disc-alert": "\uF1D1",
    "disc-player": "\uF95F",
    "discord": "\uF66F",
    "dishwasher": "\uFAAB",
    "dishwasher-alert": "\U000F01E3",
    "dishwasher-off": "\U000F01E4",
    "disqus": "\uF1D2",
    "disqus-outline": "\uF1D3",
    "distribute-horizontal-center": "\U000F01F4",
    "distribute-horizontal-left": "\U000F01F3",
    "distribute-horizontal-right": "\U000F01F5",
    "distribute-vertical-bottom": "\U000F01F6",
    "distribute-vertical-center": "\U000F01F7",
    "distribute-vertical-top": "\U000F01F8",
    "diving-flippers": "\uFD9B",
    "diving-helmet": "\uFD9C",
    "diving-scuba": "\uFD9D",
    "diving-scuba-flag": "\uFD9E",
    "diving-scuba-tank": "\uFD9F",
    "diving-scuba-tank-multiple": "\uFDA0",
    "diving-snorkel": "\uFDA1",
    "division": "\uF1D4",
    "division-box": "\uF1D5",
    "dlna": "\uFA40",
    "dna": "\uF683",
    "dns": "\uF1D6",
    "dns-outline": "\uFB68",
    "do-not-disturb": "\uF697",
    "do-not-disturb-off": "\uF698",
    "dock-bottom": "\U000F00D4",
    "dock-left": "\U000F00D5",
    "dock-right": "\U000F00D6",
    "dock-window": "\U000F00D7",
    "docker": "\uF867",
    "doctor": "\uFA41",
    "dog": "\uFA42",
    "dog-service": "\uFAAC",
    "dog-side": "\uFA43",
    "dolby": "\uF6B2",
    "dolly": "\uFEBB",
    "domain": "\uF1D7",
    "domain-off": "\uFD4B",
    "domain-plus": "\U000F00D8",
    "domain-remove": "\U000F00D9",
    "domino-mask": "\U000F0045",
    "donkey": "\uF7C1",
    "door": "\uF819",
    "door-closed": "\uF81A",
    "door-closed-lock": "\U000F00DA",
    "door-open": "\uF81B",
    "doorbell": "\U000F0311",
    "doorbell-video": "\uF868",
    "dot-net": "\uFAAD",
    "dots-horizontal": "\uF1D8",
    "dots-horizontal-circle": "\uF7C2",
    "dots-horizontal-circle-outline": "\uFB69",
    "dots-vertical": "\uF1D9",
    "dots-vertical-circle": "\uF7C3",
    "dots-vertical-circle-outline": "\uFB6A",
    "douban": "\uF699",
    "download": "\uF1DA",
    "download-lock": "\U000F034B",
    "download-lock-outline": "\U000F034C",
    "download-multiple": "\uF9E8",
    "download-network": "\uF6F3",
    "download-network-outline": "\uFC42",
    "download-off": "\U000F00DB",
    "download-off-outline": "\U000F00DC",
    "download-outline": "\uFB6B",
    "drag": "\uF1DB",
    "drag-horizontal": "\uF1DC",
    "drag-horizontal-variant": "\U000F031B",
    "drag-variant": "\uFB6C",
    "drag-vertical": "\uF1DD",
    "drag-vertical-variant": "\U000F031C",
    "drama-masks": "\uFCDE",
    "draw": "\uFF66",
    "drawing": "\uF1DE",
    "drawing-box": "\uF1DF",
    "dresser": "\uFF67",
    "dresser-outline": "\uFF68",
    "dribbble": "\uF1E0",
    "dribbble-box": "\uF1E1",
    "drone": "\uF1E2",
    "dropbox": "\uF1E3",
    "drupal": "\uF1E4",
    "duck": "\uF1E5",
    "dumbbell": "\uF1E6",
    "dump-truck": "\uFC43",
    "ear-hearing": "\uF7C4",
    "ear-hearing-off": "\uFA44",
    "earth": "\uF1E7",
    "earth-arrow-right": "\U000F033C",
    "earth-box": "\uF6CC",
    "earth-box-off": "\uF6CD",
    "earth-off": "\uF1E8",
    "edge": "\uF1E9",
    "edge-legacy": "\U000F027B",
    "egg": "\uFAAE",
    "egg-easter": "\uFAAF",
    "eight-track": "\uF9E9",
    "eject": "\uF1EA",
    "eject-outline": "\uFB6D",
    "electric-switch": "\uFEBC",
    "electric-switch-closed": "\U000F0104",
    "electron-framework": "\U000F0046",
    "elephant": "\uF7C5",
    "elevation-decline": "\uF1EB",
    "elevation-rise": "\uF1EC",
    "elevator": "\uF1ED",
    "elevator-down": "\U000F02ED",
    "elevator-passenger": "\U000F03AC",
    "elevator-up": "\U000F02EC",
    "ellipse": "\uFEBD",
    "ellipse-outline": "\uFEBE",
    "email": "\uF1EE",
    "email-alert": "\uF6CE",
    "email-alert-outline": "\uFD1E",
    "email-box": "\uFCDF",
    "email-check": "\uFAB0",
    "email-check-outline": "\uFAB1",
    "email-edit": "\uFF00",
    "email-edit-outline": "\uFF01",
    "email-lock": "\uF1F1",
    "email-mark-as-unread": "\uFB6E",
    "email-minus": "\uFF02",
    "email-minus-outline": "\uFF03",
    "email-multiple": "\uFF04",
    "email-multiple-outline": "\uFF05",
    "email-newsletter": "\uFFD1",
    "email-open": "\uF1EF",
    "email-open-multiple": "\uFF06",
    "email-open-multiple-outline": "\uFF07",
    "email-open-outline": "\uF5EF",
    "email-outline": "\uF1F0",
    "email-plus": "\uF9EA",
    "email-plus-outline": "\uF9EB",
    "email-receive": "\U000F0105",
    "email-receive-outline": "\U000F0106",
    "email-search": "\uF960",
    "email-search-outline": "\uF961",
    "email-send": "\U000F0107",
    "email-send-outline": "\U000F0108",
    "email-sync": "\U000F02F2",
    "email-sync-outline": "\U000F02F3",
    "email-variant": "\uF5F0",
    "ember": "\uFB15",
    "emby": "\uF6B3",
    "emoticon": "\uFC44",
    "emoticon-angry": "\uFC45",
    "emoticon-angry-outline": "\uFC46",
    "emoticon-confused": "\U000F0109",
    "emoticon-confused-outline": "\U000F010A",
    "emoticon-cool": "\uFC47",
    "emoticon-cool-outline": "\uF1F3",
    "emoticon-cry": "\uFC48",
    "emoticon-cry-outline": "\uFC49",
    "emoticon-dead": "\uFC4A",
    "emoticon-dead-outline": "\uF69A",
    "emoticon-devil": "\uFC4B",
    "emoticon-devil-outline": "\uF1F4",
    "emoticon-excited": "\uFC4C",
    "emoticon-excited-outline": "\uF69B",
    "emoticon-frown": "\uFF69",
    "emoticon-frown-outline": "\uFF6A",
    "emoticon-happy": "\uFC4D",
    "emoticon-happy-outline": "\uF1F5",
    "emoticon-kiss": "\uFC4E",
    "emoticon-kiss-outline": "\uFC4F",
    "emoticon-lol": "\U000F023F",
    "emoticon-lol-outline": "\U000F0240",
    "emoticon-neutral": "\uFC50",
    "emoticon-neutral-outline": "\uF1F6",
    "emoticon-outline": "\uF1F2",
    "emoticon-poop": "\uF1F7",
    "emoticon-poop-outline": "\uFC51",
    "emoticon-sad": "\uFC52",
    "emoticon-sad-outline": "\uF1F8",
    "emoticon-tongue": "\uF1F9",
    "emoticon-tongue-outline": "\uFC53",
    "emoticon-wink": "\uFC54",
    "emoticon-wink-outline": "\uFC55",
    "engine": "\uF1FA",
    "engine-off": "\uFA45",
    "engine-off-outline": "\uFA46",
    "engine-outline": "\uF1FB",
    "epsilon": "\U000F010B",
    "equal": "\uF1FC",
    "equal-box": "\uF1FD",
    "equalizer": "\uFEBF",
    "equalizer-outline": "\uFEC0",
    "eraser": "\uF1FE",
    "eraser-variant": "\uF642",
    "escalator": "\uF1FF",
    "escalator-down": "\U000F02EB",
    "escalator-up": "\U000F02EA",
    "eslint": "\uFC56",
    "et": "\uFAB2",
    "ethereum": "\uF869",
    "ethernet": "\uF200",
    "ethernet-cable": "\uF201",
    "ethernet-cable-off": "\uF202",
    "etsy": "\uF203",
    "ev-station": "\uF5F1",
    "eventbrite": "\uF7C6",
    "evernote": "\uF204",
    "excavator": "\U000F0047",
    "exclamation": "\uF205",
    "exclamation-thick": "\U000F0263",
    "exit-run": "\uFA47",
    "exit-to-app": "\uF206",
    "expand-all": "\uFAB3",
    "expand-all-outline": "\uFAB4",
    "expansion-card": "\uF8AD",
    "expansion-card-variant": "\uFFD2",
    "exponent": "\uF962",
    "exponent-box": "\uF963",
    "export": "\uF207",
    "export-variant": "\uFB6F",
    "eye": "\uF208",
    "eye-check": "\uFCE0",
    "eye-check-outline": "\uFCE1",
    "eye-circle": "\uFB70",
    "eye-circle-outline": "\uFB71",
    "eye-minus": "\U000F0048",
    "eye-minus-outline": "\U000F0049",
    "eye-off": "\uF209",
    "eye-off-outline": "\uF6D0",
    "eye-outline": "\uF6CF",
    "eye-plus": "\uF86A",
    "eye-plus-outline": "\uF86B",
    "eye-settings": "\uF86C",
    "eye-settings-outline": "\uF86D",
    "eyedropper": "\uF20A",
    "eyedropper-variant": "\uF20B",
    "face": "\uF643",
    "face-agent": "\uFD4C",
    "face-outline": "\uFB72",
    "face-profile": "\uF644",
    "face-profile-woman": "\U000F00A1",
    "face-recognition": "\uFC57",
    "face-woman": "\U000F00A2",
    "face-woman-outline": "\U000F00A3",
    "facebook": "\uF20C",
    "facebook-box": "\uF20D",
    "facebook-messenger": "\uF20E",
    "facebook-workplace": "\uFB16",
    "factory": "\uF20F",
    "fan": "\uF210",
    "fan-off": "\uF81C",
    "fast-forward": "\uF211",
    "fast-forward-10": "\uFD4D",
    "fast-forward-30": "\uFCE2",
    "fast-forward-5": "\U000F0223",
    "fast-forward-outline": "\uF6D1",
    "fax": "\uF212",
    "feather": "\uF6D2",
    "feature-search": "\uFA48",
    "feature-search-outline": "\uFA49",
    "fedora": "\uF8DA",
    "ferris-wheel": "\uFEC1",
    "ferry": "\uF213",
    "file": "\uF214",
    "file-account": "\uF73A",
    "file-account-outline": "\U000F004A",
    "file-alert": "\uFA4A",
    "file-alert-outline": "\uFA4B",
    "file-cabinet": "\uFAB5",
    "file-cad": "\uFF08",
    "file-cad-box": "\uFF09",
    "file-cancel": "\uFDA2",
    "file-cancel-outline": "\uFDA3",
    "file-certificate": "\U000F01B1",
    "file-certificate-outline": "\U000F01B2",
    "file-chart": "\uF215",
    "file-chart-outline": "\U000F004B",
    "file-check": "\uF216",
    "file-check-outline": "\uFE7B",
    "file-clock": "\U000F030C",
    "file-clock-outline": "\U000F030D",
    "file-cloud": "\uF217",
    "file-cloud-outline": "\U000F004C",
    "file-code": "\uF22E",
    "file-code-outline": "\U000F004D",
    "file-compare": "\uF8A9",
    "file-delimited": "\uF218",
    "file-delimited-outline": "\uFEC2",
    "file-document": "\uF219",
    "file-document-box": "\uF21A",
    "file-document-box-check": "\uFEC3",
    "file-document-box-check-outline": "\uFEC4",
    "file-document-box-minus": "\uFEC5",
    "file-document-box-minus-outline": "\uFEC6",
    "file-document-box-multiple": "\uFAB6",
    "file-document-box-multiple-outline": "\uFAB7",
    "file-document-box-outline": "\uF9EC",
    "file-document-box-plus": "\uFEC7",
    "file-document-box-plus-outline": "\uFEC8",
    "file-document-box-remove": "\uFEC9",
    "file-document-box-remove-outline": "\uFECA",
    "file-document-box-search": "\uFECB",
    "file-document-box-search-outline": "\uFECC",
    "file-document-edit": "\uFDA4",
    "file-document-edit-outline": "\uFDA5",
    "file-document-outline": "\uF9ED",
    "file-download": "\uF964",
    "file-download-outline": "\uF965",
    "file-edit": "\U000F0212",
    "file-edit-outline": "\U000F0213",
    "file-excel": "\uF21B",
    "file-excel-box": "\uF21C",
    "file-excel-box-outline": "\U000F004E",
    "file-excel-outline": "\U000F004F",
    "file-export": "\uF21D",
    "file-export-outline": "\U000F0050",
    "file-eye": "\uFDA6",
    "file-eye-outline": "\uFDA7",
    "file-find": "\uF21E",
    "file-find-outline": "\uFB73",
    "file-hidden": "\uF613",
    "file-image": "\uF21F",
    "file-image-outline": "\uFECD",
    "file-import": "\uF220",
    "file-import-outline": "\U000F0051",
    "file-key": "\U000F01AF",
    "file-key-outline": "\U000F01B0",
    "file-link": "\U000F01A2",
    "file-link-outline": "\U000F01A3",
    "file-lock": "\uF221",
    "file-lock-outline": "\U000F0052",
    "file-move": "\uFAB8",
    "file-move-outline": "\U000F0053",
    "file-multiple": "\uF222",
    "file-multiple-outline": "\U000F0054",
    "file-music": "\uF223",
    "file-music-outline": "\uFE7C",
    "file-outline": "\uF224",
    "file-pdf": "\uF225",
    "file-pdf-box": "\uF226",
    "file-pdf-box-outline": "\uFFD3",
    "file-pdf-outline": "\uFE7D",
    "file-percent": "\uF81D",
    "file-percent-outline": "\U000F0055",
    "file-phone": "\U000F01A4",
    "file-phone-outline": "\U000F01A5",
    "file-plus": "\uF751",
    "file-plus-outline": "\uFF0A",
    "file-powerpoint": "\uF227",
    "file-powerpoint-box": "\uF228",
    "file-powerpoint-box-outline": "\U000F0056",
    "file-powerpoint-outline": "\U000F0057",
    "file-presentation-box": "\uF229",
    "file-question": "\uF86E",
    "file-question-outline": "\U000F0058",
    "file-remove": "\uFB74",
    "file-remove-outline": "\U000F0059",
    "file-replace": "\uFB17",
    "file-replace-outline": "\uFB18",
    "file-restore": "\uF670",
    "file-restore-outline": "\U000F005A",
    "file-search": "\uFC58",
    "file-search-outline": "\uFC59",
    "file-send": "\uF22A",
    "file-send-outline": "\U000F005B",
    "file-settings": "\U000F00A4",
    "file-settings-outline": "\U000F00A5",
    "file-settings-variant": "\U000F00A6",
    "file-settings-variant-outline": "\U000F00A7",
    "file-star": "\U000F005C",
    "file-star-outline": "\U000F005D",
    "file-swap": "\uFFD4",
    "file-swap-outline": "\uFFD5",
    "file-sync": "\U000F0241",
    "file-sync-outline": "\U000F0242",
    "file-table": "\uFC5A",
    "file-table-box": "\U000F010C",
    "file-table-box-multiple": "\U000F010D",
    "file-table-box-multiple-outline": "\U000F010E",
    "file-table-box-outline": "\U000F010F",
    "file-table-outline": "\uFC5B",
    "file-tree": "\uF645",
    "file-undo": "\uF8DB",
    "file-undo-outline": "\U000F005E",
    "file-upload": "\uFA4C",
    "file-upload-outline": "\uFA4D",
    "file-video": "\uF22B",
    "file-video-outline": "\uFE10",
    "file-word": "\uF22C",
    "file-word-box": "\uF22D",
    "file-word-box-outline": "\U000F005F",
    "file-word-outline": "\U000F0060",
    "film": "\uF22F",
    "filmstrip": "\uF230",
    "filmstrip-off": "\uF231",
    "filter": "\uF232",
    "filter-menu": "\U000F0110",
    "filter-menu-outline": "\U000F0111",
    "filter-minus": "\uFF0B",
    "filter-minus-outline": "\uFF0C",
    "filter-outline": "\uF233",
    "filter-plus": "\uFF0D",
    "filter-plus-outline": "\uFF0E",
    "filter-remove": "\uF234",
    "filter-remove-outline": "\uF235",
    "filter-variant": "\uF236",
    "filter-variant-minus": "\U000F013D",
    "filter-variant-plus": "\U000F013E",
    "filter-variant-remove": "\U000F0061",
    "finance": "\uF81E",
    "find-replace": "\uF6D3",
    "fingerprint": "\uF237",
    "fingerprint-off": "\uFECE",
    "fire": "\uF238",
    "fire-extinguisher": "\uFF0F",
    "fire-hydrant": "\U000F0162",
    "fire-hydrant-alert": "\U000F0163",
    "fire-hydrant-off": "\U000F0164",
    "fire-truck": "\uF8AA",
    "firebase": "\uF966",
    "firefox": "\uF239",
    "fireplace": "\uFE11",
    "fireplace-off": "\uFE12",
    "firework": "\uFE13",
    "fish": "\uF23A",
    "fishbowl": "\uFF10",
    "fishbowl-outline": "\uFF11",
    "fit-to-page": "\uFF12",
    "fit-to-page-outline": "\uFF13",
    "flag": "\uF23B",
    "flag-checkered": "\uF23C",
    "flag-minus": "\uFB75",
    "flag-minus-outline": "\U000F00DD",
    "flag-outline": "\uF23D",
    "flag-plus": "\uFB76",
    "flag-plus-outline": "\U000F00DE",
    "flag-remove": "\uFB77",
    "flag-remove-outline": "\U000F00DF",
    "flag-triangle": "\uF23F",
    "flag-variant": "\uF240",
    "flag-variant-outline": "\uF23E",
    "flare": "\uFD4E",
    "flash": "\uF241",
    "flash-alert": "\uFF14",
    "flash-alert-outline": "\uFF15",
    "flash-auto": "\uF242",
    "flash-circle": "\uF81F",
    "flash-off": "\uF243",
    "flash-outline": "\uF6D4",
    "flash-red-eye": "\uF67A",
    "flashlight": "\uF244",
    "flashlight-off": "\uF245",
    "flask": "\uF093",
    "flask-empty": "\uF094",
    "flask-empty-minus": "\U000F0265",
    "flask-empty-minus-outline": "\U000F0266",
    "flask-empty-outline": "\uF095",
    "flask-empty-plus": "\U000F0267",
    "flask-empty-plus-outline": "\U000F0268",
    "flask-empty-remove": "\U000F0269",
    "flask-empty-remove-outline": "\U000F026A",
    "flask-minus": "\U000F026B",
    "flask-minus-outline": "\U000F026C",
    "flask-outline": "\uF096",
    "flask-plus": "\U000F026D",
    "flask-plus-outline": "\U000F026E",
    "flask-remove": "\U000F026F",
    "flask-remove-outline": "\U000F0270",
    "flask-round-bottom": "\U000F0276",
    "flask-round-bottom-empty": "\U000F0277",
    "flask-round-bottom-empty-outline": "\U000F0278",
    "flask-round-bottom-outline": "\U000F0279",
    "flattr": "\uF246",
    "fleur-de-lis": "\U000F032E",
    "flickr": "\uFCE3",
    "flip-horizontal": "\U000F0112",
    "flip-to-back": "\uF247",
    "flip-to-front": "\uF248",
    "flip-vertical": "\U000F0113",
    "floor-lamp": "\uF8DC",
    "floor-lamp-dual": "\U000F0062",
    "floor-lamp-variant": "\U000F0063",
    "floor-plan": "\uF820",
    "floppy": "\uF249",
    "floppy-variant": "\uF9EE",
    "flower": "\uF24A",
    "flower-outline": "\uF9EF",
    "flower-poppy": "\uFCE4",
    "flower-tulip": "\uF9F0",
    "flower-tulip-outline": "\uF9F1",
    "focus-auto": "\uFF6B",
    "focus-field": "\uFF6C",
    "focus-field-horizontal": "\uFF6D",
    "focus-field-vertical": "\uFF6E",
    "folder": "\uF24B",
    "folder-account": "\uF24C",
    "folder-account-outline": "\uFB78",
    "folder-alert": "\uFDA8",
    "folder-alert-outline": "\uFDA9",
    "folder-clock": "\uFAB9",
    "folder-clock-outline": "\uFABA",
    "folder-download": "\uF24D",
    "folder-download-outline": "\U000F0114",
    "folder-edit": "\uF8DD",
    "folder-edit-outline": "\uFDAA",
    "folder-google-drive": "\uF24E",
    "folder-heart": "\U000F0115",
    "folder-heart-outline": "\U000F0116",
    "folder-home": "\U000F00E0",
    "folder-home-outline": "\U000F00E1",
    "folder-image": "\uF24F",
    "folder-information": "\U000F00E2",
    "folder-information-outline": "\U000F00E3",
    "folder-key": "\uF8AB",
    "folder-key-network": "\uF8AC",
    "folder-key-network-outline": "\uFC5C",
    "folder-key-outline": "\U000F0117",
    "folder-lock": "\uF250",
    "folder-lock-open": "\uF251",
    "folder-marker": "\U000F0298",
    "folder-marker-outline": "\U000F0299",
    "folder-move": "\uF252",
    "folder-move-outline": "\U000F0271",
    "folder-multiple": "\uF253",
    "folder-multiple-image": "\uF254",
    "folder-multiple-outline": "\uF255",
    "folder-music": "\U000F0384",
    "folder-music-outline": "\U000F0385",
    "folder-network": "\uF86F",
    "folder-network-outline": "\uFC5D",
    "folder-open": "\uF76F",
    "folder-open-outline": "\uFDAB",
    "folder-outline": "\uF256",
    "folder-plus": "\uF257",
    "folder-plus-outline": "\uFB79",
    "folder-pound": "\uFCE5",
    "folder-pound-outline": "\uFCE6",
    "folder-remove": "\uF258",
    "folder-remove-outline": "\uFB7A",
    "folder-search": "\uF967",
    "folder-search-outline": "\uF968",
    "folder-settings": "\U000F00A8",
    "folder-settings-outline": "\U000F00A9",
    "folder-settings-variant": "\U000F00AA",
    "folder-settings-variant-outline": "\U000F00AB",
    "folder-star": "\uF69C",
    "folder-star-outline": "\uFB7B",
    "folder-swap": "\uFFD6",
    "folder-swap-outline": "\uFFD7",
    "folder-sync": "\uFCE7",
    "folder-sync-outline": "\uFCE8",
    "folder-table": "\U000F030E",
    "folder-table-outline": "\U000F030F",
    "folder-text": "\uFC5E",
    "folder-text-outline": "\uFC5F",
    "folder-upload": "\uF259",
    "folder-upload-outline": "\U000F0118",
    "folder-zip": "\uF6EA",
    "folder-zip-outline": "\uF7B8",
    "font-awesome": "\uF03A",
    "food": "\uF25A",
    "food-apple": "\uF25B",
    "food-apple-outline": "\uFC60",
    "food-croissant": "\uF7C7",
    "food-fork-drink": "\uF5F2",
    "food-off": "\uF5F3",
    "food-variant": "\uF25C",
    "foot-print": "\uFF6F",
    "football": "\uF25D",
    "football-australian": "\uF25E",
    "football-helmet": "\uF25F",
    "forklift": "\uF7C8",
    "format-align-bottom": "\uF752",
    "format-align-center": "\uF260",
    "format-align-justify": "\uF261",
    "format-align-left": "\uF262",
    "format-align-middle": "\uF753",
    "format-align-right": "\uF263",
    "format-align-top": "\uF754",
    "format-annotation-minus": "\uFABB",
    "format-annotation-plus": "\uF646",
    "format-bold": "\uF264",
    "format-clear": "\uF265",
    "format-color-fill": "\uF266",
    "format-color-highlight": "\uFE14",
    "format-color-marker-cancel": "\U000F033E",
    "format-color-text": "\uF69D",
    "format-columns": "\uF8DE",
    "format-float-center": "\uF267",
    "format-float-left": "\uF268",
    "format-float-none": "\uF269",
    "format-float-right": "\uF26A",
    "format-font": "\uF6D5",
    "format-font-size-decrease": "\uF9F2",
    "format-font-size-increase": "\uF9F3",
    "format-header-1": "\uF26B",
    "format-header-2": "\uF26C",
    "format-header-3": "\uF26D",
    "format-header-4": "\uF26E",
    "format-header-5": "\uF26F",
    "format-header-6": "\uF270",
    "format-header-decrease": "\uF271",
    "format-header-equal": "\uF272",
    "format-header-increase": "\uF273",
    "format-header-pound": "\uF274",
    "format-horizontal-align-center": "\uF61E",
    "format-horizontal-align-left": "\uF61F",
    "format-horizontal-align-right": "\uF620",
    "format-indent-decrease": "\uF275",
    "format-indent-increase": "\uF276",
    "format-italic": "\uF277",
    "format-letter-case": "\uFB19",
    "format-letter-case-lower": "\uFB1A",
    "format-letter-case-upper": "\uFB1B",
    "format-letter-ends-with": "\uFFD8",
    "format-letter-matches": "\uFFD9",
    "format-letter-starts-with": "\uFFDA",
    "format-line-spacing": "\uF278",
    "format-line-style": "\uF5C8",
    "format-line-weight": "\uF5C9",
    "format-list-bulleted": "\uF279",
    "format-list-bulleted-square": "\uFDAC",
    "format-list-bulleted-triangle": "\uFECF",
    "format-list-bulleted-type": "\uF27A",
    "format-list-checkbox": "\uF969",
    "format-list-checks": "\uF755",
    "format-list-numbered": "\uF27B",
    "format-list-numbered-rtl": "\uFCE9",
    "format-list-text": "\U000F029A",
    "format-overline": "\uFED0",
    "format-page-break": "\uF6D6",
    "format-paint": "\uF27C",
    "format-paragraph": "\uF27D",
    "format-pilcrow": "\uF6D7",
    "format-quote-close": "\uF27E",
    "format-quote-close-outline": "\U000F01D3",
    "format-quote-open": "\uF756",
    "format-quote-open-outline": "\U000F01D2",
    "format-rotate-90": "\uF6A9",
    "format-section": "\uF69E",
    "format-size": "\uF27F",
    "format-strikethrough": "\uF280",
    "format-strikethrough-variant": "\uF281",
    "format-subscript": "\uF282",
    "format-superscript": "\uF283",
    "format-text": "\uF284",
    "format-text-rotation-angle-down": "\uFFDB",
    "format-text-rotation-angle-up": "\uFFDC",
    "format-text-rotation-down": "\uFD4F",
    "format-text-rotation-down-vertical": "\uFFDD",
    "format-text-rotation-none": "\uFD50",
    "format-text-rotation-up": "\uFFDE",
    "format-text-rotation-vertical": "\uFFDF",
    "format-text-variant": "\uFE15",
    "format-text-wrapping-clip": "\uFCEA",
    "format-text-wrapping-overflow": "\uFCEB",
    "format-text-wrapping-wrap": "\uFCEC",
    "format-textbox": "\uFCED",
    "format-textdirection-l-to-r": "\uF285",
    "format-textdirection-r-to-l": "\uF286",
    "format-title": "\uF5F4",
    "format-underline": "\uF287",
    "format-vertical-align-bottom": "\uF621",
    "format-vertical-align-center": "\uF622",
    "format-vertical-align-top": "\uF623",
    "format-wrap-inline": "\uF288",
    "format-wrap-square": "\uF289",
    "format-wrap-tight": "\uF28A",
    "format-wrap-top-bottom": "\uF28B",
    "forum": "\uF28C",
    "forum-outline": "\uF821",
    "forward": "\uF28D",
    "forwardburger": "\uFD51",
    "fountain": "\uF96A",
    "fountain-pen": "\uFCEE",
    "fountain-pen-tip": "\uFCEF",
    "foursquare": "\uF28E",
    "freebsd": "\uF8DF",
    "frequently-asked-questions": "\uFED1",
    "fridge": "\uF290",
    "fridge-alert": "\U000F01DC",
    "fridge-alert-outline": "\U000F01DD",
    "fridge-bottom": "\uF292",
    "fridge-off": "\U000F01DA",
    "fridge-off-outline": "\U000F01DB",
    "fridge-outline": "\uF28F",
    "fridge-top": "\uF291",
    "fruit-cherries": "\U000F0064",
    "fruit-citrus": "\U000F0065",
    "fruit-grapes": "\U000F0066",
    "fruit-grapes-outline": "\U000F0067",
    "fruit-pineapple": "\U000F0068",
    "fruit-watermelon": "\U000F0069",
    "fuel": "\uF7C9",
    "fullscreen": "\uF293",
    "fullscreen-exit": "\uF294",
    "function": "\uF295",
    "function-variant": "\uF870",
    "furigana-horizontal": "\U000F00AC",
    "furigana-vertical": "\U000F00AD",
    "fuse": "\uFC61",
    "fuse-blade": "\uFC62",
    "gamepad": "\uF296",
    "gamepad-circle": "\uFE16",
    "gamepad-circle-down": "\uFE17",
    "gamepad-circle-left": "\uFE18",
    "gamepad-circle-outline": "\uFE19",
    "gamepad-circle-right": "\uFE1A",
    "gamepad-circle-up": "\uFE1B",
    "gamepad-down": "\uFE1C",
    "gamepad-left": "\uFE1D",
    "gamepad-right": "\uFE1E",
    "gamepad-round": "\uFE1F",
    "gamepad-round-down": "\uFE7E",
    "gamepad-round-left": "\uFE7F",
    "gamepad-round-outline": "\uFE80",
    "gamepad-round-right": "\uFE81",
    "gamepad-round-up": "\uFE82",
    "gamepad-square": "\uFED2",
    "gamepad-square-outline": "\uFED3",
    "gamepad-up": "\uFE83",
    "gamepad-variant": "\uF297",
    "gamepad-variant-outline": "\uFED4",
    "gamma": "\U000F0119",
    "gantry-crane": "\uFDAD",
    "garage": "\uF6D8",
    "garage-alert": "\uF871",
    "garage-alert-variant": "\U000F0300",
    "garage-open": "\uF6D9",
    "garage-open-variant": "\U000F02FF",
    "garage-variant": "\U000F02FE",
    "gas-cylinder": "\uF647",
    "gas-station": "\uF298",
    "gas-station-outline": "\uFED5",
    "gate": "\uF299",
    "gate-and": "\uF8E0",
    "gate-arrow-right": "\U000F0194",
    "gate-nand": "\uF8E1",
    "gate-nor": "\uF8E2",
    "gate-not": "\uF8E3",
    "gate-open": "\U000F0195",
    "gate-or": "\uF8E4",
    "gate-xnor": "\uF8E5",
    "gate-xor": "\uF8E6",
    "gatsby": "\uFE84",
    "gauge": "\uF29A",
    "gauge-empty": "\uF872",
    "gauge-full": "\uF873",
    "gauge-low": "\uF874",
    "gavel": "\uF29B",
    "gender-female": "\uF29C",
    "gender-male": "\uF29D",
    "gender-male-female": "\uF29E",
    "gender-male-female-variant": "\U000F016A",
    "gender-non-binary": "\U000F016B",
    "gender-transgender": "\uF29F",
    "gentoo": "\uF8E7",
    "gesture": "\uF7CA",
    "gesture-double-tap": "\uF73B",
    "gesture-pinch": "\uFABC",
    "gesture-spread": "\uFABD",
    "gesture-swipe": "\uFD52",
    "gesture-swipe-down": "\uF73C",
    "gesture-swipe-horizontal": "\uFABE",
    "gesture-swipe-left": "\uF73D",
    "gesture-swipe-right": "\uF73E",
    "gesture-swipe-up": "\uF73F",
    "gesture-swipe-vertical": "\uFABF",
    "gesture-tap": "\uF740",
    "gesture-tap-box": "\U000F02D4",
    "gesture-tap-button": "\U000F02D3",
    "gesture-tap-hold": "\uFD53",
    "gesture-two-double-tap": "\uF741",
    "gesture-two-tap": "\uF742",
    "ghost": "\uF2A0",
    "ghost-off": "\uF9F4",
    "gif": "\uFD54",
    "gift": "\uFE85",
    "gift-outline": "\uF2A1",
    "git": "\uF2A2",
    "github-box": "\uF2A3",
    "github-circle": "\uF2A4",
    "github-face": "\uF6DA",
    "gitlab": "\uFB7C",
    "glass-cocktail": "\uF356",
    "glass-flute": "\uF2A5",
    "glass-mug": "\uF2A6",
    "glass-mug-variant": "\U000F0141",
    "glass-pint-outline": "\U000F0338",
    "glass-stange": "\uF2A7",
    "glass-tulip": "\uF2A8",
    "glass-wine": "\uF875",
    "glassdoor": "\uF2A9",
    "glasses": "\uF2AA",
    "globe-light": "\U000F0302",
    "globe-model": "\uF8E8",
    "gmail": "\uF2AB",
    "gnome": "\uF2AC",
    "go-kart": "\uFD55",
    "go-kart-track": "\uFD56",
    "gog": "\uFB7D",
    "gold": "\U000F027A",
    "golf": "\uF822",
    "golf-cart": "\U000F01CF",
    "golf-tee": "\U000F00AE",
    "gondola": "\uF685",
    "goodreads": "\uFD57",
    "google": "\uF2AD",
    "google-adwords": "\uFC63",
    "google-analytics": "\uF7CB",
    "google-assistant": "\uF7CC",
    "google-cardboard": "\uF2AE",
    "google-chrome": "\uF2AF",
    "google-circles": "\uF2B0",
    "google-circles-communities": "\uF2B1",
    "google-circles-extended": "\uF2B2",
    "google-circles-group": "\uF2B3",
    "google-classroom": "\uF2C0",
    "google-cloud": "\U000F0221",
    "google-controller": "\uF2B4",
    "google-controller-off": "\uF2B5",
    "google-downasaur": "\U000F038D",
    "google-drive": "\uF2B6",
    "google-earth": "\uF2B7",
    "google-fit": "\uF96B",
    "google-glass": "\uF2B8",
    "google-hangouts": "\uF2C9",
    "google-home": "\uF823",
    "google-keep": "\uF6DB",
    "google-lens": "\uF9F5",
    "google-maps": "\uF5F5",
    "google-my-business": "\U000F006A",
    "google-nearby": "\uF2B9",
    "google-pages": "\uF2BA",
    "google-photos": "\uF6DC",
    "google-physical-web": "\uF2BB",
    "google-play": "\uF2BC",
    "google-plus": "\uF2BD",
    "google-plus-box": "\uF2BE",
    "google-podcast": "\uFED6",
    "google-spreadsheet": "\uF9F6",
    "google-street-view": "\uFC64",
    "google-translate": "\uF2BF",
    "gradient": "\uF69F",
    "grain": "\uFD58",
    "graph": "\U000F006B",
    "graph-outline": "\U000F006C",
    "graphql": "\uF876",
    "grave-stone": "\uFB7E",
    "grease-pencil": "\uF648",
    "greater-than": "\uF96C",
    "greater-than-or-equal": "\uF96D",
    "grid": "\uF2C1",
    "grid-large": "\uF757",
    "grid-off": "\uF2C2",
    "grill": "\uFE86",
    "grill-outline": "\U000F01B5",
    "group": "\uF2C3",
    "guitar-acoustic": "\uF770",
    "guitar-electric": "\uF2C4",
    "guitar-pick": "\uF2C5",
    "guitar-pick-outline": "\uF2C6",
    "guy-fawkes-mask": "\uF824",
    "hackernews": "\uF624",
    "hail": "\uFAC0",
    "hair-dryer": "\U000F011A",
    "hair-dryer-outline": "\U000F011B",
    "halloween": "\uFB7F",
    "hamburger": "\uF684",
    "hammer": "\uF8E9",
    "hammer-screwdriver": "\U000F034D",
    "hammer-wrench": "\U000F034E",
    "hand": "\uFA4E",
    "hand-heart": "\U000F011C",
    "hand-left": "\uFE87",
    "hand-okay": "\uFA4F",
    "hand-peace": "\uFA50",
    "hand-peace-variant": "\uFA51",
    "hand-pointing-down": "\uFA52",
    "hand-pointing-left": "\uFA53",
    "hand-pointing-right": "\uF2C7",
    "hand-pointing-up": "\uFA54",
    "hand-right": "\uFE88",
    "hand-saw": "\uFE89",
    "handball": "\uFF70",
    "handcuffs": "\U000F0169",
    "handshake": "\U000F0243",
    "hanger": "\uF2C8",
    "hard-hat": "\uF96E",
    "harddisk": "\uF2CA",
    "harddisk-plus": "\U000F006D",
    "harddisk-remove": "\U000F006E",
    "hat-fedora": "\uFB80",
    "hazard-lights": "\uFC65",
    "hdr": "\uFD59",
    "hdr-off": "\uFD5A",
    "head": "\U000F0389",
    "head-alert": "\U000F0363",
    "head-alert-outline": "\U000F0364",
    "head-check": "\U000F0365",
    "head-check-outline": "\U000F0366",
    "head-cog": "\U000F0367",
    "head-cog-outline": "\U000F0368",
    "head-dots-horizontal": "\U000F0369",
    "head-dots-horizontal-outline": "\U000F036A",
    "head-flash": "\U000F036B",
    "head-flash-outline": "\U000F036C",
    "head-heart": "\U000F036D",
    "head-heart-outline": "\U000F036E",
    "head-lightbulb": "\U000F036F",
    "head-lightbulb-outline": "\U000F0370",
    "head-minus": "\U000F0371",
    "head-minus-outline": "\U000F0372",
    "head-outline": "\U000F038A",
    "head-plus": "\U000F0373",
    "head-plus-outline": "\U000F0374",
    "head-question": "\U000F0375",
    "head-question-outline": "\U000F0376",
    "head-remove": "\U000F0377",
    "head-remove-outline": "\U000F0378",
    "head-snowflake": "\U000F0379",
    "head-snowflake-outline": "\U000F037A",
    "head-sync": "\U000F037B",
    "head-sync-outline": "\U000F037C",
    "headphones": "\uF2CB",
    "headphones-bluetooth": "\uF96F",
    "headphones-box": "\uF2CC",
    "headphones-off": "\uF7CD",
    "headphones-settings": "\uF2CD",
    "headset": "\uF2CE",
    "headset-dock": "\uF2CF",
    "headset-off": "\uF2D0",
    "heart": "\uF2D1",
    "heart-box": "\uF2D2",
    "heart-box-outline": "\uF2D3",
    "heart-broken": "\uF2D4",
    "heart-broken-outline": "\uFCF0",
    "heart-circle": "\uF970",
    "heart-circle-outline": "\uF971",
    "heart-flash": "\uFF16",
    "heart-half": "\uF6DE",
    "heart-half-full": "\uF6DD",
    "heart-half-outline": "\uF6DF",
    "heart-multiple": "\uFA55",
    "heart-multiple-outline": "\uFA56",
    "heart-off": "\uF758",
    "heart-outline": "\uF2D5",
    "heart-pulse": "\uF5F6",
    "helicopter": "\uFAC1",
    "help": "\uF2D6",
    "help-box": "\uF78A",
    "help-circle": "\uF2D7",
    "help-circle-outline": "\uF625",
    "help-network": "\uF6F4",
    "help-network-outline": "\uFC66",
    "help-rhombus": "\uFB81",
    "help-rhombus-outline": "\uFB82",
    "hexadecimal": "\U000F02D2",
    "hexagon": "\uF2D8",
    "hexagon-multiple": "\uF6E0",
    "hexagon-multiple-outline": "\U000F011D",
    "hexagon-outline": "\uF2D9",
    "hexagon-slice-1": "\uFAC2",
    "hexagon-slice-2": "\uFAC3",
    "hexagon-slice-3": "\uFAC4",
    "hexagon-slice-4": "\uFAC5",
    "hexagon-slice-5": "\uFAC6",
    "hexagon-slice-6": "\uFAC7",
    "hexagram": "\uFAC8",
    "hexagram-outline": "\uFAC9",
    "high-definition": "\uF7CE",
    "high-definition-box": "\uF877",
    "highway": "\uF5F7",
    "hiking": "\uFD5B",
    "hinduism": "\uF972",
    "history": "\uF2DA",
    "hockey-puck": "\uF878",
    "hockey-sticks": "\uF879",
    "hololens": "\uF2DB",
    "home": "\uF2DC",
    "home-account": "\uF825",
    "home-alert": "\uF87A",
    "home-analytics": "\uFED7",
    "home-assistant": "\uF7CF",
    "home-automation": "\uF7D0",
    "home-circle": "\uF7D1",
    "home-circle-outline": "\U000F006F",
    "home-city": "\uFCF1",
    "home-city-outline": "\uFCF2",
    "home-currency-usd": "\uF8AE",
    "home-edit": "\U000F0184",
    "home-edit-outline": "\U000F0185",
    "home-export-outline": "\uFFB8",
    "home-flood": "\uFF17",
    "home-floor-0": "\uFDAE",
    "home-floor-1": "\uFD5C",
    "home-floor-2": "\uFD5D",
    "home-floor-3": "\uFD5E",
    "home-floor-a": "\uFD5F",
    "home-floor-b": "\uFD60",
    "home-floor-g": "\uFD61",
    "home-floor-l": "\uFD62",
    "home-floor-negative-1": "\uFDAF",
    "home-group": "\uFDB0",
    "home-heart": "\uF826",
    "home-import-outline": "\uFFB9",
    "home-lightbulb": "\U000F027C",
    "home-lightbulb-outline": "\U000F027D",
    "home-lock": "\uF8EA",
    "home-lock-open": "\uF8EB",
    "home-map-marker": "\uF5F8",
    "home-minus": "\uF973",
    "home-modern": "\uF2DD",
    "home-outline": "\uF6A0",
    "home-plus": "\uF974",
    "home-remove": "\U000F0272",
    "home-roof": "\U000F0156",
    "home-thermometer": "\uFF71",
    "home-thermometer-outline": "\uFF72",
    "home-variant": "\uF2DE",
    "home-variant-outline": "\uFB83",
    "hook": "\uF6E1",
    "hook-off": "\uF6E2",
    "hops": "\uF2DF",
    "horizontal-rotate-clockwise": "\U000F011E",
    "horizontal-rotate-counterclockwise": "\U000F011F",
    "horseshoe": "\uFA57",
    "hospital": "\U000F0017",
    "hospital-box": "\uF2E0",
    "hospital-box-outline": "\U000F0018",
    "hospital-building": "\uF2E1",
    "hospital-marker": "\uF2E2",
    "hot-tub": "\uF827",
    "hotel": "\uF2E3",
    "houzz": "\uF2E4",
    "houzz-box": "\uF2E5",
    "hubspot": "\uFCF3",
    "hulu": "\uF828",
    "human": "\uF2E6",
    "human-child": "\uF2E7",
    "human-female": "\uF649",
    "human-female-boy": "\uFA58",
    "human-female-female": "\uFA59",
    "human-female-girl": "\uFA5A",
    "human-greeting": "\uF64A",
    "human-handsdown": "\uF64B",
    "human-handsup": "\uF64C",
    "human-male": "\uF64D",
    "human-male-boy": "\uFA5B",
    "human-male-female": "\uF2E8",
    "human-male-girl": "\uFA5C",
    "human-male-height": "\uFF18",
    "human-male-height-variant": "\uFF19",
    "human-male-male": "\uFA5D",
    "human-pregnant": "\uF5CF",
    "humble-bundle": "\uF743",
    "hvac": "\U000F037D",
    "hydraulic-oil-level": "\U000F034F",
    "hydraulic-oil-temperature": "\U000F0350",
    "hydro-power": "\U000F0310",
    "ice-cream": "\uF829",
    "ice-pop": "\uFF1A",
    "id-card": "\uFFE0",
    "identifier": "\uFF1B",
    "ideogram-cjk": "\U000F035C",
    "ideogram-cjk-variant": "\U000F035D",
    "iframe": "\uFC67",
    "iframe-array": "\U000F0120",
    "iframe-array-outline": "\U000F0121",
    "iframe-braces": "\U000F0122",
    "iframe-braces-outline": "\U000F0123",
    "iframe-outline": "\uFC68",
    "iframe-parentheses": "\U000F0124",
    "iframe-parentheses-outline": "\U000F0125",
    "iframe-variable": "\U000F0126",
    "iframe-variable-outline": "\U000F0127",
    "image": "\uF2E9",
    "image-album": "\uF2EA",
    "image-area": "\uF2EB",
    "image-area-close": "\uF2EC",
    "image-auto-adjust": "\uFFE1",
    "image-broken": "\uF2ED",
    "image-broken-variant": "\uF2EE",
    "image-edit": "\U000F020E",
    "image-edit-outline": "\U000F020F",
    "image-filter": "\uF2EF",
    "image-filter-black-white": "\uF2F0",
    "image-filter-center-focus": "\uF2F1",
    "image-filter-center-focus-strong": "\uFF1C",
    "image-filter-center-focus-strong-outline": "\uFF1D",
    "image-filter-center-focus-weak": "\uF2F2",
    "image-filter-drama": "\uF2F3",
    "image-filter-frames": "\uF2F4",
    "image-filter-hdr": "\uF2F5",
    "image-filter-none": "\uF2F6",
    "image-filter-tilt-shift": "\uF2F7",
    "image-filter-vintage": "\uF2F8",
    "image-frame": "\uFE8A",
    "image-move": "\uF9F7",
    "image-multiple": "\uF2F9",
    "image-off": "\uF82A",
    "image-off-outline": "\U000F01FC",
    "image-outline": "\uF975",
    "image-plus": "\uF87B",
    "image-search": "\uF976",
    "image-search-outline": "\uF977",
    "image-size-select-actual": "\uFC69",
    "image-size-select-large": "\uFC6A",
    "image-size-select-small": "\uFC6B",
    "import": "\uF2FA",
    "inbox": "\uF686",
    "inbox-arrow-down": "\uF2FB",
    "inbox-arrow-down-outline": "\U000F029B",
    "inbox-arrow-up": "\uF3D1",
    "inbox-arrow-up-outline": "\U000F029C",
    "inbox-full": "\U000F029D",
    "inbox-full-outline": "\U000F029E",
    "inbox-multiple": "\uF8AF",
    "inbox-multiple-outline": "\uFB84",
    "inbox-outline": "\U000F029F",
    "incognito": "\uF5F9",
    "infinity": "\uF6E3",
    "information": "\uF2FC",
    "information-outline": "\uF2FD",
    "information-variant": "\uF64E",
    "instagram": "\uF2FE",
    "instapaper": "\uF2FF",
    "instrument-triangle": "\U000F0070",
    "internet-explorer": "\uF300",
    "invert-colors": "\uF301",
    "invert-colors-off": "\uFE8B",
    "iobroker": "\U000F0313",
    "ip": "\uFA5E",
    "ip-network": "\uFA5F",
    "ip-network-outline": "\uFC6C",
    "ipod": "\uFC6D",
    "islam": "\uF978",
    "island": "\U000F0071",
    "itunes": "\uF676",
    "iv-bag": "\U000F00E4",
    "jabber": "\uFDB1",
    "jeepney": "\uF302",
    "jellyfish": "\uFF1E",
    "jellyfish-outline": "\uFF1F",
    "jira": "\uF303",
    "jquery": "\uF87C",
    "jsfiddle": "\uF304",
    "json": "\uF626",
    "judaism": "\uF979",
    "jump-rope": "\U000F032A",
    "kabaddi": "\uFD63",
    "karate": "\uF82B",
    "keg": "\uF305",
    "kettle": "\uF5FA",
    "kettle-alert": "\U000F0342",
    "kettle-alert-outline": "\U000F0343",
    "kettle-off": "\U000F0346",
    "kettle-off-outline": "\U000F0347",
    "kettle-outline": "\uFF73",
    "kettle-steam": "\U000F0344",
    "kettle-steam-outline": "\U000F0345",
    "kettlebell": "\U000F032B",
    "key": "\uF306",
    "key-arrow-right": "\U000F033D",
    "key-change": "\uF307",
    "key-link": "\U000F01CA",
    "key-minus": "\uF308",
    "key-outline": "\uFDB2",
    "key-plus": "\uF309",
    "key-remove": "\uF30A",
    "key-star": "\U000F01C9",
    "key-variant": "\uF30B",
    "key-wireless": "\uFFE2",
    "keyboard": "\uF30C",
    "keyboard-backspace": "\uF30D",
    "keyboard-caps": "\uF30E",
    "keyboard-close": "\uF30F",
    "keyboard-esc": "\U000F02E2",
    "keyboard-f1": "\U000F02D6",
    "keyboard-f10": "\U000F02DF",
    "keyboard-f11": "\U000F02E0",
    "keyboard-f12": "\U000F02E1",
    "keyboard-f2": "\U000F02D7",
    "keyboard-f3": "\U000F02D8",
    "keyboard-f4": "\U000F02D9",
    "keyboard-f5": "\U000F02DA",
    "keyboard-f6": "\U000F02DB",
    "keyboard-f7": "\U000F02DC",
    "keyboard-f8": "\U000F02DD",
    "keyboard-f9": "\U000F02DE",
    "keyboard-off": "\uF310",
    "keyboard-off-outline": "\uFE8C",
    "keyboard-outline": "\uF97A",
    "keyboard-return": "\uF311",
    "keyboard-settings": "\uF9F8",
    "keyboard-settings-outline": "\uF9F9",
    "keyboard-space": "\U000F0072",
    "keyboard-tab": "\uF312",
    "keyboard-variant": "\uF313",
    "khanda": "\U000F0128",
    "kickstarter": "\uF744",
    "klingon": "\U000F0386",
    "knife": "\uF9FA",
    "knife-military": "\uF9FB",
    "kodi": "\uF314",
    "kotlin": "\U000F0244",
    "kubernetes": "\U000F0129",
    "label": "\uF315",
    "label-multiple": "\U000F03A0",
    "label-multiple-outline": "\U000F03A1",
    "label-off": "\uFACA",
    "label-off-outline": "\uFACB",
    "label-outline": "\uF316",
    "label-percent": "\U000F0315",
    "label-percent-outline": "\U000F0316",
    "label-variant": "\uFACC",
    "label-variant-outline": "\uFACD",
    "ladybug": "\uF82C",
    "lambda": "\uF627",
    "lamp": "\uF6B4",
    "lan": "\uF317",
    "lan-check": "\U000F02D5",
    "lan-connect": "\uF318",
    "lan-disconnect": "\uF319",
    "lan-pending": "\uF31A",
    "language-c": "\uF671",
    "language-cpp": "\uF672",
    "language-csharp": "\uF31B",
    "language-css3": "\uF31C",
    "language-fortran": "\U000F0245",
    "language-go": "\uF7D2",
    "language-haskell": "\uFC6E",
    "language-html5": "\uF31D",
    "language-java": "\uFB1C",
    "language-javascript": "\uF31E",
    "language-lua": "\uF8B0",
    "language-php": "\uF31F",
    "language-python": "\uF320",
    "language-python-text": "\uF321",
    "language-r": "\uF7D3",
    "language-ruby-on-rails": "\uFACE",
    "language-swift": "\uF6E4",
    "language-typescript": "\uF6E5",
    "laptop": "\uF322",
    "laptop-chromebook": "\uF323",
    "laptop-mac": "\uF324",
    "laptop-off": "\uF6E6",
    "laptop-windows": "\uF325",
    "laravel": "\uFACF",
    "lasso": "\uFF20",
    "lastfm": "\uF326",
    "lastpass": "\uF446",
    "latitude": "\uFF74",
    "launch": "\uF327",
    "lava-lamp": "\uF7D4",
    "layers": "\uF328",
    "layers-minus": "\uFE8D",
    "layers-off": "\uF329",
    "layers-off-outline": "\uF9FC",
    "layers-outline": "\uF9FD",
    "layers-plus": "\uFE30",
    "layers-remove": "\uFE31",
    "layers-search": "\U000F0231",
    "layers-search-outline": "\U000F0232",
    "layers-triple": "\uFF75",
    "layers-triple-outline": "\uFF76",
    "lead-pencil": "\uF64F",
    "leaf": "\uF32A",
    "leaf-maple": "\uFC6F",
    "leaf-maple-off": "\U000F0305",
    "leaf-off": "\U000F0304",
    "leak": "\uFDB3",
    "leak-off": "\uFDB4",
    "led-off": "\uF32B",
    "led-on": "\uF32C",
    "led-outline": "\uF32D",
    "led-strip": "\uF7D5",
    "led-strip-variant": "\U000F0073",
    "led-variant-off": "\uF32E",
    "led-variant-on": "\uF32F",
    "led-variant-outline": "\uF330",
    "leek": "\U000F01A8",
    "less-than": "\uF97B",
    "less-than-or-equal": "\uF97C",
    "library": "\uF331",
    "library-books": "\uF332",
    "library-movie": "\uFCF4",
    "library-music": "\uF333",
    "library-music-outline": "\uFF21",
    "library-shelves": "\uFB85",
    "library-video": "\uFCF5",
    "license": "\uFFE3",
    "lifebuoy": "\uF87D",
    "light-switch": "\uF97D",
    "lightbulb": "\uF335",
    "lightbulb-cfl": "\U000F0233",
    "lightbulb-cfl-off": "\U000F0234",
    "lightbulb-cfl-spiral": "\U000F02A0",
    "lightbulb-cfl-spiral-off": "\U000F02EE",
    "lightbulb-group": "\U000F027E",
    "lightbulb-group-off": "\U000F02F8",
    "lightbulb-group-off-outline": "\U000F02F9",
    "lightbulb-group-outline": "\U000F027F",
    "lightbulb-multiple": "\U000F0280",
    "lightbulb-multiple-off": "\U000F02FA",
    "lightbulb-multiple-off-outline": "\U000F02FB",
    "lightbulb-multiple-outline": "\U000F0281",
    "lightbulb-off": "\uFE32",
    "lightbulb-off-outline": "\uFE33",
    "lightbulb-on": "\uF6E7",
    "lightbulb-on-outline": "\uF6E8",
    "lightbulb-outline": "\uF336",
    "lighthouse": "\uF9FE",
    "lighthouse-on": "\uF9FF",
    "link": "\uF337",
    "link-box": "\uFCF6",
    "link-box-outline": "\uFCF7",
    "link-box-variant": "\uFCF8",
    "link-box-variant-outline": "\uFCF9",
    "link-lock": "\U000F00E5",
    "link-off": "\uF338",
    "link-plus": "\uFC70",
    "link-variant": "\uF339",
    "link-variant-minus": "\U000F012A",
    "link-variant-off": "\uF33A",
    "link-variant-plus": "\U000F012B",
    "link-variant-remove": "\U000F012C",
    "linkedin": "\uF33B",
    "linkedin-box": "\uF33C",
    "linux": "\uF33D",
    "linux-mint": "\uF8EC",
    "litecoin": "\uFA60",
    "loading": "\uF771",
    "location-enter": "\uFFE4",
    "location-exit": "\uFFE5",
    "lock": "\uF33E",
    "lock-alert": "\uF8ED",
    "lock-clock": "\uF97E",
    "lock-open": "\uF33F",
    "lock-open-outline": "\uF340",
    "lock-open-variant": "\uFFE6",
    "lock-open-variant-outline": "\uFFE7",
    "lock-outline": "\uF341",
    "lock-pattern": "\uF6E9",
    "lock-plus": "\uF5FB",
    "lock-question": "\uF8EE",
    "lock-reset": "\uF772",
    "lock-smart": "\uF8B1",
    "locker": "\uF7D6",
    "locker-multiple": "\uF7D7",
    "login": "\uF342",
    "login-variant": "\uF5FC",
    "logout": "\uF343",
    "logout-variant": "\uF5FD",
    "longitude": "\uFF77",
    "looks": "\uF344",
    "loupe": "\uF345",
    "lumx": "\uF346",
    "lungs": "\U000F00AF",
    "lyft": "\uFB1D",
    "magnet": "\uF347",
    "magnet-on": "\uF348",
    "magnify": "\uF349",
    "magnify-close": "\uF97F",
    "magnify-minus": "\uF34A",
    "magnify-minus-cursor": "\uFA61",
    "magnify-minus-outline": "\uF6EB",
    "magnify-plus": "\uF34B",
    "magnify-plus-cursor": "\uFA62",
    "magnify-plus-outline": "\uF6EC",
    "magnify-remove-cursor": "\U000F0237",
    "magnify-remove-outline": "\U000F0238",
    "magnify-scan": "\U000F02A1",
    "mail": "\uFED8",
    "mail-ru": "\uF34C",
    "mailbox": "\uF6ED",
    "mailbox-open": "\uFD64",
    "mailbox-open-outline": "\uFD65",
    "mailbox-open-up": "\uFD66",
    "mailbox-open-up-outline": "\uFD67",
    "mailbox-outline": "\uFD68",
    "mailbox-up": "\uFD69",
    "mailbox-up-outline": "\uFD6A",
    "map": "\uF34D",
    "map-check": "\uFED9",
    "map-check-outline": "\uFEDA",
    "map-clock": "\uFCFA",
    "map-clock-outline": "\uFCFB",
    "map-legend": "\uFA00",
    "map-marker": "\uF34E",
    "map-marker-alert": "\uFF22",
    "map-marker-alert-outline": "\uFF23",
    "map-marker-check": "\uFC71",
    "map-marker-check-outline": "\U000F0326",
    "map-marker-circle": "\uF34F",
    "map-marker-distance": "\uF8EF",
    "map-marker-down": "\U000F012D",
    "map-marker-left": "\U000F0306",
    "map-marker-left-outline": "\U000F0308",
    "map-marker-minus": "\uF650",
    "map-marker-minus-outline": "\U000F0324",
    "map-marker-multiple": "\uF350",
    "map-marker-multiple-outline": "\U000F02A2",
    "map-marker-off": "\uF351",
    "map-marker-off-outline": "\U000F0328",
    "map-marker-outline": "\uF7D8",
    "map-marker-path": "\uFCFC",
    "map-marker-plus": "\uF651",
    "map-marker-plus-outline": "\U000F0323",
    "map-marker-question": "\uFF24",
    "map-marker-question-outline": "\uFF25",
    "map-marker-radius": "\uF352",
    "map-marker-radius-outline": "\U000F0327",
    "map-marker-remove": "\uFF26",
    "map-marker-remove-outline": "\U000F0325",
    "map-marker-remove-variant": "\uFF27",
    "map-marker-right": "\U000F0307",
    "map-marker-right-outline": "\U000F0309",
    "map-marker-up": "\U000F012E",
    "map-minus": "\uF980",
    "map-outline": "\uF981",
    "map-plus": "\uF982",
    "map-search": "\uF983",
    "map-search-outline": "\uF984",
    "mapbox": "\uFB86",
    "margin": "\uF353",
    "markdown": "\uF354",
    "markdown-outline": "\uFF78",
    "marker": "\uF652",
    "marker-cancel": "\uFDB5",
    "marker-check": "\uF355",
    "mastodon": "\uFAD0",
    "mastodon-variant": "\uFAD1",
    "material-design": "\uF985",
    "material-ui": "\uF357",
    "math-compass": "\uF358",
    "math-cos": "\uFC72",
    "math-integral": "\uFFE8",
    "math-integral-box": "\uFFE9",
    "math-log": "\U000F00B0",
    "math-norm": "\uFFEA",
    "math-norm-box": "\uFFEB",
    "math-sin": "\uFC73",
    "math-tan": "\uFC74",
    "matrix": "\uF628",
    "medal": "\uF986",
    "medal-outline": "\U000F0351",
    "medical-bag": "\uF6EE",
    "meditation": "\U000F01A6",
    "medium": "\uF35A",
    "meetup": "\uFAD2",
    "memory": "\uF35B",
    "menu": "\uF35C",
    "menu-down": "\uF35D",
    "menu-down-outline": "\uF6B5",
    "menu-left": "\uF35E",
    "menu-left-outline": "\uFA01",
    "menu-open": "\uFB87",
    "menu-right": "\uF35F",
    "menu-right-outline": "\uFA02",
    "menu-swap": "\uFA63",
    "menu-swap-outline": "\uFA64",
    "menu-up": "\uF360",
    "menu-up-outline": "\uF6B6",
    "merge": "\uFF79",
    "message": "\uF361",
    "message-alert": "\uF362",
    "message-alert-outline": "\uFA03",
    "message-arrow-left": "\U000F031D",
    "message-arrow-left-outline": "\U000F031E",
    "message-arrow-right": "\U000F031F",
    "message-arrow-right-outline": "\U000F0320",
    "message-bulleted": "\uF6A1",
    "message-bulleted-off": "\uF6A2",
    "message-draw": "\uF363",
    "message-image": "\uF364",
    "message-image-outline": "\U000F0197",
    "message-lock": "\uFFEC",
    "message-lock-outline": "\U000F0198",
    "message-minus": "\U000F0199",
    "message-minus-outline": "\U000F019A",
    "message-outline": "\uF365",
    "message-plus": "\uF653",
    "message-plus-outline": "\U000F00E6",
    "message-processing": "\uF366",
    "message-processing-outline": "\U000F019B",
    "message-reply": "\uF367",
    "message-reply-text": "\uF368",
    "message-settings": "\uF6EF",
    "message-settings-outline": "\U000F019C",
    "message-settings-variant": "\uF6F0",
    "message-settings-variant-outline": "\U000F019D",
    "message-text": "\uF369",
    "message-text-clock": "\U000F019E",
    "message-text-clock-outline": "\U000F019F",
    "message-text-lock": "\uFFED",
    "message-text-lock-outline": "\U000F01A0",
    "message-text-outline": "\uF36A",
    "message-video": "\uF36B",
    "meteor": "\uF629",
    "metronome": "\uF7D9",
    "metronome-tick": "\uF7DA",
    "micro-sd": "\uF7DB",
    "microphone": "\uF36C",
    "microphone-minus": "\uF8B2",
    "microphone-off": "\uF36D",
    "microphone-outline": "\uF36E",
    "microphone-plus": "\uF8B3",
    "microphone-settings": "\uF36F",
    "microphone-variant": "\uF370",
    "microphone-variant-off": "\uF371",
    "microscope": "\uF654",
    "microsoft": "\uF372",
    "microsoft-dynamics": "\uF987",
    "microwave": "\uFC75",
    "middleware": "\uFF7A",
    "middleware-outline": "\uFF7B",
    "midi": "\uF8F0",
    "midi-port": "\uF8F1",
    "mine": "\uFDB6",
    "minecraft": "\uF373",
    "mini-sd": "\uFA04",
    "minidisc": "\uFA05",
    "minus": "\uF374",
    "minus-box": "\uF375",
    "minus-box-multiple": "\U000F016C",
    "minus-box-multiple-outline": "\U000F016D",
    "minus-box-outline": "\uF6F1",
    "minus-circle": "\uF376",
    "minus-circle-outline": "\uF377",
    "minus-network": "\uF378",
    "minus-network-outline": "\uFC76",
    "mirror": "\U000F0228",
    "mixcloud": "\uF62A",
    "mixed-martial-arts": "\uFD6B",
    "mixed-reality": "\uF87E",
    "mixer": "\uF7DC",
    "molecule": "\uFB88",
    "monitor": "\uF379",
    "monitor-cellphone": "\uF988",
    "monitor-cellphone-star": "\uF989",
    "monitor-clean": "\U000F012F",
    "monitor-dashboard": "\uFA06",
    "monitor-edit": "\U000F02F1",
    "monitor-lock": "\uFDB7",
    "monitor-multiple": "\uF37A",
    "monitor-off": "\uFD6C",
    "monitor-screenshot": "\uFE34",
    "monitor-speaker": "\uFF7C",
    "monitor-speaker-off": "\uFF7D",
    "monitor-star": "\uFDB8",
    "moon-first-quarter": "\uFF7E",
    "moon-full": "\uFF7F",
    "moon-last-quarter": "\uFF80",
    "moon-new": "\uFF81",
    "moon-waning-crescent": "\uFF82",
    "moon-waning-gibbous": "\uFF83",
    "moon-waxing-crescent": "\uFF84",
    "moon-waxing-gibbous": "\uFF85",
    "moped": "\U000F00B1",
    "more": "\uF37B",
    "mother-heart": "\U000F033F",
    "mother-nurse": "\uFCFD",
    "motion-sensor": "\uFD6D",
    "motorbike": "\uF37C",
    "mouse": "\uF37D",
    "mouse-bluetooth": "\uF98A",
    "mouse-off": "\uF37E",
    "mouse-variant": "\uF37F",
    "mouse-variant-off": "\uF380",
    "move-resize": "\uF655",
    "move-resize-variant": "\uF656",
    "movie": "\uF381",
    "movie-edit": "\U000F014D",
    "movie-edit-outline": "\U000F014E",
    "movie-filter": "\U000F014F",
    "movie-filter-outline": "\U000F0150",
    "movie-open": "\uFFEE",
    "movie-open-outline": "\uFFEF",
    "movie-outline": "\uFDB9",
    "movie-roll": "\uF7DD",
    "movie-search": "\U000F01FD",
    "movie-search-outline": "\U000F01FE",
    "muffin": "\uF98B",
    "multiplication": "\uF382",
    "multiplication-box": "\uF383",
    "mushroom": "\uF7DE",
    "mushroom-outline": "\uF7DF",
    "music": "\uF759",
    "music-accidental-double-flat": "\uFF86",
    "music-accidental-double-sharp": "\uFF87",
    "music-accidental-flat": "\uFF88",
    "music-accidental-natural": "\uFF89",
    "music-accidental-sharp": "\uFF8A",
    "music-box": "\uF384",
    "music-box-outline": "\uF385",
    "music-circle": "\uF386",
    "music-circle-outline": "\uFAD3",
    "music-clef-alto": "\uFF8B",
    "music-clef-bass": "\uFF8C",
    "music-clef-treble": "\uFF8D",
    "music-note": "\uF387",
    "music-note-bluetooth": "\uF5FE",
    "music-note-bluetooth-off": "\uF5FF",
    "music-note-eighth": "\uF388",
    "music-note-eighth-dotted": "\uFF8E",
    "music-note-half": "\uF389",
    "music-note-half-dotted": "\uFF8F",
    "music-note-off": "\uF38A",
    "music-note-off-outline": "\uFF90",
    "music-note-outline": "\uFF91",
    "music-note-plus": "\uFDBA",
    "music-note-quarter": "\uF38B",
    "music-note-quarter-dotted": "\uFF92",
    "music-note-sixteenth": "\uF38C",
    "music-note-sixteenth-dotted": "\uFF93",
    "music-note-whole": "\uF38D",
    "music-note-whole-dotted": "\uFF94",
    "music-off": "\uF75A",
    "music-rest-eighth": "\uFF95",
    "music-rest-half": "\uFF96",
    "music-rest-quarter": "\uFF97",
    "music-rest-sixteenth": "\uFF98",
    "music-rest-whole": "\uFF99",
    "nail": "\uFDBB",
    "nas": "\uF8F2",
    "nativescript": "\uF87F",
    "nature": "\uF38E",
    "nature-people": "\uF38F",
    "navigation": "\uF390",
    "near-me": "\uF5CD",
    "necklace": "\uFF28",
    "needle": "\uF391",
    "netflix": "\uF745",
    "network": "\uF6F2",
    "network-off": "\uFC77",
    "network-off-outline": "\uFC78",
    "network-outline": "\uFC79",
    "network-router": "\U000F00B2",
    "network-strength-1": "\uF8F3",
    "network-strength-1-alert": "\uF8F4",
    "network-strength-2": "\uF8F5",
    "network-strength-2-alert": "\uF8F6",
    "network-strength-3": "\uF8F7",
    "network-strength-3-alert": "\uF8F8",
    "network-strength-4": "\uF8F9",
    "network-strength-4-alert": "\uF8FA",
    "network-strength-off": "\uF8FB",
    "network-strength-off-outline": "\uF8FC",
    "network-strength-outline": "\uF8FD",
    "new-box": "\uF394",
    "newspaper": "\uF395",
    "newspaper-minus": "\uFF29",
    "newspaper-plus": "\uFF2A",
    "newspaper-variant": "\U000F0023",
    "newspaper-variant-multiple": "\U000F0024",
    "newspaper-variant-multiple-outline": "\U000F0025",
    "newspaper-variant-outline": "\U000F0026",
    "nfc": "\uF396",
    "nfc-off": "\uFE35",
    "nfc-search-variant": "\uFE36",
    "nfc-tap": "\uF397",
    "nfc-variant": "\uF398",
    "nfc-variant-off": "\uFE37",
    "ninja": "\uF773",
    "nintendo-switch": "\uF7E0",
    "nix": "\U000F0130",
    "nodejs": "\uF399",
    "noodles": "\U000F01A9",
    "not-equal": "\uF98C",
    "not-equal-variant": "\uF98D",
    "note": "\uF39A",
    "note-multiple": "\uF6B7",
    "note-multiple-outline": "\uF6B8",
    "note-outline": "\uF39B",
    "note-plus": "\uF39C",
    "note-plus-outline": "\uF39D",
    "note-text": "\uF39E",
    "note-text-outline": "\U000F0202",
    "notebook": "\uF82D",
    "notebook-multiple": "\uFE38",
    "notebook-outline": "\uFEDC",
    "notification-clear-all": "\uF39F",
    "npm": "\uF6F6",
    "npm-variant": "\uF98E",
    "npm-variant-outline": "\uF98F",
    "nuke": "\uF6A3",
    "null": "\uF7E1",
    "numeric": "\uF3A0",
    "numeric-0": "\u0030",
    "numeric-0-box": "\uF3A1",
    "numeric-0-box-multiple": "\uFF2B",
    "numeric-0-box-multiple-outline": "\uF3A2",
    "numeric-0-box-outline": "\uF3A3",
    "numeric-0-circle": "\uFC7A",
    "numeric-0-circle-outline": "\uFC7B",
    "numeric-1": "\u0031",
    "numeric-1-box": "\uF3A4",
    "numeric-1-box-multiple": "\uFF2C",
    "numeric-1-box-multiple-outline": "\uF3A5",
    "numeric-1-box-outline": "\uF3A6",
    "numeric-1-circle": "\uFC7C",
    "numeric-1-circle-outline": "\uFC7D",
    "numeric-10": "\U000F000A",
    "numeric-10-box": "\uFF9A",
    "numeric-10-box-multiple": "\U000F000B",
    "numeric-10-box-multiple-outline": "\U000F000C",
    "numeric-10-box-outline": "\uFF9B",
    "numeric-10-circle": "\U000F000D",
    "numeric-10-circle-outline": "\U000F000E",
    "numeric-2": "\u0032",
    "numeric-2-box": "\uF3A7",
    "numeric-2-box-multiple": "\uFF2D",
    "numeric-2-box-multiple-outline": "\uF3A8",
    "numeric-2-box-outline": "\uF3A9",
    "numeric-2-circle": "\uFC7E",
    "numeric-2-circle-outline": "\uFC7F",
    "numeric-3": "\u0033",
    "numeric-3-box": "\uF3AA",
    "numeric-3-box-multiple": "\uFF2E",
    "numeric-3-box-multiple-outline": "\uF3AB",
    "numeric-3-box-outline": "\uF3AC",
    "numeric-3-circle": "\uFC80",
    "numeric-3-circle-outline": "\uFC81",
    "numeric-4": "\u0034",
    "numeric-4-box": "\uF3AD",
    "numeric-4-box-multiple": "\uFF2F",
    "numeric-4-box-multiple-outline": "\uF3AE",
    "numeric-4-box-outline": "\uF3AF",
    "numeric-4-circle": "\uFC82",
    "numeric-4-circle-outline": "\uFC83",
    "numeric-5": "\u0035",
    "numeric-5-box": "\uF3B0",
    "numeric-5-box-multiple": "\uFF30",
    "numeric-5-box-multiple-outline": "\uF3B1",
    "numeric-5-box-outline": "\uF3B2",
    "numeric-5-circle": "\uFC84",
    "numeric-5-circle-outline": "\uFC85",
    "numeric-6": "\u0036",
    "numeric-6-box": "\uF3B3",
    "numeric-6-box-multiple": "\uFF31",
    "numeric-6-box-multiple-outline": "\uF3B4",
    "numeric-6-box-outline": "\uF3B5",
    "numeric-6-circle": "\uFC86",
    "numeric-6-circle-outline": "\uFC87",
    "numeric-7": "\u0037",
    "numeric-7-box": "\uF3B6",
    "numeric-7-box-multiple": "\uFF32",
    "numeric-7-box-multiple-outline": "\uF3B7",
    "numeric-7-box-outline": "\uF3B8",
    "numeric-7-circle": "\uFC88",
    "numeric-7-circle-outline": "\uFC89",
    "numeric-8": "\u0038",
    "numeric-8-box": "\uF3B9",
    "numeric-8-box-multiple": "\uFF33",
    "numeric-8-box-multiple-outline": "\uF3BA",
    "numeric-8-box-outline": "\uF3BB",
    "numeric-8-circle": "\uFC8A",
    "numeric-8-circle-outline": "\uFC8B",
    "numeric-9": "\u0039",
    "numeric-9-box": "\uF3BC",
    "numeric-9-box-multiple": "\uFF34",
    "numeric-9-box-multiple-outline": "\uF3BD",
    "numeric-9-box-outline": "\uF3BE",
    "numeric-9-circle": "\uFC8C",
    "numeric-9-circle-outline": "\uFC8D",
    "numeric-9-plus": "\U000F000F",
    "numeric-9-plus-box": "\uF3BF",
    "numeric-9-plus-box-multiple": "\uFF35",
    "numeric-9-plus-box-multiple-outline": "\uF3C0",
    "numeric-9-plus-box-outline": "\uF3C1",
    "numeric-9-plus-circle": "\uFC8E",
    "numeric-9-plus-circle-outline": "\uFC8F",
    "numeric-negative-1": "\U000F0074",
    "nut": "\uF6F7",
    "nutrition": "\uF3C2",
    "nuxt": "\U000F0131",
    "oar": "\uF67B",
    "ocarina": "\uFDBC",
    "oci": "\U000F0314",
    "ocr": "\U000F0165",
    "octagon": "\uF3C3",
    "octagon-outline": "\uF3C4",
    "octagram": "\uF6F8",
    "octagram-outline": "\uF774",
    "odnoklassniki": "\uF3C5",
    "offer": "\U000F0246",
    "office": "\uF3C6",
    "office-building": "\uF990",
    "oil": "\uF3C7",
    "oil-lamp": "\uFF36",
    "oil-level": "\U000F0075",
    "oil-temperature": "\U000F0019",
    "omega": "\uF3C9",
    "one-up": "\uFB89",
    "onedrive": "\uF3CA",
    "onenote": "\uF746",
    "onepassword": "\uF880",
    "opacity": "\uF5CC",
    "open-in-app": "\uF3CB",
    "open-in-new": "\uF3CC",
    "open-source-initiative": "\uFB8A",
    "openid": "\uF3CD",
    "opera": "\uF3CE",
    "orbit": "\uF018",
    "origin": "\uFB2B",
    "ornament": "\uF3CF",
    "ornament-variant": "\uF3D0",
    "outdoor-lamp": "\U000F0076",
    "outlook": "\uFCFE",
    "overscan": "\U000F0027",
    "owl": "\uF3D2",
    "pac-man": "\uFB8B",
    "package": "\uF3D3",
    "package-down": "\uF3D4",
    "package-up": "\uF3D5",
    "package-variant": "\uF3D6",
    "package-variant-closed": "\uF3D7",
    "page-first": "\uF600",
    "page-last": "\uF601",
    "page-layout-body": "\uF6F9",
    "page-layout-footer": "\uF6FA",
    "page-layout-header": "\uF6FB",
    "page-layout-header-footer": "\uFF9C",
    "page-layout-sidebar-left": "\uF6FC",
    "page-layout-sidebar-right": "\uF6FD",
    "page-next": "\uFB8C",
    "page-next-outline": "\uFB8D",
    "page-previous": "\uFB8E",
    "page-previous-outline": "\uFB8F",
    "palette": "\uF3D8",
    "palette-advanced": "\uF3D9",
    "palette-outline": "\uFE6C",
    "palette-swatch": "\uF8B4",
    "palette-swatch-outline": "\U000F0387",
    "palm-tree": "\U000F0077",
    "pan": "\uFB90",
    "pan-bottom-left": "\uFB91",
    "pan-bottom-right": "\uFB92",
    "pan-down": "\uFB93",
    "pan-horizontal": "\uFB94",
    "pan-left": "\uFB95",
    "pan-right": "\uFB96",
    "pan-top-left": "\uFB97",
    "pan-top-right": "\uFB98",
    "pan-up": "\uFB99",
    "pan-vertical": "\uFB9A",
    "panda": "\uF3DA",
    "pandora": "\uF3DB",
    "panorama": "\uF3DC",
    "panorama-fisheye": "\uF3DD",
    "panorama-horizontal": "\uF3DE",
    "panorama-vertical": "\uF3DF",
    "panorama-wide-angle": "\uF3E0",
    "paper-cut-vertical": "\uF3E1",
    "paper-roll": "\U000F0182",
    "paper-roll-outline": "\U000F0183",
    "paperclip": "\uF3E2",
    "parachute": "\uFC90",
    "parachute-outline": "\uFC91",
    "parking": "\uF3E3",
    "party-popper": "\U000F0078",
    "passport": "\uF7E2",
    "passport-biometric": "\uFDBD",
    "pasta": "\U000F018B",
    "patio-heater": "\uFF9D",
    "patreon": "\uF881",
    "pause": "\uF3E4",
    "pause-circle": "\uF3E5",
    "pause-circle-outline": "\uF3E6",
    "pause-octagon": "\uF3E7",
    "pause-octagon-outline": "\uF3E8",
    "paw": "\uF3E9",
    "paw-off": "\uF657",
    "paypal": "\uF882",
    "pdf-box": "\uFE39",
    "peace": "\uF883",
    "peanut": "\U000F001E",
    "peanut-off": "\U000F001F",
    "peanut-off-outline": "\U000F0021",
    "peanut-outline": "\U000F0020",
    "pen": "\uF3EA",
    "pen-lock": "\uFDBE",
    "pen-minus": "\uFDBF",
    "pen-off": "\uFDC0",
    "pen-plus": "\uFDC1",
    "pen-remove": "\uFDC2",
    "pencil": "\uF3EB",
    "pencil-box": "\uF3EC",
    "pencil-box-multiple": "\U000F016F",
    "pencil-box-multiple-outline": "\U000F0170",
    "pencil-box-outline": "\uF3ED",
    "pencil-circle": "\uF6FE",
    "pencil-circle-outline": "\uF775",
    "pencil-lock": "\uF3EE",
    "pencil-lock-outline": "\uFDC3",
    "pencil-minus": "\uFDC4",
    "pencil-minus-outline": "\uFDC5",
    "pencil-off": "\uF3EF",
    "pencil-off-outline": "\uFDC6",
    "pencil-outline": "\uFC92",
    "pencil-plus": "\uFDC7",
    "pencil-plus-outline": "\uFDC8",
    "pencil-remove": "\uFDC9",
    "pencil-remove-outline": "\uFDCA",
    "pencil-ruler": "\U000F037E",
    "penguin": "\uFEDD",
    "pentagon": "\uF6FF",
    "pentagon-outline": "\uF700",
    "percent": "\uF3F0",
    "percent-outline": "\U000F02A3",
    "periodic-table": "\uF8B5",
    "periodic-table-co": "\U000F0329",
    "periodic-table-co2": "\uF7E3",
    "periscope": "\uF747",
    "perspective-less": "\uFCFF",
    "perspective-more": "\uFD00",
    "pharmacy": "\uF3F1",
    "phone": "\uF3F2",
    "phone-alert": "\uFF37",
    "phone-alert-outline": "\U000F01B9",
    "phone-bluetooth": "\uF3F3",
    "phone-bluetooth-outline": "\U000F01BA",
    "phone-cancel": "\U000F00E7",
    "phone-cancel-outline": "\U000F01BB",
    "phone-check": "\U000F01D4",
    "phone-check-outline": "\U000F01D5",
    "phone-classic": "\uF602",
    "phone-classic-off": "\U000F02A4",
    "phone-forward": "\uF3F4",
    "phone-forward-outline": "\U000F01BC",
    "phone-hangup": "\uF3F5",
    "phone-hangup-outline": "\U000F01BD",
    "phone-in-talk": "\uF3F6",
    "phone-in-talk-outline": "\U000F01AD",
    "phone-incoming": "\uF3F7",
    "phone-incoming-outline": "\U000F01BE",
    "phone-lock": "\uF3F8",
    "phone-lock-outline": "\U000F01BF",
    "phone-log": "\uF3F9",
    "phone-log-outline": "\U000F01C0",
    "phone-message": "\U000F01C1",
    "phone-message-outline": "\U000F01C2",
    "phone-minus": "\uF658",
    "phone-minus-outline": "\U000F01C3",
    "phone-missed": "\uF3FA",
    "phone-missed-outline": "\U000F01D0",
    "phone-off": "\uFDCB",
    "phone-off-outline": "\U000F01D1",
    "phone-outgoing": "\uF3FB",
    "phone-outgoing-outline": "\U000F01C4",
    "phone-outline": "\uFDCC",
    "phone-paused": "\uF3FC",
    "phone-paused-outline": "\U000F01C5",
    "phone-plus": "\uF659",
    "phone-plus-outline": "\U000F01C6",
    "phone-return": "\uF82E",
    "phone-return-outline": "\U000F01C7",
    "phone-ring": "\U000F01D6",
    "phone-ring-outline": "\U000F01D7",
    "phone-rotate-landscape": "\uF884",
    "phone-rotate-portrait": "\uF885",
    "phone-settings": "\uF3FD",
    "phone-settings-outline": "\U000F01C8",
    "phone-voip": "\uF3FE",
    "pi": "\uF3FF",
    "pi-box": "\uF400",
    "pi-hole": "\uFDCD",
    "piano": "\uF67C",
    "pickaxe": "\uF8B6",
    "picture-in-picture-bottom-right": "\uFE3A",
    "picture-in-picture-bottom-right-outline": "\uFE3B",
    "picture-in-picture-top-right": "\uFE3C",
    "picture-in-picture-top-right-outline": "\uFE3D",
    "pier": "\uF886",
    "pier-crane": "\uF887",
    "pig": "\uF401",
    "pig-variant": "\U000F0028",
    "piggy-bank": "\U000F0029",
    "pill": "\uF402",
    "pillar": "\uF701",
    "pin": "\uF403",
    "pin-off": "\uF404",
    "pin-off-outline": "\uF92F",
    "pin-outline": "\uF930",
    "pine-tree": "\uF405",
    "pine-tree-box": "\uF406",
    "pinterest": "\uF407",
    "pinterest-box": "\uF408",
    "pinwheel": "\uFAD4",
    "pinwheel-outline": "\uFAD5",
    "pipe": "\uF7E4",
    "pipe-disconnected": "\uF7E5",
    "pipe-leak": "\uF888",
    "pipe-wrench": "\U000F037F",
    "pirate": "\uFA07",
    "pistol": "\uF702",
    "piston": "\uF889",
    "pizza": "\uF409",
    "play": "\uF40A",
    "play-box": "\U000F02A5",
    "play-box-outline": "\uF40B",
    "play-circle": "\uF40C",
    "play-circle-outline": "\uF40D",
    "play-network": "\uF88A",
    "play-network-outline": "\uFC93",
    "play-outline": "\uFF38",
    "play-pause": "\uF40E",
    "play-protected-content": "\uF40F",
    "play-speed": "\uF8FE",
    "playlist-check": "\uF5C7",
    "playlist-edit": "\uF8FF",
    "playlist-minus": "\uF410",
    "playlist-music": "\uFC94",
    "playlist-music-outline": "\uFC95",
    "playlist-play": "\uF411",
    "playlist-plus": "\uF412",
    "playlist-remove": "\uF413",
    "playlist-star": "\uFDCE",
    "playstation": "\uF414",
    "plex": "\uF6B9",
    "plus": "\uF415",
    "plus-box": "\uF416",
    "plus-box-multiple": "\uF334",
    "plus-box-multiple-outline": "\U000F016E",
    "plus-box-outline": "\uF703",
    "plus-circle": "\uF417",
    "plus-circle-multiple-outline": "\uF418",
    "plus-circle-outline": "\uF419",
    "plus-minus": "\uF991",
    "plus-minus-box": "\uF992",
    "plus-network": "\uF41A",
    "plus-network-outline": "\uFC96",
    "plus-one": "\uF41B",
    "plus-outline": "\uF704",
    "plus-thick": "\U000F0217",
    "pocket": "\uF41C",
    "podcast": "\uF993",
    "podium": "\uFD01",
    "podium-bronze": "\uFD02",
    "podium-gold": "\uFD03",
    "podium-silver": "\uFD04",
    "point-of-sale": "\uFD6E",
    "pokeball": "\uF41D",
    "pokemon-go": "\uFA08",
    "poker-chip": "\uF82F",
    "polaroid": "\uF41E",
    "police-badge": "\U000F0192",
    "police-badge-outline": "\U000F0193",
    "poll": "\uF41F",
    "poll-box": "\uF420",
    "poll-box-outline": "\U000F02A6",
    "polymer": "\uF421",
    "pool": "\uF606",
    "popcorn": "\uF422",
    "post": "\U000F002A",
    "post-outline": "\U000F002B",
    "postage-stamp": "\uFC97",
    "pot": "\uF65A",
    "pot-mix": "\uF65B",
    "pound": "\uF423",
    "pound-box": "\uF424",
    "pound-box-outline": "\U000F01AA",
    "power": "\uF425",
    "power-cycle": "\uF900",
    "power-off": "\uF901",
    "power-on": "\uF902",
    "power-plug": "\uF6A4",
    "power-plug-off": "\uF6A5",
    "power-settings": "\uF426",
    "power-sleep": "\uF903",
    "power-socket": "\uF427",
    "power-socket-au": "\uF904",
    "power-socket-de": "\U000F0132",
    "power-socket-eu": "\uF7E6",
    "power-socket-fr": "\U000F0133",
    "power-socket-jp": "\U000F0134",
    "power-socket-uk": "\uF7E7",
    "power-socket-us": "\uF7E8",
    "power-standby": "\uF905",
    "powershell": "\uFA09",
    "prescription": "\uF705",
    "presentation": "\uF428",
    "presentation-play": "\uF429",
    "printer": "\uF42A",
    "printer-3d": "\uF42B",
    "printer-3d-nozzle": "\uFE3E",
    "printer-3d-nozzle-alert": "\U000F01EB",
    "printer-3d-nozzle-alert-outline": "\U000F01EC",
    "printer-3d-nozzle-outline": "\uFE3F",
    "printer-alert": "\uF42C",
    "printer-check": "\U000F0171",
    "printer-off": "\uFE40",
    "printer-pos": "\U000F0079",
    "printer-settings": "\uF706",
    "printer-wireless": "\uFA0A",
    "priority-high": "\uF603",
    "priority-low": "\uF604",
    "professional-hexagon": "\uF42D",
    "progress-alert": "\uFC98",
    "progress-check": "\uF994",
    "progress-clock": "\uF995",
    "progress-close": "\U000F0135",
    "progress-download": "\uF996",
    "progress-upload": "\uF997",
    "progress-wrench": "\uFC99",
    "projector": "\uF42E",
    "projector-screen": "\uF42F",
    "propane-tank": "\U000F0382",
    "propane-tank-outline": "\U000F0383",
    "protocol": "\uFFF9",
    "publish": "\uF6A6",
    "pulse": "\uF430",
    "pumpkin": "\uFB9B",
    "purse": "\uFF39",
    "purse-outline": "\uFF3A",
    "puzzle": "\uF431",
    "puzzle-outline": "\uFA65",
    "qi": "\uF998",
    "qqchat": "\uF605",
    "qrcode": "\uF432",
    "qrcode-edit": "\uF8B7",
    "qrcode-minus": "\U000F01B7",
    "qrcode-plus": "\U000F01B6",
    "qrcode-remove": "\U000F01B8",
    "qrcode-scan": "\uF433",
    "quadcopter": "\uF434",
    "quality-high": "\uF435",
    "quality-low": "\uFA0B",
    "quality-medium": "\uFA0C",
    "quicktime": "\uF436",
    "quora": "\uFD05",
    "rabbit": "\uF906",
    "racing-helmet": "\uFD6F",
    "racquetball": "\uFD70",
    "radar": "\uF437",
    "radiator": "\uF438",
    "radiator-disabled": "\uFAD6",
    "radiator-off": "\uFAD7",
    "radio": "\uF439",
    "radio-am": "\uFC9A",
    "radio-fm": "\uFC9B",
    "radio-handheld": "\uF43A",
    "radio-off": "\U000F0247",
    "radio-tower": "\uF43B",
    "radioactive": "\uF43C",
    "radioactive-off": "\uFEDE",
    "radiobox-blank": "\uF43D",
    "radiobox-marked": "\uF43E",
    "radius": "\uFC9C",
    "radius-outline": "\uFC9D",
    "railroad-light": "\uFF3B",
    "raspberry-pi": "\uF43F",
    "ray-end": "\uF440",
    "ray-end-arrow": "\uF441",
    "ray-start": "\uF442",
    "ray-start-arrow": "\uF443",
    "ray-start-end": "\uF444",
    "ray-vertex": "\uF445",
    "react": "\uF707",
    "read": "\uF447",
    "receipt": "\uF449",
    "record": "\uF44A",
    "record-circle": "\uFEDF",
    "record-circle-outline": "\uFEE0",
    "record-player": "\uF999",
    "record-rec": "\uF44B",
    "rectangle": "\uFE41",
    "rectangle-outline": "\uFE42",
    "recycle": "\uF44C",
    "reddit": "\uF44D",
    "redhat": "\U000F0146",
    "redo": "\uF44E",
    "redo-variant": "\uF44F",
    "reflect-horizontal": "\uFA0D",
    "reflect-vertical": "\uFA0E",
    "refresh": "\uF450",
    "refresh-circle": "\U000F03A2",
    "regex": "\uF451",
    "registered-trademark": "\uFA66",
    "relative-scale": "\uF452",
    "reload": "\uF453",
    "reload-alert": "\U000F0136",
    "reminder": "\uF88B",
    "remote": "\uF454",
    "remote-desktop": "\uF8B8",
    "remote-off": "\uFEE1",
    "remote-tv": "\uFEE2",
    "remote-tv-off": "\uFEE3",
    "rename-box": "\uF455",
    "reorder-horizontal": "\uF687",
    "reorder-vertical": "\uF688",
    "repeat": "\uF456",
    "repeat-off": "\uF457",
    "repeat-once": "\uF458",
    "replay": "\uF459",
    "reply": "\uF45A",
    "reply-all": "\uF45B",
    "reply-all-outline": "\uFF3C",
    "reply-circle": "\U000F01D9",
    "reply-outline": "\uFF3D",
    "reproduction": "\uF45C",
    "resistor": "\uFB1F",
    "resistor-nodes": "\uFB20",
    "resize": "\uFA67",
    "resize-bottom-right": "\uF45D",
    "responsive": "\uF45E",
    "restart": "\uF708",
    "restart-alert": "\U000F0137",
    "restart-off": "\uFD71",
    "restore": "\uF99A",
    "restore-alert": "\U000F0138",
    "rewind": "\uF45F",
    "rewind-10": "\uFD06",
    "rewind-30": "\uFD72",
    "rewind-5": "\U000F0224",
    "rewind-outline": "\uF709",
    "rhombus": "\uF70A",
    "rhombus-medium": "\uFA0F",
    "rhombus-outline": "\uF70B",
    "rhombus-split": "\uFA10",
    "ribbon": "\uF460",
    "rice": "\uF7E9",
    "ring": "\uF7EA",
    "rivet": "\uFE43",
    "road": "\uF461",
    "road-variant": "\uF462",
    "robber": "\U000F007A",
    "robot": "\uF6A8",
    "robot-industrial": "\uFB21",
    "robot-mower": "\U000F0222",
    "robot-mower-outline": "\U000F021E",
    "robot-vacuum": "\uF70C",
    "robot-vacuum-variant": "\uF907",
    "rocket": "\uF463",
    "rodent": "\U000F0352",
    "roller-skate": "\uFD07",
    "rollerblade": "\uFD08",
    "rollupjs": "\uFB9C",
    "roman-numeral-1": "\U000F00B3",
    "roman-numeral-10": "\U000F00BC",
    "roman-numeral-2": "\U000F00B4",
    "roman-numeral-3": "\U000F00B5",
    "roman-numeral-4": "\U000F00B6",
    "roman-numeral-5": "\U000F00B7",
    "roman-numeral-6": "\U000F00B8",
    "roman-numeral-7": "\U000F00B9",
    "roman-numeral-8": "\U000F00BA",
    "roman-numeral-9": "\U000F00BB",
    "room-service": "\uF88C",
    "room-service-outline": "\uFD73",
    "rotate-3d": "\uFEE4",
    "rotate-3d-variant": "\uF464",
    "rotate-left": "\uF465",
    "rotate-left-variant": "\uF466",
    "rotate-orbit": "\uFD74",
    "rotate-right": "\uF467",
    "rotate-right-variant": "\uF468",
    "rounded-corner": "\uF607",
    "router": "\U000F020D",
    "router-wireless": "\uF469",
    "router-wireless-settings": "\uFA68",
    "routes": "\uF46A",
    "routes-clock": "\U000F007B",
    "rowing": "\uF608",
    "rss": "\uF46B",
    "rss-box": "\uF46C",
    "rss-off": "\uFF3E",
    "ruby": "\uFD09",
    "rugby": "\uFD75",
    "ruler": "\uF46D",
    "ruler-square": "\uFC9E",
    "ruler-square-compass": "\uFEDB",
    "run": "\uF70D",
    "run-fast": "\uF46E",
    "rv-truck": "\U000F01FF",
    "sack": "\uFD0A",
    "sack-percent": "\uFD0B",
    "safe": "\uFA69",
    "safe-square": "\U000F02A7",
    "safe-square-outline": "\U000F02A8",
    "safety-goggles": "\uFD0C",
    "sailing": "\uFEE5",
    "sale": "\uF46F",
    "salesforce": "\uF88D",
    "sass": "\uF7EB",
    "satellite": "\uF470",
    "satellite-uplink": "\uF908",
    "satellite-variant": "\uF471",
    "sausage": "\uF8B9",
    "saw-blade": "\uFE44",
    "saxophone": "\uF609",
    "scale": "\uF472",
    "scale-balance": "\uF5D1",
    "scale-bathroom": "\uF473",
    "scale-off": "\U000F007C",
    "scanner": "\uF6AA",
    "scanner-off": "\uF909",
    "scatter-plot": "\uFEE6",
    "scatter-plot-outline": "\uFEE7",
    "school": "\uF474",
    "school-outline": "\U000F01AB",
    "scissors-cutting": "\uFA6A",
    "scooter": "\U000F0214",
    "scoreboard": "\U000F02A9",
    "scoreboard-outline": "\U000F02AA",
    "screen-rotation": "\uF475",
    "screen-rotation-lock": "\uF476",
    "screw-flat-top": "\uFDCF",
    "screw-lag": "\uFE54",
    "screw-machine-flat-top": "\uFE55",
    "screw-machine-round-top": "\uFE56",
    "screw-round-top": "\uFE57",
    "screwdriver": "\uF477",
    "script": "\uFB9D",
    "script-outline": "\uF478",
    "script-text": "\uFB9E",
    "script-text-outline": "\uFB9F",
    "sd": "\uF479",
    "seal": "\uF47A",
    "seal-variant": "\uFFFA",
    "search-web": "\uF70E",
    "seat": "\uFC9F",
    "seat-flat": "\uF47B",
    "seat-flat-angled": "\uF47C",
    "seat-individual-suite": "\uF47D",
    "seat-legroom-extra": "\uF47E",
    "seat-legroom-normal": "\uF47F",
    "seat-legroom-reduced": "\uF480",
    "seat-outline": "\uFCA0",
    "seat-passenger": "\U000F0274",
    "seat-recline-extra": "\uF481",
    "seat-recline-normal": "\uF482",
    "seatbelt": "\uFCA1",
    "security": "\uF483",
    "security-network": "\uF484",
    "seed": "\uFE45",
    "seed-outline": "\uFE46",
    "segment": "\uFEE8",
    "select": "\uF485",
    "select-all": "\uF486",
    "select-color": "\uFD0D",
    "select-compare": "\uFAD8",
    "select-drag": "\uFA6B",
    "select-group": "\uFF9F",
    "select-inverse": "\uF487",
    "select-marker": "\U000F02AB",
    "select-multiple": "\U000F02AC",
    "select-multiple-marker": "\U000F02AD",
    "select-off": "\uF488",
    "select-place": "\uFFFB",
    "select-search": "\U000F022F",
    "selection": "\uF489",
    "selection-drag": "\uFA6C",
    "selection-ellipse": "\uFD0E",
    "selection-ellipse-arrow-inside": "\uFF3F",
    "selection-marker": "\U000F02AE",
    "selection-multiple-marker": "\U000F02AF",
    "selection-mutliple": "\U000F02B0",
    "selection-off": "\uF776",
    "selection-search": "\U000F0230",
    "semantic-web": "\U000F0341",
    "send": "\uF48A",
    "send-check": "\U000F018C",
    "send-check-outline": "\U000F018D",
    "send-circle": "\uFE58",
    "send-circle-outline": "\uFE59",
    "send-clock": "\U000F018E",
    "send-clock-outline": "\U000F018F",
    "send-lock": "\uF7EC",
    "send-lock-outline": "\U000F0191",
    "send-outline": "\U000F0190",
    "serial-port": "\uF65C",
    "server": "\uF48B",
    "server-minus": "\uF48C",
    "server-network": "\uF48D",
    "server-network-off": "\uF48E",
    "server-off": "\uF48F",
    "server-plus": "\uF490",
    "server-remove": "\uF491",
    "server-security": "\uF492",
    "set-all": "\uF777",
    "set-center": "\uF778",
    "set-center-right": "\uF779",
    "set-left": "\uF77A",
    "set-left-center": "\uF77B",
    "set-left-right": "\uF77C",
    "set-none": "\uF77D",
    "set-right": "\uF77E",
    "set-top-box": "\uF99E",
    "settings": "\uF493",
    "settings-box": "\uF494",
    "settings-helper": "\uFA6D",
    "settings-outline": "\uF8BA",
    "settings-transfer": "\U000F007D",
    "settings-transfer-outline": "\U000F007E",
    "shaker": "\U000F0139",
    "shaker-outline": "\U000F013A",
    "shape": "\uF830",
    "shape-circle-plus": "\uF65D",
    "shape-outline": "\uF831",
    "shape-oval-plus": "\U000F0225",
    "shape-plus": "\uF495",
    "shape-polygon-plus": "\uF65E",
    "shape-rectangle-plus": "\uF65F",
    "shape-square-plus": "\uF660",
    "share": "\uF496",
    "share-all": "\U000F021F",
    "share-all-outline": "\U000F0220",
    "share-circle": "\U000F01D8",
    "share-off": "\uFF40",
    "share-off-outline": "\uFF41",
    "share-outline": "\uF931",
    "share-variant": "\uF497",
    "sheep": "\uFCA2",
    "shield": "\uF498",
    "shield-account": "\uF88E",
    "shield-account-outline": "\uFA11",
    "shield-airplane": "\uF6BA",
    "shield-airplane-outline": "\uFCA3",
    "shield-alert": "\uFEE9",
    "shield-alert-outline": "\uFEEA",
    "shield-car": "\uFFA0",
    "shield-check": "\uF565",
    "shield-check-outline": "\uFCA4",
    "shield-cross": "\uFCA5",
    "shield-cross-outline": "\uFCA6",
    "shield-edit": "\U000F01CB",
    "shield-edit-outline": "\U000F01CC",
    "shield-half": "\U000F038B",
    "shield-half-full": "\uF77F",
    "shield-home": "\uF689",
    "shield-home-outline": "\uFCA7",
    "shield-key": "\uFBA0",
    "shield-key-outline": "\uFBA1",
    "shield-link-variant": "\uFD0F",
    "shield-link-variant-outline": "\uFD10",
    "shield-lock": "\uF99C",
    "shield-lock-outline": "\uFCA8",
    "shield-off": "\uF99D",
    "shield-off-outline": "\uF99B",
    "shield-outline": "\uF499",
    "shield-plus": "\uFAD9",
    "shield-plus-outline": "\uFADA",
    "shield-refresh": "\U000F01CD",
    "shield-refresh-outline": "\U000F01CE",
    "shield-remove": "\uFADB",
    "shield-remove-outline": "\uFADC",
    "shield-search": "\uFD76",
    "shield-star": "\U000F0166",
    "shield-star-outline": "\U000F0167",
    "shield-sun": "\U000F007F",
    "shield-sun-outline": "\U000F0080",
    "ship-wheel": "\uF832",
    "shoe-formal": "\uFB22",
    "shoe-heel": "\uFB23",
    "shoe-print": "\uFE5A",
    "shopify": "\uFADD",
    "shopping": "\uF49A",
    "shopping-music": "\uF49B",
    "shopping-outline": "\U000F0200",
    "shopping-search": "\uFFA1",
    "shovel": "\uF70F",
    "shovel-off": "\uF710",
    "shower": "\uF99F",
    "shower-head": "\uF9A0",
    "shredder": "\uF49C",
    "shuffle": "\uF49D",
    "shuffle-disabled": "\uF49E",
    "shuffle-variant": "\uF49F",
    "shuriken": "\U000F03AA",
    "sigma": "\uF4A0",
    "sigma-lower": "\uF62B",
    "sign-caution": "\uF4A1",
    "sign-direction": "\uF780",
    "sign-direction-minus": "\U000F0022",
    "sign-direction-plus": "\uFFFD",
    "sign-direction-remove": "\uFFFE",
    "sign-real-estate": "\U000F0143",
    "sign-text": "\uF781",
    "signal": "\uF4A2",
    "signal-2g": "\uF711",
    "signal-3g": "\uF712",
    "signal-4g": "\uF713",
    "signal-5g": "\uFA6E",
    "signal-cellular-1": "\uF8BB",
    "signal-cellular-2": "\uF8BC",
    "signal-cellular-3": "\uF8BD",
    "signal-cellular-outline": "\uF8BE",
    "signal-distance-variant": "\uFE47",
    "signal-hspa": "\uF714",
    "signal-hspa-plus": "\uF715",
    "signal-off": "\uF782",
    "signal-variant": "\uF60A",
    "signature": "\uFE5B",
    "signature-freehand": "\uFE5C",
    "signature-image": "\uFE5D",
    "signature-text": "\uFE5E",
    "silo": "\uFB24",
    "silverware": "\uF4A3",
    "silverware-clean": "\uFFFF",
    "silverware-fork": "\uF4A4",
    "silverware-fork-knife": "\uFA6F",
    "silverware-spoon": "\uF4A5",
    "silverware-variant": "\uF4A6",
    "sim": "\uF4A7",
    "sim-alert": "\uF4A8",
    "sim-off": "\uF4A9",
    "simple-icons": "\U000F0348",
    "sina-weibo": "\uFADE",
    "sitemap": "\uF4AA",
    "skate": "\uFD11",
    "skew-less": "\uFD12",
    "skew-more": "\uFD13",
    "ski": "\U000F032F",
    "ski-cross-country": "\U000F0330",
    "ski-water": "\U000F0331",
    "skip-backward": "\uF4AB",
    "skip-backward-outline": "\uFF42",
    "skip-forward": "\uF4AC",
    "skip-forward-outline": "\uFF43",
    "skip-next": "\uF4AD",
    "skip-next-circle": "\uF661",
    "skip-next-circle-outline": "\uF662",
    "skip-next-outline": "\uFF44",
    "skip-previous": "\uF4AE",
    "skip-previous-circle": "\uF663",
    "skip-previous-circle-outline": "\uF664",
    "skip-previous-outline": "\uFF45",
    "skull": "\uF68B",
    "skull-crossbones": "\uFBA2",
    "skull-crossbones-outline": "\uFBA3",
    "skull-outline": "\uFBA4",
    "skype": "\uF4AF",
    "skype-business": "\uF4B0",
    "slack": "\uF4B1",
    "slackware": "\uF90A",
    "slash-forward": "\U000F0000",
    "slash-forward-box": "\U000F0001",
    "sleep": "\uF4B2",
    "sleep-off": "\uF4B3",
    "slope-downhill": "\uFE5F",
    "slope-uphill": "\uFE60",
    "slot-machine": "\U000F013F",
    "slot-machine-outline": "\U000F0140",
    "smart-card": "\U000F00E8",
    "smart-card-outline": "\U000F00E9",
    "smart-card-reader": "\U000F00EA",
    "smart-card-reader-outline": "\U000F00EB",
    "smog": "\uFA70",
    "smoke-detector": "\uF392",
    "smoking": "\uF4B4",
    "smoking-off": "\uF4B5",
    "snapchat": "\uF4B6",
    "snowboard": "\U000F0332",
    "snowflake": "\uF716",
    "snowflake-alert": "\uFF46",
    "snowflake-melt": "\U000F02F6",
    "snowflake-variant": "\uFF47",
    "snowman": "\uF4B7",
    "soccer": "\uF4B8",
    "soccer-field": "\uF833",
    "sofa": "\uF4B9",
    "solar-panel": "\uFD77",
    "solar-panel-large": "\uFD78",
    "solar-power": "\uFA71",
    "soldering-iron": "\U000F00BD",
    "solid": "\uF68C",
    "sort": "\uF4BA",
    "sort-alphabetical": "\uF4BB",
    "sort-alphabetical-ascending": "\U000F0173",
    "sort-alphabetical-descending": "\U000F0174",
    "sort-ascending": "\uF4BC",
    "sort-descending": "\uF4BD",
    "sort-numeric": "\uF4BE",
    "sort-variant": "\uF4BF",
    "sort-variant-lock": "\uFCA9",
    "sort-variant-lock-open": "\uFCAA",
    "sort-variant-remove": "\U000F0172",
    "soundcloud": "\uF4C0",
    "source-branch": "\uF62C",
    "source-commit": "\uF717",
    "source-commit-end": "\uF718",
    "source-commit-end-local": "\uF719",
    "source-commit-local": "\uF71A",
    "source-commit-next-local": "\uF71B",
    "source-commit-start": "\uF71C",
    "source-commit-start-next-local": "\uF71D",
    "source-fork": "\uF4C1",
    "source-merge": "\uF62D",
    "source-pull": "\uF4C2",
    "source-repository": "\uFCAB",
    "source-repository-multiple": "\uFCAC",
    "soy-sauce": "\uF7ED",
    "spa": "\uFCAD",
    "spa-outline": "\uFCAE",
    "space-invaders": "\uFBA5",
    "space-station": "\U000F03AE",
    "spade": "\uFE48",
    "speaker": "\uF4C3",
    "speaker-bluetooth": "\uF9A1",
    "speaker-multiple": "\uFD14",
    "speaker-off": "\uF4C4",
    "speaker-wireless": "\uF71E",
    "speedometer": "\uF4C5",
    "speedometer-medium": "\uFFA2",
    "speedometer-slow": "\uFFA3",
    "spellcheck": "\uF4C6",
    "spider": "\U000F0215",
    "spider-thread": "\U000F0216",
    "spider-web": "\uFBA6",
    "spotify": "\uF4C7",
    "spotlight": "\uF4C8",
    "spotlight-beam": "\uF4C9",
    "spray": "\uF665",
    "spray-bottle": "\uFADF",
    "sprinkler": "\U000F0081",
    "sprinkler-variant": "\U000F0082",
    "sprout": "\uFE49",
    "sprout-outline": "\uFE4A",
    "square": "\uF763",
    "square-edit-outline": "\uF90B",
    "square-inc": "\uF4CA",
    "square-inc-cash": "\uF4CB",
    "square-medium": "\uFA12",
    "square-medium-outline": "\uFA13",
    "square-off": "\U000F0319",
    "square-off-outline": "\U000F031A",
    "square-outline": "\uF762",
    "square-root": "\uF783",
    "square-root-box": "\uF9A2",
    "square-small": "\uFA14",
    "squeegee": "\uFAE0",
    "ssh": "\uF8BF",
    "stack-exchange": "\uF60B",
    "stack-overflow": "\uF4CC",
    "stackpath": "\uF359",
    "stadium": "\U000F001A",
    "stadium-variant": "\uF71F",
    "stairs": "\uF4CD",
    "stairs-down": "\U000F02E9",
    "stairs-up": "\U000F02E8",
    "stamper": "\uFD15",
    "standard-definition": "\uF7EE",
    "star": "\uF4CE",
    "star-box": "\uFA72",
    "star-box-multiple": "\U000F02B1",
    "star-box-multiple-outline": "\U000F02B2",
    "star-box-outline": "\uFA73",
    "star-circle": "\uF4CF",
    "star-circle-outline": "\uF9A3",
    "star-face": "\uF9A4",
    "star-four-points": "\uFAE1",
    "star-four-points-outline": "\uFAE2",
    "star-half": "\uF4D0",
    "star-off": "\uF4D1",
    "star-outline": "\uF4D2",
    "star-three-points": "\uFAE3",
    "star-three-points-outline": "\uFAE4",
    "state-machine": "\U000F021A",
    "steam": "\uF4D3",
    "steam-box": "\uF90C",
    "steering": "\uF4D4",
    "steering-off": "\uF90D",
    "step-backward": "\uF4D5",
    "step-backward-2": "\uF4D6",
    "step-forward": "\uF4D7",
    "step-forward-2": "\uF4D8",
    "stethoscope": "\uF4D9",
    "sticker": "\U000F038F",
    "sticker-alert": "\U000F0390",
    "sticker-alert-outline": "\U000F0391",
    "sticker-check": "\U000F0392",
    "sticker-check-outline": "\U000F0393",
    "sticker-circle-outline": "\uF5D0",
    "sticker-emoji": "\uF784",
    "sticker-minus": "\U000F0394",
    "sticker-minus-outline": "\U000F0395",
    "sticker-outline": "\U000F0396",
    "sticker-plus": "\U000F0397",
    "sticker-plus-outline": "\U000F0398",
    "sticker-remove": "\U000F0399",
    "sticker-remove-outline": "\U000F039A",
    "stocking": "\uF4DA",
    "stomach": "\U000F00BE",
    "stop": "\uF4DB",
    "stop-circle": "\uF666",
    "stop-circle-outline": "\uF667",
    "store": "\uF4DC",
    "store-24-hour": "\uF4DD",
    "store-outline": "\U000F038C",
    "storefront": "\U000F00EC",
    "stove": "\uF4DE",
    "strategy": "\U000F0201",
    "strava": "\uFB25",
    "stretch-to-page": "\uFF48",
    "stretch-to-page-outline": "\uFF49",
    "string-lights": "\U000F02E5",
    "string-lights-off": "\U000F02E6",
    "subdirectory-arrow-left": "\uF60C",
    "subdirectory-arrow-right": "\uF60D",
    "subtitles": "\uFA15",
    "subtitles-outline": "\uFA16",
    "subway": "\uF6AB",
    "subway-alert-variant": "\uFD79",
    "subway-variant": "\uF4DF",
    "summit": "\uF785",
    "sunglasses": "\uF4E0",
    "surround-sound": "\uF5C5",
    "surround-sound-2-0": "\uF7EF",
    "surround-sound-3-1": "\uF7F0",
    "surround-sound-5-1": "\uF7F1",
    "surround-sound-7-1": "\uF7F2",
    "svg": "\uF720",
    "swap-horizontal": "\uF4E1",
    "swap-horizontal-bold": "\uFBA9",
    "swap-horizontal-circle": "\U000F0002",
    "swap-horizontal-circle-outline": "\U000F0003",
    "swap-horizontal-variant": "\uF8C0",
    "swap-vertical": "\uF4E2",
    "swap-vertical-bold": "\uFBAA",
    "swap-vertical-circle": "\U000F0004",
    "swap-vertical-circle-outline": "\U000F0005",
    "swap-vertical-variant": "\uF8C1",
    "swim": "\uF4E3",
    "switch": "\uF4E4",
    "sword": "\uF4E5",
    "sword-cross": "\uF786",
    "syllabary-hangul": "\U000F035E",
    "syllabary-hiragana": "\U000F035F",
    "syllabary-katakana": "\U000F0360",
    "syllabary-katakana-half-width": "\U000F0361",
    "symfony": "\uFAE5",
    "sync": "\uF4E6",
    "sync-alert": "\uF4E7",
    "sync-circle": "\U000F03A3",
    "sync-off": "\uF4E8",
    "tab": "\uF4E9",
    "tab-minus": "\uFB26",
    "tab-plus": "\uF75B",
    "tab-remove": "\uFB27",
    "tab-unselected": "\uF4EA",
    "table": "\uF4EB",
    "table-border": "\uFA17",
    "table-chair": "\U000F0083",
    "table-column": "\uF834",
    "table-column-plus-after": "\uF4EC",
    "table-column-plus-before": "\uF4ED",
    "table-column-remove": "\uF4EE",
    "table-column-width": "\uF4EF",
    "table-edit": "\uF4F0",
    "table-eye": "\U000F00BF",
    "table-headers-eye": "\U000F0248",
    "table-headers-eye-off": "\U000F0249",
    "table-large": "\uF4F1",
    "table-large-plus": "\uFFA4",
    "table-large-remove": "\uFFA5",
    "table-merge-cells": "\uF9A5",
    "table-of-contents": "\uF835",
    "table-plus": "\uFA74",
    "table-remove": "\uFA75",
    "table-row": "\uF836",
    "table-row-height": "\uF4F2",
    "table-row-plus-after": "\uF4F3",
    "table-row-plus-before": "\uF4F4",
    "table-row-remove": "\uF4F5",
    "table-search": "\uF90E",
    "table-settings": "\uF837",
    "table-tennis": "\uFE4B",
    "tablet": "\uF4F6",
    "tablet-android": "\uF4F7",
    "tablet-cellphone": "\uF9A6",
    "tablet-dashboard": "\uFEEB",
    "tablet-ipad": "\uF4F8",
    "taco": "\uF761",
    "tag": "\uF4F9",
    "tag-faces": "\uF4FA",
    "tag-heart": "\uF68A",
    "tag-heart-outline": "\uFBAB",
    "tag-minus": "\uF90F",
    "tag-minus-outline": "\U000F024A",
    "tag-multiple": "\uF4FB",
    "tag-multiple-outline": "\U000F0322",
    "tag-off": "\U000F024B",
    "tag-off-outline": "\U000F024C",
    "tag-outline": "\uF4FC",
    "tag-plus": "\uF721",
    "tag-plus-outline": "\U000F024D",
    "tag-remove": "\uF722",
    "tag-remove-outline": "\U000F024E",
    "tag-text": "\U000F024F",
    "tag-text-outline": "\uF4FD",
    "tank": "\uFD16",
    "tanker-truck": "\U000F0006",
    "tape-measure": "\uFB28",
    "target": "\uF4FE",
    "target-account": "\uFBAC",
    "target-variant": "\uFA76",
    "taxi": "\uF4FF",
    "tea": "\uFD7A",
    "tea-outline": "\uFD7B",
    "teach": "\uF88F",
    "teamviewer": "\uF500",
    "telegram": "\uF501",
    "telescope": "\uFB29",
    "television": "\uF502",
    "television-ambient-light": "\U000F0381",
    "television-box": "\uF838",
    "television-classic": "\uF7F3",
    "television-classic-off": "\uF839",
    "television-clean": "\U000F013B",
    "television-guide": "\uF503",
    "television-off": "\uF83A",
    "television-pause": "\uFFA6",
    "television-play": "\uFEEC",
    "television-stop": "\uFFA7",
    "temperature-celsius": "\uF504",
    "temperature-fahrenheit": "\uF505",
    "temperature-kelvin": "\uF506",
    "tennis": "\uFD7C",
    "tennis-ball": "\uF507",
    "tent": "\uF508",
    "terraform": "\U000F0084",
    "terrain": "\uF509",
    "test-tube": "\uF668",
    "test-tube-empty": "\uF910",
    "test-tube-off": "\uF911",
    "text": "\uF9A7",
    "text-recognition": "\U000F0168",
    "text-shadow": "\uF669",
    "text-short": "\uF9A8",
    "text-subject": "\uF9A9",
    "text-to-speech": "\uF50A",
    "text-to-speech-off": "\uF50B",
    "textarea": "\U000F00C0",
    "textbox": "\uF60E",
    "textbox-lock": "\U000F0388",
    "textbox-password": "\uF7F4",
    "texture": "\uF50C",
    "texture-box": "\U000F0007",
    "theater": "\uF50D",
    "theme-light-dark": "\uF50E",
    "thermometer": "\uF50F",
    "thermometer-alert": "\uFE61",
    "thermometer-chevron-down": "\uFE62",
    "thermometer-chevron-up": "\uFE63",
    "thermometer-high": "\U000F00ED",
    "thermometer-lines": "\uF510",
    "thermometer-low": "\U000F00EE",
    "thermometer-minus": "\uFE64",
    "thermometer-plus": "\uFE65",
    "thermostat": "\uF393",
    "thermostat-box": "\uF890",
    "thought-bubble": "\uF7F5",
    "thought-bubble-outline": "\uF7F6",
    "thumb-down": "\uF511",
    "thumb-down-outline": "\uF512",
    "thumb-up": "\uF513",
    "thumb-up-outline": "\uF514",
    "thumbs-up-down": "\uF515",
    "ticket": "\uF516",
    "ticket-account": "\uF517",
    "ticket-confirmation": "\uF518",
    "ticket-outline": "\uF912",
    "ticket-percent": "\uF723",
    "tie": "\uF519",
    "tilde": "\uF724",
    "timelapse": "\uF51A",
    "timeline": "\uFBAD",
    "timeline-alert": "\uFFB2",
    "timeline-alert-outline": "\uFFB5",
    "timeline-clock": "\U000F0226",
    "timeline-clock-outline": "\U000F0227",
    "timeline-help": "\uFFB6",
    "timeline-help-outline": "\uFFB7",
    "timeline-outline": "\uFBAE",
    "timeline-plus": "\uFFB3",
    "timeline-plus-outline": "\uFFB4",
    "timeline-text": "\uFBAF",
    "timeline-text-outline": "\uFBB0",
    "timer": "\uF51B",
    "timer-10": "\uF51C",
    "timer-3": "\uF51D",
    "timer-off": "\uF51E",
    "timer-sand": "\uF51F",
    "timer-sand-empty": "\uF6AC",
    "timer-sand-full": "\uF78B",
    "timetable": "\uF520",
    "toaster": "\U000F0085",
    "toaster-off": "\U000F01E2",
    "toaster-oven": "\uFCAF",
    "toggle-switch": "\uF521",
    "toggle-switch-off": "\uF522",
    "toggle-switch-off-outline": "\uFA18",
    "toggle-switch-outline": "\uFA19",
    "toilet": "\uF9AA",
    "toolbox": "\uF9AB",
    "toolbox-outline": "\uF9AC",
    "tools": "\U000F0086",
    "tooltip": "\uF523",
    "tooltip-account": "\uF00C",
    "tooltip-edit": "\uF524",
    "tooltip-edit-outline": "\U000F02F0",
    "tooltip-image": "\uF525",
    "tooltip-image-outline": "\uFBB1",
    "tooltip-outline": "\uF526",
    "tooltip-plus": "\uFBB2",
    "tooltip-plus-outline": "\uF527",
    "tooltip-text": "\uF528",
    "tooltip-text-outline": "\uFBB3",
    "tooth": "\uF8C2",
    "tooth-outline": "\uF529",
    "toothbrush": "\U000F0154",
    "toothbrush-electric": "\U000F0157",
    "toothbrush-paste": "\U000F0155",
    "tor": "\uF52A",
    "tortoise": "\uFD17",
    "toslink": "\U000F02E3",
    "tournament": "\uF9AD",
    "tower-beach": "\uF680",
    "tower-fire": "\uF681",
    "towing": "\uF83B",
    "toy-brick": "\U000F02B3",
    "toy-brick-marker": "\U000F02B4",
    "toy-brick-marker-outline": "\U000F02B5",
    "toy-brick-minus": "\U000F02B6",
    "toy-brick-minus-outline": "\U000F02B7",
    "toy-brick-outline": "\U000F02B8",
    "toy-brick-plus": "\U000F02B9",
    "toy-brick-plus-outline": "\U000F02BA",
    "toy-brick-remove": "\U000F02BB",
    "toy-brick-remove-outline": "\U000F02BC",
    "toy-brick-search": "\U000F02BD",
    "toy-brick-search-outline": "\U000F02BE",
    "track-light": "\uF913",
    "trackpad": "\uF7F7",
    "trackpad-lock": "\uF932",
    "tractor": "\uF891",
    "trademark": "\uFA77",
    "traffic-cone": "\U000F03A7",
    "traffic-light": "\uF52B",
    "train": "\uF52C",
    "train-car": "\uFBB4",
    "train-variant": "\uF8C3",
    "tram": "\uF52D",
    "tram-side": "\U000F0008",
    "transcribe": "\uF52E",
    "transcribe-close": "\uF52F",
    "transfer": "\U000F0087",
    "transfer-down": "\uFD7D",
    "transfer-left": "\uFD7E",
    "transfer-right": "\uF530",
    "transfer-up": "\uFD7F",
    "transit-connection": "\uFD18",
    "transit-connection-variant": "\uFD19",
    "transit-detour": "\uFFA8",
    "transit-transfer": "\uF6AD",
    "transition": "\uF914",
    "transition-masked": "\uF915",
    "translate": "\uF5CA",
    "translate-off": "\uFE66",
    "transmission-tower": "\uFD1A",
    "trash-can": "\uFA78",
    "trash-can-outline": "\uFA79",
    "tray": "\U000F02BF",
    "tray-alert": "\U000F02C0",
    "tray-full": "\U000F02C1",
    "tray-minus": "\U000F02C2",
    "tray-plus": "\U000F02C3",
    "tray-remove": "\U000F02C4",
    "treasure-chest": "\uF725",
    "tree": "\uF531",
    "tree-outline": "\uFE4C",
    "trello": "\uF532",
    "trending-down": "\uF533",
    "trending-neutral": "\uF534",
    "trending-up": "\uF535",
    "triangle": "\uF536",
    "triangle-outline": "\uF537",
    "triforce": "\uFBB5",
    "trophy": "\uF538",
    "trophy-award": "\uF539",
    "trophy-broken": "\uFD80",
    "trophy-outline": "\uF53A",
    "trophy-variant": "\uF53B",
    "trophy-variant-outline": "\uF53C",
    "truck": "\uF53D",
    "truck-check": "\uFCB0",
    "truck-check-outline": "\U000F02C5",
    "truck-delivery": "\uF53E",
    "truck-delivery-outline": "\U000F02C6",
    "truck-fast": "\uF787",
    "truck-fast-outline": "\U000F02C7",
    "truck-outline": "\U000F02C8",
    "truck-trailer": "\uF726",
    "trumpet": "\U000F00C1",
    "tshirt-crew": "\uFA7A",
    "tshirt-crew-outline": "\uF53F",
    "tshirt-v": "\uFA7B",
    "tshirt-v-outline": "\uF540",
    "tumble-dryer": "\uF916",
    "tumble-dryer-alert": "\U000F01E5",
    "tumble-dryer-off": "\U000F01E6",
    "tumblr": "\uF541",
    "tumblr-box": "\uF917",
    "tumblr-reblog": "\uF542",
    "tune": "\uF62E",
    "tune-vertical": "\uF66A",
    "turnstile": "\uFCB1",
    "turnstile-outline": "\uFCB2",
    "turtle": "\uFCB3",
    "twitch": "\uF543",
    "twitter": "\uF544",
    "twitter-box": "\uF545",
    "twitter-circle": "\uF546",
    "twitter-retweet": "\uF547",
    "two-factor-authentication": "\uF9AE",
    "typewriter": "\uFF4A",
    "uber": "\uF748",
    "ubisoft": "\uFBB6",
    "ubuntu": "\uF548",
    "ufo": "\U000F00EF",
    "ufo-outline": "\U000F00F0",
    "ultra-high-definition": "\uF7F8",
    "umbraco": "\uF549",
    "umbrella": "\uF54A",
    "umbrella-closed": "\uF9AF",
    "umbrella-outline": "\uF54B",
    "undo": "\uF54C",
    "undo-variant": "\uF54D",
    "unfold-less-horizontal": "\uF54E",
    "unfold-less-vertical": "\uF75F",
    "unfold-more-horizontal": "\uF54F",
    "unfold-more-vertical": "\uF760",
    "ungroup": "\uF550",
    "unicode": "\uFEED",
    "unity": "\uF6AE",
    "unreal": "\uF9B0",
    "untappd": "\uF551",
    "update": "\uF6AF",
    "upload": "\uF552",
    "upload-lock": "\U000F039E",
    "upload-lock-outline": "\U000F039F",
    "upload-multiple": "\uF83C",
    "upload-network": "\uF6F5",
    "upload-network-outline": "\uFCB4",
    "upload-off": "\U000F00F1",
    "upload-off-outline": "\U000F00F2",
    "upload-outline": "\uFE67",
    "usb": "\uF553",
    "usb-flash-drive": "\U000F02C9",
    "usb-flash-drive-outline": "\U000F02CA",
    "usb-port": "\U000F021B",
    "valve": "\U000F0088",
    "valve-closed": "\U000F0089",
    "valve-open": "\U000F008A",
    "van-passenger": "\uF7F9",
    "van-utility": "\uF7FA",
    "vanish": "\uF7FB",
    "vanity-light": "\U000F020C",
    "variable": "\uFAE6",
    "variable-box": "\U000F013C",
    "vector-arrange-above": "\uF554",
    "vector-arrange-below": "\uF555",
    "vector-bezier": "\uFAE7",
    "vector-circle": "\uF556",
    "vector-circle-variant": "\uF557",
    "vector-combine": "\uF558",
    "vector-curve": "\uF559",
    "vector-difference": "\uF55A",
    "vector-difference-ab": "\uF55B",
    "vector-difference-ba": "\uF55C",
    "vector-ellipse": "\uF892",
    "vector-intersection": "\uF55D",
    "vector-line": "\uF55E",
    "vector-link": "\U000F0009",
    "vector-point": "\uF55F",
    "vector-polygon": "\uF560",
    "vector-polyline": "\uF561",
    "vector-polyline-edit": "\U000F0250",
    "vector-polyline-minus": "\U000F0251",
    "vector-polyline-plus": "\U000F0252",
    "vector-polyline-remove": "\U000F0253",
    "vector-radius": "\uF749",
    "vector-rectangle": "\uF5C6",
    "vector-selection": "\uF562",
    "vector-square": "\uF001",
    "vector-triangle": "\uF563",
    "vector-union": "\uF564",
    "venmo": "\uF578",
    "vhs": "\uFA1A",
    "vibrate": "\uF566",
    "vibrate-off": "\uFCB5",
    "video": "\uF567",
    "video-3d": "\uF7FC",
    "video-3d-variant": "\uFEEE",
    "video-4k-box": "\uF83D",
    "video-account": "\uF918",
    "video-check": "\U000F008B",
    "video-check-outline": "\U000F008C",
    "video-image": "\uF919",
    "video-input-antenna": "\uF83E",
    "video-input-component": "\uF83F",
    "video-input-hdmi": "\uF840",
    "video-input-scart": "\uFFA9",
    "video-input-svideo": "\uF841",
    "video-minus": "\uF9B1",
    "video-off": "\uF568",
    "video-off-outline": "\uFBB7",
    "video-outline": "\uFBB8",
    "video-plus": "\uF9B2",
    "video-stabilization": "\uF91A",
    "video-switch": "\uF569",
    "video-vintage": "\uFA1B",
    "video-wireless": "\uFEEF",
    "video-wireless-outline": "\uFEF0",
    "view-agenda": "\uF56A",
    "view-agenda-outline": "\U000F0203",
    "view-array": "\uF56B",
    "view-carousel": "\uF56C",
    "view-column": "\uF56D",
    "view-comfy": "\uFE4D",
    "view-compact": "\uFE4E",
    "view-compact-outline": "\uFE4F",
    "view-dashboard": "\uF56E",
    "view-dashboard-outline": "\uFA1C",
    "view-dashboard-variant": "\uF842",
    "view-day": "\uF56F",
    "view-grid": "\uF570",
    "view-grid-outline": "\U000F0204",
    "view-grid-plus": "\uFFAA",
    "view-grid-plus-outline": "\U000F0205",
    "view-headline": "\uF571",
    "view-list": "\uF572",
    "view-module": "\uF573",
    "view-parallel": "\uF727",
    "view-quilt": "\uF574",
    "view-sequential": "\uF728",
    "view-split-horizontal": "\uFBA7",
    "view-split-vertical": "\uFBA8",
    "view-stream": "\uF575",
    "view-week": "\uF576",
    "vimeo": "\uF577",
    "violin": "\uF60F",
    "virtual-reality": "\uF893",
    "visual-studio": "\uF610",
    "visual-studio-code": "\uFA1D",
    "vk": "\uF579",
    "vk-box": "\uF57A",
    "vk-circle": "\uF57B",
    "vlc": "\uF57C",
    "voice": "\uF5CB",
    "voice-off": "\uFEF1",
    "voicemail": "\uF57D",
    "volleyball": "\uF9B3",
    "volume-high": "\uF57E",
    "volume-low": "\uF57F",
    "volume-medium": "\uF580",
    "volume-minus": "\uF75D",
    "volume-mute": "\uF75E",
    "volume-off": "\uF581",
    "volume-plus": "\uF75C",
    "volume-source": "\U000F014B",
    "volume-variant-off": "\uFE68",
    "volume-vibrate": "\U000F014C",
    "vote": "\uFA1E",
    "vote-outline": "\uFA1F",
    "vpn": "\uF582",
    "vuejs": "\uF843",
    "vuetify": "\uFE50",
    "walk": "\uF583",
    "wall": "\uF7FD",
    "wall-sconce": "\uF91B",
    "wall-sconce-flat": "\uF91C",
    "wall-sconce-variant": "\uF91D",
    "wallet": "\uF584",
    "wallet-giftcard": "\uF585",
    "wallet-membership": "\uF586",
    "wallet-outline": "\uFBB9",
    "wallet-plus": "\uFFAB",
    "wallet-plus-outline": "\uFFAC",
    "wallet-travel": "\uF587",
    "wallpaper": "\uFE69",
    "wan": "\uF588",
    "wardrobe": "\uFFAD",
    "wardrobe-outline": "\uFFAE",
    "warehouse": "\uFFBB",
    "washing-machine": "\uF729",
    "washing-machine-alert": "\U000F01E7",
    "washing-machine-off": "\U000F01E8",
    "watch": "\uF589",
    "watch-export": "\uF58A",
    "watch-export-variant": "\uF894",
    "watch-import": "\uF58B",
    "watch-import-variant": "\uF895",
    "watch-variant": "\uF896",
    "watch-vibrate": "\uF6B0",
    "watch-vibrate-off": "\uFCB6",
    "water": "\uF58C",
    "water-boiler": "\uFFAF",
    "water-boiler-alert": "\U000F01DE",
    "water-boiler-off": "\U000F01DF",
    "water-off": "\uF58D",
    "water-outline": "\uFE6A",
    "water-percent": "\uF58E",
    "water-polo": "\U000F02CB",
    "water-pump": "\uF58F",
    "water-pump-off": "\uFFB0",
    "water-well": "\U000F008D",
    "water-well-outline": "\U000F008E",
    "watermark": "\uF612",
    "wave": "\uFF4B",
    "waves": "\uF78C",
    "waze": "\uFBBA",
    "weather-cloudy": "\uF590",
    "weather-cloudy-alert": "\uFF4C",
    "weather-cloudy-arrow-right": "\uFE51",
    "weather-fog": "\uF591",
    "weather-hail": "\uF592",
    "weather-hazy": "\uFF4D",
    "weather-hurricane": "\uF897",
    "weather-lightning": "\uF593",
    "weather-lightning-rainy": "\uF67D",
    "weather-night": "\uF594",
    "weather-night-partly-cloudy": "\uFF4E",
    "weather-partly-cloudy": "\uF595",
    "weather-partly-lightning": "\uFF4F",
    "weather-partly-rainy": "\uFF50",
    "weather-partly-snowy": "\uFF51",
    "weather-partly-snowy-rainy": "\uFF52",
    "weather-pouring": "\uF596",
    "weather-rainy": "\uF597",
    "weather-snowy": "\uF598",
    "weather-snowy-heavy": "\uFF53",
    "weather-snowy-rainy": "\uF67E",
    "weather-sunny": "\uF599",
    "weather-sunny-alert": "\uFF54",
    "weather-sunset": "\uF59A",
    "weather-sunset-down": "\uF59B",
    "weather-sunset-up": "\uF59C",
    "weather-tornado": "\uFF55",
    "weather-windy": "\uF59D",
    "weather-windy-variant": "\uF59E",
    "web": "\uF59F",
    "web-box": "\uFFB1",
    "web-clock": "\U000F0275",
    "webcam": "\uF5A0",
    "webhook": "\uF62F",
    "webpack": "\uF72A",
    "webrtc": "\U000F0273",
    "wechat": "\uF611",
    "weight": "\uF5A1",
    "weight-gram": "\uFD1B",
    "weight-kilogram": "\uF5A2",
    "weight-lifter": "\U000F0188",
    "weight-pound": "\uF9B4",
    "whatsapp": "\uF5A3",
    "wheelchair-accessibility": "\uF5A4",
    "whistle": "\uF9B5",
    "whistle-outline": "\U000F02E7",
    "white-balance-auto": "\uF5A5",
    "white-balance-incandescent": "\uF5A6",
    "white-balance-iridescent": "\uF5A7",
    "white-balance-sunny": "\uF5A8",
    "widgets": "\uF72B",
    "widgets-outline": "\U000F0380",
    "wifi": "\uF5A9",
    "wifi-off": "\uF5AA",
    "wifi-star": "\uFE6B",
    "wifi-strength-1": "\uF91E",
    "wifi-strength-1-alert": "\uF91F",
    "wifi-strength-1-lock": "\uF920",
    "wifi-strength-2": "\uF921",
    "wifi-strength-2-alert": "\uF922",
    "wifi-strength-2-lock": "\uF923",
    "wifi-strength-3": "\uF924",
    "wifi-strength-3-alert": "\uF925",
    "wifi-strength-3-lock": "\uF926",
    "wifi-strength-4": "\uF927",
    "wifi-strength-4-alert": "\uF928",
    "wifi-strength-4-lock": "\uF929",
    "wifi-strength-alert-outline": "\uF92A",
    "wifi-strength-lock-outline": "\uF92B",
    "wifi-strength-off": "\uF92C",
    "wifi-strength-off-outline": "\uF92D",
    "wifi-strength-outline": "\uF92E",
    "wii": "\uF5AB",
    "wiiu": "\uF72C",
    "wikipedia": "\uF5AC",
    "wind-turbine": "\uFD81",
    "window-close": "\uF5AD",
    "window-closed": "\uF5AE",
    "window-closed-variant": "\U000F0206",
    "window-maximize": "\uF5AF",
    "window-minimize": "\uF5B0",
    "window-open": "\uF5B1",
    "window-open-variant": "\U000F0207",
    "window-restore": "\uF5B2",
    "window-shutter": "\U000F0147",
    "window-shutter-alert": "\U000F0148",
    "window-shutter-open": "\U000F0149",
    "windows": "\uF5B3",
    "windows-classic": "\uFA20",
    "wiper": "\uFAE8",
    "wiper-wash": "\uFD82",
    "wordpress": "\uF5B4",
    "worker": "\uF5B5",
    "wrap": "\uF5B6",
    "wrap-disabled": "\uFBBB",
    "wrench": "\uF5B7",
    "wrench-outline": "\uFBBC",
    "wunderlist": "\uF5B8",
    "xamarin": "\uF844",
    "xamarin-outline": "\uF845",
    "xaml": "\uF673",
    "xbox": "\uF5B9",
    "xbox-controller": "\uF5BA",
    "xbox-controller-battery-alert": "\uF74A",
    "xbox-controller-battery-charging": "\uFA21",
    "xbox-controller-battery-empty": "\uF74B",
    "xbox-controller-battery-full": "\uF74C",
    "xbox-controller-battery-low": "\uF74D",
    "xbox-controller-battery-medium": "\uF74E",
    "xbox-controller-battery-unknown": "\uF74F",
    "xbox-controller-menu": "\uFE52",
    "xbox-controller-off": "\uF5BB",
    "xbox-controller-view": "\uFE53",
    "xda": "\uF5BC",
    "xing": "\uF5BD",
    "xing-box": "\uF5BE",
    "xing-circle": "\uF5BF",
    "xml": "\uF5C0",
    "xmpp": "\uF7FE",
    "yahoo": "\uFB2A",
    "yammer": "\uF788",
    "yeast": "\uF5C1",
    "yelp": "\uF5C2",
    "yin-yang": "\uF67F",
    "yoga": "\U000F01A7",
    "youtube": "\uF5C3",
    "youtube-creator-studio": "\uF846",
    "youtube-gaming": "\uF847",
    "youtube-subscription": "\uFD1C",
    "youtube-tv": "\uF448",
    "z-wave": "\uFAE9",
    "zend": "\uFAEA",
    "zigbee": "\uFD1D",
    "zip-box": "\uF5C4",
    "zip-box-outline": "\U000F001B",
    "zip-disk": "\uFA22",
    "zodiac-aquarius": "\uFA7C",
    "zodiac-aries": "\uFA7D",
    "zodiac-cancer": "\uFA7E",
    "zodiac-capricorn": "\uFA7F",
    "zodiac-gemini": "\uFA80",
    "zodiac-leo": "\uFA81",
    "zodiac-libra": "\uFA82",
    "zodiac-pisces": "\uFA83",
    "zodiac-sagittarius": "\uFA84",
    "zodiac-scorpio": "\uFA85",
    "zodiac-taurus": "\uFA86",
    "zodiac-virgo": "\uFA87",
    "blank": " ",
}
